%==========================================================================
% IBD_fs_AnalyseFeatureSelectionRelapse
%==========================================================================
% Wrapper for IBD_fs_analyseFeatureSelection for relapse
% 11 March 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine'};     % without antibiotics
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine'};

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Overall model
S = load(fileNameList.fs_TestRelapseModel);

%--------------------------------------------------------------------------
% Plot response rates over eta
f1 = figure;
n = 3;
m = 3;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

% Tables of linear models
linearModel.all = struct;
linearModel.measurable = struct;
N = 4;
for j = 1:N
    linearModel.all.(['x',int2str(j)]) = table('Size',[length(scenarios),2*j+2],'VariableTypes',['double',repmat({'double','string'},1,j),'double'],'RowNames',scenarioNames);
end

colours             = IBD_myColours('fs');
colour_measurable   = (1-colours(1,:))/2+colours(1,:);
colour_all          = (1-colours(3,:))/2+colours(3,:);

for i = 1:length(scenarios)
    scenario    = scenarios{i};
    
    subplot(m,n,i);
    ax = gca;
    
    [fs,~] = IBD_fs_analyseFeatureSelection([scenarios{i},'_relapse'],save2tikz,save2pdf,struct('title',[scenarioNames{i},'\phantom{y}'],'omitLegend',true,'textBelow',true),ax);
    hold on
    plot([S.fs.all.all.nr;length(S.fs.all.all.linearCoeff{1})],[S.fs.all.all.(scenario);S.fs.all.all.(scenario)(end)],'Color',colour_all)
    plot([S.fs.measurable.all.nr;length(S.fs.measurable.all.linearCoeff{1})],[S.fs.measurable.all.(scenario);S.fs.measurable.all.(scenario)(end)],'Color',colour_measurable)
    
    if ~ismember(i,[4])
        ylabel('')
    end
	if save2tikz
        ax = gca;
       	xlabel({ax.XLabel.String,''})
    end
    
    % Print best linear models with 2 features
    fprintf('\n%s (all): %s --- %.2f\n',scenarioNames{i},fs.all.all.linearModel_original_rounded{2},fs.all.all.correct2(2))
    fprintf('%s (measurable): %s --- %.2f\n',scenarioNames{i},fs.measurable.all.linearModel_original_rounded{2},fs.measurable.all.correct2(2))
    
    % Tables of linear models
    for j = 1:N
        % all
        idx = find(fs.all.all.nr==j);
        if ~isempty(idx)
            linearCoeff = fs.all.all.linearCoeff_original{idx};
            linearModel.all.(['x',int2str(j)]){i,1} = fs.all.all.constCoeff(idx);
            linearModel.all.(['x',int2str(j)]){i,2:2:end-2} = linearCoeff(linearCoeff~=0)';
            linearModel.all.(['x',int2str(j)]){i,3:2:end-1} = fs.all.all.features{idx};
            linearModel.all.(['x',int2str(j)]){i,end} = fs.all.all.correct2(idx);
        end
        % measurable
        idx = find(fs.measurable.all.nr==j);
        if ~isempty(idx)
            linearCoeff = fs.measurable.all.linearCoeff_original{idx};
            linearModel.all.(['x',int2str(j)]){i,1} = fs.measurable.all.constCoeff(idx);
            linearModel.all.(['x',int2str(j)]){i,2:2:end-2} = linearCoeff(linearCoeff~=0)';
            linearModel.all.(['x',int2str(j)]){i,3:2:end-1} = fs.measurable.all.features{idx};
            linearModel.all.(['x',int2str(j)]){i,end} = fs.measurable.all.correct2(idx);
        end
    end
    
end

% Add legend in separate subplot
subplot(3,3,9)
hold on
colours = IBD_myColours('fs');
p1 = plot(1,1,'Color',colours(3,:));
p2 = plot(1,1,'Color',colours(1,:));
p3 = plot(1,1,'Color',colour_all);
p4 = plot(1,1,'Color',colour_measurable);
l = legend({'all features','measurable','all features/overall model','measurable/overall model'},'Location','east');
set(gca,'visible','off');

f1 = IBD_nicePlot(f1);

if save2pdf
    IBD_saveFigure(f1,'fs_relapse','pdf')
end
if save2tikz
    IBD_saveFigure(f1,'fs_relapse','tikz')
end

%--------------------------------------------------------------------------
