function [featureSelection,f] = IBD_fs_analyseFeatureSelection(datasetName,save2tikz,save2pdf,options,ax)
%==========================================================================
% function [featureSelection,f] = IBD_fs_analyseFeatureSelection(datasetName,save2tikz,save2pdf,options,ax)
%==========================================================================
% Visual analysis of feature selection using linear discriminant analysis
% 14 October 2020
%--------------------------------------------------------------------------
%-- input
% datasetName:    	name of the dataset
%                   'par' | 'ss0' | any treatment name
% save2tikz:        bool
% save2pdf:         bool
% options:          additional options
% ax:               (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output   
% featureSelection: result table of best linear model per nr of features
% f:                figure
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load comparison result
load(fileNameList.fs_LDAfeatureSelection.(datasetName));

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

if ~exist('options','var')
    options = struct;
end

if ~exist('ax','var') || isempty(ax)
    f = figure;
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

%--------------------------------------------------------------------------
% Plots
colours = IBD_myColours('fs');
colour.measurable.all           = colours(1,:);
colour.measurable.excludeCDEIS  = colours(2,:);
colour.all.all                  = colours(3,:);
colour.all.excludeCDEIS         = colours(4,:);

xlabel('Number of features')
ylabel('Fraction correctly classified')
ylim([0.5 1])
legendCell = {};
measName = fieldnames(featureSelection)';
maxNrOfFeatures = 0;
addyTicks = [];
cm = zeros(0,3);
idx_cm = 1;
for j = 1:length(measName)
    excludeName = fieldnames(featureSelection.(measName{j}))';
    for k = 1:length(excludeName)
        fsTable = featureSelection.(measName{j}).(excludeName{k});
        maxNrOfFeatures = max(maxNrOfFeatures,length(fsTable.linearCoeff{1}));

        % Add linear model to table
        for l = 1:size(fsTable,1)
            constCoeff  = fsTable.constCoeff(l);
            linearCoeff = fsTable.linearCoeff{l};
            linearCoeff = linearCoeff(abs(linearCoeff)>0);
            predictors  = fsTable.features{l}';
            fsTable.linearModel(l) = join([num2str(constCoeff),join(join([cellstr(num2str(linearCoeff)),predictors],'*')',' + ')],' + ');
            linearCoeff_original = fsTable.linearCoeff_original{l};
            linearCoeff_original = linearCoeff_original(abs(linearCoeff_original)>0);
            fsTable.linearModel_original(l) = join([num2str(constCoeff),join(join([cellstr(num2str(linearCoeff_original)),predictors],'*')',' + ')],' + ');
            fsTable.linearModel_original_rounded(l) = join([num2str(round(constCoeff,3,'significant')),join(join([cellstr(num2str(round(linearCoeff_original,3,'significant'))),predictors],'*')',' + ')],' + ');
        end

        % Eliminate rows with lower corrected correct value than row before
        idx = 1;
        for m = 2:size(fsTable,1)
            if fsTable.correct2(m)>max(fsTable.correct2(1:m-1))
                idx = [idx,m];
            end
        end
        fsTable = fsTable(idx,:);
        
        % Plot
        plot(ax,[fsTable.nr;length(fsTable.linearCoeff{1})],[fsTable.correct2;fsTable.correct2(end)],'Color',colour.(measName{j}).(excludeName{k}))
        
        % Add reference line with maximal values
        h = yline(ax,fsTable.correct2(end),'--','Color',colour.(measName{j}).(excludeName{k}));
        set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
        addyTicks = [addyTicks,fsTable.correct2(end)];
        cm(idx_cm,:) = colour.(measName{j}).(excludeName{k}); idx_cm = idx_cm+1;
        
        % Legend
        thisLegend = '';
        switch measName{j}
            case 'all'
                thisLegend = [thisLegend,'all features'];
            case 'measurable'
                thisLegend = [thisLegend,'measurable'];
        end
        thisLegend = [thisLegend,'/'];
        switch excludeName{k}
            case 'all'
                thisLegend = [thisLegend,'all patients'];
            case 'excludeCDEIS'
                thisLegend = [thisLegend,'CDEIS>6'];
        end
      	legendCell = [legendCell,{thisLegend}];  

        featureSelection.(measName{j}).(excludeName{k}) = fsTable;
    end
end

xlim(ax,[0 maxNrOfFeatures])
ylim(ax,[0.5 1])

% Add end value for each curve
xl = xlim;
for i = 1:length(addyTicks)
    if isfield(options,'textBelow') && options.textBelow
        if addyTicks(i) == max(addyTicks)
            ypos = addyTicks(i)+0.06;
        else
            ypos = addyTicks(i)-0.06;
        end
        text(ax,xl(2),ypos,sprintf('%.2f',addyTicks(i)),'Color',cm(i,:),'HorizontalAlignment','right')
    else
        text(ax,xl(2),addyTicks(i),sprintf('%.2f',addyTicks(i)),'Color',cm(i,:),'HorizontalAlignment','left')
    end
end

% Legend
switch datasetName
    case 'ss0'
        legendLocation = 'northeast';
    otherwise
        legendLocation = 'southeast';
end
if ~isfield(options,'omitLegend') || ~options.omitLegend
	legend(ax,legendCell,'Location',legendLocation)
end

% Title
if isfield(options,'title')
    t = title(options.title);
else   
    switch datasetName
        case 'par'
            t = title('Parameters');
        case 'ss0'
            t = title('Pre-trigger steady state');
        case 'par_ss0'
            t = title('Parameters and pre-trigger steady state');
        otherwise
            t = title(datasetName);
    end
end

if save2tikz
    yl = ylim;
    xl = xlim;
    t = title(t.String,'Interpreter','latex','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
    text(xl(1),(yl(2)-yl(1))*1.12+yl(1),t.String,'HorizontalAlignment',t.HorizontalAlignment,'FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
    title('')
end

if makeFigure
    f = IBD_nicePlot(f);
    if save2pdf
        IBD_saveFigure(f,sprintf('fs_%s',datasetName),'pdf')
    end
    if save2tikz
        IBD_saveFigure(f,sprintf('fs_%s',datasetName),'tikz')
    end
else
    f = nan;
end

%--------------------------------------------------------------------------
