function [dataTable,ref] = IBD_fs_makeDataset(datasetName,measurable,excludeCDEIS)
%==========================================================================
% IBD_fs_makeDataset(datasetName,measurable,excludeCDEIS)
%==========================================================================
% Load data and make dataset for feature selection
%--------------------------------------------------------------------------
%-- input
% datasetName:    	name of the data to compare
% measurable:      	bool: include only measurable parameters/states
% excludeCDEIS:     bool: exclude patients with CDEIS<6
%                   (only for datasetName 'par' or 'ss0')
%--------------------------------------------------------------------------
%-- output
% dataTable:        dataset  
% ref:              reference values used to normalise the dataset
%==========================================================================

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Options
targetResponse = 50;    % approximate percentage of responders per treatment

% Dataset (full)
switch datasetName
    
    case 'par'
        % Load data
        if exist('excludeCDEIS','var') && excludeCDEIS
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','ssMI','individual_ref');
            patient.CDEIS   = IBD_CDEIS(patient.ssMI,patient.individual_ref.I);
            data2           = patient.par(:,patient.CDEIS>6);        % exclude patients with CDEIS<6
        else
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'par','individual_ref');
            data2           = patient.par;
        end
        healthy             = load(strrep(fileNameList.CombinePopulation,'xxx','healthy'),'par','individual_ref');
        data1               = healthy.par;
        variableNames       = patient.individual_ref.I.parName;
        ref                 = patient.individual_ref.par;

    case 'ss0'
        % Load data
        if exist('excludeCDEIS','var') && excludeCDEIS
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','ssMI','individual_ref');
            patient.CDEIS   = IBD_CDEIS(patient.ssMI,patient.individual_ref.I);
            data2           = patient.ss0(:,patient.CDEIS>6);        % exclude patients with CDEIS<6
        else
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','individual_ref');
            data2           = patient.ss0;
        end
        healthy             = load(strrep(fileNameList.CombinePopulation,'xxx','healthy'),'ss0','individual_ref');
        data1               = healthy.ss0;
        variableNames       = IBD_uniqueStateName(patient.individual_ref.I);
        ref                 = patient.individual_ref.Xadd_ss;
        
    case 'par_ss0'
        % Load data
        if exist('excludeCDEIS','var') && excludeCDEIS
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','ssMI','par','individual_ref');
            patient.CDEIS   = IBD_CDEIS(patient.ssMI,patient.individual_ref.I);
            data2           = [patient.ss0(:,patient.CDEIS>6);patient.par(:,patient.CDEIS>6)];        % exclude patients with CDEIS<6
        else
            patient         = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','par','individual_ref');
            data2           = [patient.ss0;patient.par];
        end
        healthy             = load(strrep(fileNameList.CombinePopulation,'xxx','healthy'),'ss0','par','individual_ref');
        data1               = [healthy.ss0;healthy.par];
        variableNames       = [IBD_uniqueStateName(patient.individual_ref.I),patient.individual_ref.I.parName];
        ref                 = [patient.individual_ref.Xadd_ss,patient.individual_ref.par];     
        
    otherwise
        
        if endsWith(datasetName,'relapse','IgnoreCase',true)
            % Relapse
            datasetName2 = datasetName(1:end-8);
            
            % Load data
            load(fileNameList.constantTreatment.(datasetName2),'ssEOT','options','CDEIS','individual_ref');
            response   = CDEIS.ssEOT<4;
            rr         = sum(response,2)/size(response,2)*100;
            % Etas resulting in 30/50% response rate:
            if ~isnan(options.eta50)
                idx  	= find(all(options.etas==options.eta50,1));
                fprintf('Dataset %s with response rate 50 %%\n',datasetName)
            elseif ~isnan(options.eta30)
                idx  	= find(all(options.etas==options.eta30,1));
                fprintf('Dataset %s with response rate 30 %%\n',datasetName)
            else
                [~,idx] = max(options.etas(1,:));
                fprintf('Dataset %s with response rate %.1f %%\n',datasetName,rr(idx))
            end
            responders      = CDEIS.ssEOT(idx,:)<4;
            responders_PT   = CDEIS.ssPT(idx,:)<4;
            no_relapse    	= responders & responders_PT;
            relapse         = responders & ~responders_PT;
            data1           = squeeze(ssEOT(:,idx,no_relapse));    	% non-responders
            data2           = squeeze(ssEOT(:,idx,relapse));       	% responders
            variableNames   = IBD_uniqueStateName(individual_ref.I);
            ref             = individual_ref.Xadd_ss;
            patient.individual_ref = individual_ref;
            
        else
            % Responders vs non-responders
            % Load data
            patient = load(fileNameList.ClinicalIBDpopulation,'ssMI','individual_ref');
            load(fileNameList.constantTreatment_CDEIS.(datasetName),'options','CDEIS');
            response   = CDEIS.ssEOT<4;
            rr         = sum(response,2)/size(response,2)*100;
            % Etas resulting in 30/50% response rate:
            idx30      = find(round(rr,1)==30);
            if isempty(idx30)
                idx30 = nan;
            end
            idx50      = find(round(rr,1)==50);
            if isempty(idx50)
                idx50 = nan;
            end
            if ~isnan(idx50)
                idx = idx50;
                fprintf('Dataset %s with response rate 50 %%\n',datasetName)
            elseif ~isnan(idx30)
                idx = idx30;
                fprintf('Dataset %s with response rate 30 %%\n',datasetName)
            else
                [~,idx] = max(options.etas(1,:));
                fprintf('Dataset %s with response rate %.1f %%\n',datasetName,rr(idx))
            end
            responders      = CDEIS.ssEOT(idx,:)<4;
            nonresponders   = ~responders;
            data1           = patient.ssMI(:,nonresponders); 	% non-responders
            data2           = patient.ssMI(:,responders);       % responders
            variableNames   = IBD_uniqueStateName(patient.individual_ref.I);
            ref             = patient.individual_ref.Xadd_ss;
        end
end

% Make dataset
N_ind = min(size(data1,2),size(data2,2));
dataTable = array2table(...
    [ [data1(:,datasample(1:size(data1,2),N_ind,'Replace',false))',-ones(N_ind,1)]   ;...
      [data2(:,datasample(1:size(data2,2),N_ind,'Replace',false))', ones(N_ind,1)]  ],...
    'VariableNames',[variableNames,{'class'}]...
);
ref = array2table(ref,'VariableNames',variableNames);

% Use only measurable pars/states
if exist('measurable','var') && measurable
    switch datasetName
        case 'par'
            dataTable   = IBD_fs_measurablePars(dataTable,patient.individual_ref);
            ref         = IBD_fs_measurablePars(ref,      patient.individual_ref);
        otherwise
            dataTable   = IBD_fs_measurableStates(dataTable,patient.individual_ref);
            ref         = IBD_fs_measurableStates(ref,      patient.individual_ref);
    end
end

% Normalise by reference individual's par/states
dataTable{:,1:end-1} = dataTable{:,1:end-1}./ref{:,:};

% Exclude nans and columns with zero variance
exclude     = isnan(var(dataTable{:,:})) | var(dataTable{:,:})==0;
dataTable   = removevars(dataTable,exclude);
ref         = removevars(ref,      exclude);

% Exclude duplicate columns
[~,ia,~]    = unique(dataTable{:,:}','stable','rows');
dataTable   = dataTable(:,ia);
ref         = ref(:,ia(1:end-1));

% Exclude column 'mucus' (duplicate to 'epi', but with very small numerical error)
% Exclude some of the additional state variables (as they are not used in thesis)
excludeStates = {'mucus','APCp_LP','APCm_LP','APCp_LN','APCm_LN'};
for i = 1:length(excludeStates)
        if ismember(excludeStates{i},dataTable.Properties.VariableNames)
        dataTable = removevars(dataTable,excludeStates{i});
        ref       = removevars(ref,      excludeStates{i});
    end
end


%--------------------------------------------------------------------------
end

