function fsTable = IBD_fs_regularisedLDA(model)
%==========================================================================
% fsTable = IBD_fs_regularisedLDA(model)
%==========================================================================
% Feature selection using regularisation of linear discriminant analysis
% 24 January 2020
%--------------------------------------------------------------------------
%-- input
% model:            model struct for feature selection
%--------------------------------------------------------------------------
%-- output
% fsTable:          table of performance and linear model per nr of features
%==========================================================================

% Train and test a linear model
model.type = 'LDA';
model.dataTable_train = model.dataTable;    % because cvshrink internally does cross-validation --> use the full dataset
model = IBD_fs_trainModel(model);
model = IBD_fs_testModel(model);

%--------------------------------------------------------------------------
% Regularisation of LDA
fprintf('Regularisation of LDA...\n')
tic_reg = tic;
[err,gamma,delta,numpred] = cvshrink(model.classifier,'NumGamma',49,'NumDelta',49,'Verbose',1);
toc_reg = toc(tic_reg);
fprintf('Regularisation took %.1f min\n',toc_reg/60)

%--------------------------------------------------------------------------
% Feature selection, performance per nr of features
featureNumbers              = unique(reshape(numpred,1,[]));
featureNumbers              = featureNumbers(featureNumbers>0);
fsTable                     = array2table(nan(length(featureNumbers),9),'VariableNames',{'nr','correct','correct2','gamma','delta','constCoeff','linearCoeff','linearCoeff_original','features'});
fsTable.linearCoeff         = num2cell(fsTable.linearCoeff);
fsTable.linearCoeff_original= num2cell(fsTable.linearCoeff_original);
fsTable.features            = num2cell(fsTable.features);
fsTable.nr                  = featureNumbers';
for nrOfFeatures = featureNumbers
    idx                         = find(fsTable.nr==nrOfFeatures);
    thisErr                     = min(min(err(numpred<=nrOfFeatures)));
    [r,s]                       = find((err==thisErr)&(numpred<=nrOfFeatures),1);
    fsTable{idx,'correct'}     	= 1-thisErr;
    fsTable{idx,'gamma'}      	= gamma(r);
    fsTable{idx,'delta'}      	= delta(r,s);
    modelTmp = model;
    modelTmp.classifier.Gamma   = gamma(r);
    modelTmp.classifier.Delta   = delta(r,s);
    constCoeff                  = modelTmp.classifier.Coeffs(2,1).Const;
    linearCoeff                 = modelTmp.classifier.Coeffs(2,1).Linear;
    fsTable{idx,'constCoeff'}    = constCoeff;
    fsTable{idx,'linearCoeff'}   = {linearCoeff};
    fsTable{idx,'linearCoeff_original'} = {linearCoeff./model.ref{1,:}'};
    fsTable{idx,'features'}      = {model.classifier.PredictorNames(abs(linearCoeff)>0)};
    fsTable{idx,'correct2'}      = linearModel(constCoeff,linearCoeff,model.dataTable);
end

% Delete duplicate rows
[~,idx] = unique(fsTable.correct);
fsTable = fsTable(idx,:);

%--------------------------------------------------------------------------
end

%==========================================================================
% LOCAL FUNTIONS
function correct = linearModel(constCoeff,linearCoeff,dataTable)
    pred = (constCoeff+linearCoeff'*dataTable{:,1:end-1}')';
    pred(pred>0) = 1;
    pred(pred<0) = -1;
    obs  = dataTable{:,end};
    correct = sum(pred==obs)/length(pred);
end
%--------------------------------------------------------------------------