function model = IBD_fs_trainModel(model,suppressCommandLineOutput)
%==========================================================================
% model = IBD_fs_trainModel(model,suppressCommandLineOutput)
%==========================================================================
% Train a model
% 23 January 2020
%--------------------------------------------------------------------------
%-- input
% model:            model struct for feature selection
% suppressCommandLineOutput
%--------------------------------------------------------------------------
%-- output
% model:            model struct for feature selection         
%==========================================================================

if ~exist('suppressCommandLineOutput','var')
    suppressCommandLineOutput = false;
end

if ~suppressCommandLineOutput
    fprintf('Training a %s model...',model.type)
end
tic_training                = tic;
model.FitInfo               = nan;
switch model.type
    case 'linear'           % linear model
        [X_train,Y_train]	= IBD_fs_dataTable2XY(model.dataTable_train);
        [model.classifier,model.FitInfo] = fitclinear(X_train,Y_train,'ClassNames',[-1 1]);
    case 'SVM'              % support vector machine
        model.classifier   	= fitcsvm(model.dataTable_train,'class','ClassNames',[-1 1]);
    case 'decisionTree'     % decision tree
        model.classifier   	= fitctree(model.dataTable_train,'class','ClassNames',[-1 1]);
    case 'randomForest'     % random forest
        model.classifier    = TreeBagger(model.options.randomForest.NumTrees,model.dataTable_train,'class');
    case 'naiveBayes'       % naive Bayes classifier
        model.classifier   	= fitcnb(model.dataTable_train,'class','ClassNames',[-1 1]);
    case 'LDA_fast'         % linear discriminant analysis (fast)
        model.classifier   	= fitcdiscr(model.dataTable_train,'class','ClassNames',[-1 1],'SaveMemory','on','FillCoeffs','off',...
            'Delta',model.options.LDA.Delta,'Gamma',model.options.LDA.Gamma);
    case 'LDA'           	% linear discriminant analysis
        model.classifier   	= fitcdiscr(model.dataTable_train,'class','ClassNames',[-1 1],...
            'Delta',model.options.LDA.Delta,'Gamma',model.options.LDA.Gamma);
    case 'ANN'              % artificial neural network
        [inputs,targets]    = IBD_fs_dataTable2ANN(model.dataTable_train);
        net                 = patternnet(model.options.ANN.hiddenLayerSize);
        net.divideParam.trainRatio  = model.options.ANN.trainRatio;
        net.divideParam.valRatio    = model.options.ANN.valRatio;
        net.divideParam.testRatio   = model.options.ANN.testRatio;
        net.trainParam.showWindow   = false;
        [net,~]             = train(net,inputs,targets);
        model.classifier    = net;
    case 'knn'              % k-nearest neighbour classification
        model.classifier   	= fitcknn(model.dataTable_train,'class','ClassNames',[-1 1],...
            'NumNeighbors',model.options.knn.NumNeighbours,'Distance',model.options.knn.Distance);
    case 'GPR'
        model.classifier    = fitrgp(model.dataTable_train,'class',...
            'KernelParameters',model.options.GPR.KernelParameters,'Sigma',model.options.GPR.Sigma,'KernelFunction','squaredexponential');
    otherwise
        error('Specified model type has not been implemented yet.')
end
model.trainingTime          = toc(tic_training);
if ~suppressCommandLineOutput
    fprintf(' took %.1f s.\n',model.trainingTime);
end

%--------------------------------------------------------------------------
end

