function IR = IBD_IR(input,output_idx,tstarValues,perturbFac,model)
%==========================================================================
% IR = IBD_IR(input,output_idx,tstarValues,perturbFac,model)
%==========================================================================
% Input-response indices
%--------------------------------------------------------------------------
%-- input
% input:        string specifying input scenario
%             	'STm' | 'extracellular' | 'injury'
% output_idx: 	index of output state
%               or indices of output states
% tstarValues:  time points for evaluation of IR indices
% perturbFac:   factors by which the input is perturbed
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% IR:           results table or IR indices
%--------------------------------------------------------------------------
%-- sources:
% Knöchel, J., Kloft, C., & Huisinga, W. (2018):
% Understanding and reducing complex systems pharmacology models based on a
% novel input–response index
% Journal of pharmacokinetics and pharmacodynamics, 45(1), 139-157.
%==========================================================================

I               	= model.I;

% Time points
model.tstarValues 	= tstarValues;
model.t_ref         = unique([tstarValues,(0:12:ceil(max(model.tstarValues)))])';

% Input
model.u_ref      	= zeros(size(model.X0));
switch input
    case 'STm'
        model.u_ref(I.Bact_Lu(I.STm))           = model.infection.initial;
    case 'extracellular'
        model.u_ref(I.Bact_Lu(I.extracellular)) = model.infection.initial;
    case 'injury'
        model.u_ref(I.epi)                      = -model.infection.epiDamage;
        model.u_ref(I.tissue)                   = -model.infection.tisDamage;
    otherwise
        error('Requested input not implemented.')
end

% ODE, initial values, solver options
model.X0          	= model.X_ss';
model.ode          	= model.ode_par;
model.solver.options= model.ODEoptions;

% Output
model.h             = {};
for o = 1:length(output_idx)
    model.h{o}   	= @(x) h_function(x,output_idx(o),model);
end

% Perturbations
model.perturbFac   	= perturbFac;
model.nrOfPerturb  	= length(model.perturbFac);

% Other
model.output.states  = {};

%--------------------------------------------------------------------------
% Run input-response index calculation
IR = JKn_IRindices_multiOutput(model);

end

%==========================================================================
% LOCAL FUNCTIONS

% Model output
function h = h_function(X,idx,model)
    Xadd    = model.sumStates(X,model.I,model.par);
    h       = Xadd(:,idx);
end
