function LSA = IBD_LSA(output,model)
%==========================================================================
% LSA = IBD_LSA(output,model)
%==========================================================================
% Local sensitivity analysis (finite difference approximation)
%--------------------------------------------------------------------------
%-- input
% output:     	string specifying output scenario
%               'Thmax' | 'RI' | 'elimination'
%               or cell array of strings
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% LSA:          results table
%--------------------------------------------------------------------------
%-- sources:
% Zi, Z. (2011):
% Sensitivity analysis approaches applied to systems biology mode
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------

if ~iscellstr(output)
    output = {output};
end

% Settings
delta       = 0.01;

% Parameters to analyse
% Omit integers
I           = model.I;
omitPars    = [I.egressThreshold,I.egressThresholdm,I.nTn,I.nTm,I.ssEpi,...                     % integer parameters
    I.ssTis,I.ssMucus,I.wPhagoLPqDC,I.wPhagoLPrDC,I.wPhagoLPtDC,I.wPhagoLPsDC,I.wPhagoLPNeut];  % = 1
parIdx      = setdiff(I.allPar,omitPars);

% Add additional time points around important time points in reference output
facTimepoints   = [0.8 0.85 0.9 0.93 0.95 0.97 0.99 1.01 1.03 1.05 1.07 1.1 1.15 1.2]';

% Define output y
% + additional time points around important time points in reference output
model.y = {};
addTimePoints = [];
for o = 1:length(output)
    switch output{o}

        case 'Thmax'
            model.y{o} = @(T,X)output_Thmax(T,X,model);

            % Additional time points around important time points in reference output
            [~,i]           = max(model.Xadd(:,model.I.Th_tot_LP));
            addTimePoints   = [addTimePoints; model.T(i)*facTimepoints];
            
        case 'Mmax'
            model.y{o} = @(T,X)output_Mmax(T,X,model);

            % Additional time points around important time points in reference output
            [~,i]           = max(model.Xadd(:,model.I.M_tot_LP));
            addTimePoints   = [addTimePoints; model.T(i)*facTimepoints];
            
    	case 'Neutmax'
            model.y{o} = @(T,X)output_Neutmax(T,X,model);

            % Additional time points around important time points in reference output
            [~,i]           = max(model.Xadd(:,model.I.Neut_LP));
            addTimePoints   = [addTimePoints; model.T(i)*facTimepoints];

        case 'RI'
            model.y{o} = @(T,X)output_RI(T,X,model);

            % Additional time points around important time points in reference output
            [m,i]           = max(model.X(:,model.I.Neut_LP));
            i2              = find(model.X(:,model.I.Neut_LP)<m/2 & (1:size(model.X,1))'>i, 1);
            addTimePoints   = [addTimePoints; model.T(i)*facTimepoints; model.T(i2)*facTimepoints];

        case 'elimination'
            model.y{o} = @(T,X)output_elimination(T,X,model);

            % Additional time points around important time points in reference output
            addTimePoints   = [addTimePoints; model.y(model.T,model.X)*facTimepoints];

        case 'AUCtis'
            model.y{o} = @(T,X)output_AUCtis(T,X,model);
            model.timespan 	= model.T;      % no additional time points 

        case 'AUCepi'
            model.y{o} = @(T,X)output_AUCepi(T,X,model);
            model.timespan 	= model.T;      % no additional time points 

        otherwise
            error('Requested output not implemented.')
    end
end

model.timespan 	= sort(unique([model.T; addTimePoints]));

% Reference output
fprintf('Calculation of reference output');
tic_LSA     = tic;
par         = model.par;
[T,X]     	= simulate(par,model);
yref        = nan(1,length(output));
for o = 1:length(output)
    yref(o) = model.y{o}(T,X);
end
fprintf(' took %.2f sec.\n',toc(tic_LSA));

% Results table
idx         = parIdx';
LSA         = table.empty(0,8);
LSA.Properties.VariableNames = {'idx','par','bact','output','yref','plus','minus','delta'};
for o = 1:length(output)
    LSA_j 	= table(idx,I.parName(idx)',I.bactName(I.parBact(idx))',repmat(output(o),size(idx)),repmat(yref(o),size(idx)),zeros(size(idx)),zeros(size(idx)),repmat(delta,size(idx)));
    LSA_j.Properties.VariableNames = LSA.Properties.VariableNames;
    LSA   	= [LSA;LSA_j];
end

%--------------------------------------------------------------------------
% Local sensitivity analysis for all specified parameters

for i = 1:length(parIdx)
    fprintf('Local sensitivity analysis of parameter <strong>%s</strong>\n',I.parName{parIdx(i)});
    tic_LSA = tic;
    
    % Increased parameter
    par = model.par;
    par(parIdx(i))  = (1+delta)*model.par(parIdx(i));
    % Special cases: steady state values of epi and mucus are not allowed > 1
    if (parIdx(i) == I.ssEpi && par(parIdx(i))>1) || (parIdx(i) == I.ssMucus && par(parIdx(i))>1)
        par(parIdx(i))  = 1;
    end
    [T,X]         	= simulate(par,model);
    for o = 1:length(output)
        yper        = model.y{o}(T,X);
        rownr       = LSA.idx==parIdx(i) & strcmp(LSA.output,output{o});
        LSA.plus(rownr) = yper;
    end
    
    % Decreased parameter
    par = model.par;
    par(parIdx(i))  = (1-delta)*model.par(parIdx(i));
    [T,X]         	= simulate(par,model);
    for o = 1:length(output)
        yper        = model.y{o}(T,X);
        rownr       = LSA.idx==parIdx(i) & strcmp(LSA.output,output{o});
        LSA.minus(rownr) = yper;
    end
    
    fprintf('... took %.2f sec.\n',toc(tic_LSA));
end

%--------------------------------------------------------------------------
% Calculation of sensitivities
LSA.S = ((LSA.plus-LSA.yref)./(LSA.delta.*LSA.yref) - (LSA.minus-LSA.yref)./(LSA.delta.*LSA.yref))/2;     % average sensitivity of increased and decreased parameter

end


%==========================================================================
% LOCAL FUNCTIONS

% Model output functions: (all one-dimensional)

% Maximal T helper cell concentration in LP
function y = output_Thmax(~,X,model)
    Xadd 	= model.sumStates(X,model.I,model.par);
    y       = max(Xadd(:,model.I.Th_tot_LP));
end

% Maximal macrophage concentration in LP
function y = output_Mmax(~,X,model)
    Xadd 	= model.sumStates(X,model.I,model.par);
    y       = max(Xadd(:,model.I.M_tot_LP));
end

% Maximal Neutrophil concentration in LP
function y = output_Neutmax(~,X,model)
    Xadd 	= model.sumStates(X,model.I,model.par);
    y       = max(Xadd(:,model.I.Neut_LP));
end

% Resolution interval (= time from maximal neutrophil concentration to half-maximal concentration)
function y = output_RI(T,X,model)
  	[mx,ix] = max(X(:,model.I.Neut_LP));
    i2x     = find(X(:,model.I.Neut_LP)<mx/2 & (1:size(X,1))'>ix, 1);
    RI      = T(i2x)-T(ix);
    y       = RI;
end

% Time to complete elimination of pathogen
function y = output_elimination(T,X,model)
    idx_noBact	= find((...
                        all(X(:,[model.I.Bact_LP(2:end)',model.I.MP1inf_LP,model.I.MP2inf_LP,model.I.MP3inf_LP,model.I.MP4inf_LP,model.I.Mefferoinf_LP])<(1/(model.par(model.I.VLP_tot))),2) & ...
                        (T>1) ...
                        ),1);
	y           = T(idx_noBact);
end

% Tissue AUC
function y = output_AUCtis(~,X,model)
    tissue_dev = 1-X(:,model.I.tissue);      % tissue deviations from 1 (only values lower than 1)
    tissue_dev(tissue_dev<0) = 0;
    y       = trapz(tissue_dev);
end

% Epithelium AUC
function y = output_AUCepi(~,X,model)
    epi_dev = 1-X(:,model.I.epi);         % epi deviations from 1
    y       = trapz(epi_dev);
end

%--------------------------------------------------------------------------
% Simulation for given parameter vector
function [T,X] = simulate(par,model)

model.par   = par;
model       = IBD_runSteadyState(model);
model       = IBD_runInfection(model);

T           = model.T;
X           = model.X;

end

