function LSA = IBD_LSAoverTime(output,model,parIdx)
%==========================================================================
% LSA = IBD_LSAoverTime(output,model)
%==========================================================================
% Local sensitivity analysis (finite difference approximation),
% time-resolved
%--------------------------------------------------------------------------
%-- input
% output:     	string specifying output scenario
%               'Th' | 'M' | 'Neut'
%               or cell array of strings
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% LSA:          results table
%--------------------------------------------------------------------------
%-- sources:
% Zi, Z. (2011):
% Sensitivity analysis approaches applied to systems biology mode
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------

if ~iscellstr(output)
    output = {output};
end

% Settings
delta       = 0.01;

I           = model.I;

% Define output y
% + additional time points around important time points in reference output
model.y = {};
for o = 1:length(output)
    switch output{o}

        case 'Thtot'
            model.y{o} = @(T,X)output_Th(T,X,model);
            
        case 'Mtot'
            model.y{o} = @(T,X)output_M(T,X,model);
            
    	case 'Neut'
            model.y{o} = @(T,X)output_Neut(T,X,model);
            
        otherwise
            error('Requested output not implemented.')
    end
end

model.timespan 	= model.T;

% Reference output
fprintf('Calculation of reference output');
tic_LSA     = tic;
par         = model.par;
[T,X]     	= simulate(par,model);
yref        = nan(length(model.timespan)+1,length(output));
Tref        = T;
for o = 1:length(output)
    yref(:,o) = model.y{o}(T,X);
end
fprintf(' took %.2f sec.\n',toc(tic_LSA));

% Results table
idx         = reshape(parIdx,[],1);
LSA         = struct;

%--------------------------------------------------------------------------
% Local sensitivity analysis for all specified parameters
for o = 1:length(output)
    LSA.(output{o}) = {};
end

for i = 1:length(parIdx)

    fprintf('Local sensitivity analysis of parameter <strong>%s</strong>\n',I.parName{parIdx(i)});
    tic_LSA = tic;

    % Prepare table
    for o = 1:length(output)
        LSA.(output{o}){i} = array2table(nan(length(model.timespan)+1,8));
        LSA.(output{o}){i}.Properties.VariableNames = {'idx','par','T','yref','plus','minus','delta','S'};
        LSA.(output{o}){i}.idx      = repmat(parIdx(i),length(model.timespan)+1,1);
        LSA.(output{o}){i}.par      = repmat(I.parName{parIdx(i)},length(model.timespan)+1,1);
        LSA.(output{o}){i}.yref     = yref(:,o);
        LSA.(output{o}){i}.delta    = repmat(delta,length(model.timespan)+1,1);
        LSA.(output{o}){i}.T        = Tref;
    end
    
    % Increased parameter
    par             = model.par;
    par(parIdx(i))  = (1+delta)*model.par(parIdx(i));
    [T,X]         	= simulate(par,model);
    for o = 1:length(output)
        LSA.(output{o}){i}.plus = model.y{o}(T,X);
    end
    
    % Decreased parameter
    par             = model.par;
    par(parIdx(i))  = (1-delta)*model.par(parIdx(i));
    [T,X]         	= simulate(par,model);
    for o = 1:length(output)
        LSA.(output{o}){i}.minus = model.y{o}(T,X);
    end
    
    % Calculation of sensitivities
    for o = 1:length(output)
        LSA.(output{o}){i}.S = (...
              (LSA.(output{o}){i}.plus -LSA.(output{o}){i}.yref)./(LSA.(output{o}){i}.delta.*LSA.(output{o}){i}.yref) ...
            - (LSA.(output{o}){i}.minus-LSA.(output{o}){i}.yref)./(LSA.(output{o}){i}.delta.*LSA.(output{o}){i}.yref) ...
            )/2;
    end
    
    fprintf('... took %.2f sec.\n',toc(tic_LSA));
end

%--------------------------------------------------------------------------
end


%==========================================================================
% LOCAL FUNCTIONS

% Model output functions:

% T helper cell concentration in LP
function y = output_Th(~,X,model)
    Xadd 	= model.sumStates(X,model.I,model.par);
    y       = Xadd(:,model.I.Th_tot_LP);
end

% Macrophage concentration in LP
function y = output_M(~,X,model)
    Xadd 	= model.sumStates(X,model.I,model.par);
    y       = Xadd(:,model.I.M_tot_LP);
end

% Neutrophil concentration in LP
function y = output_Neut(~,X,model)
    y       = X(:,model.I.Neut_LP);
end

%--------------------------------------------------------------------------
% Simulation for given parameter vector
function [T,X] = simulate(par,model)

model.par   = par;
model       = IBD_runSteadyState(model);
model       = IBD_runInfection(model);

T           = model.T;
X           = model.X;

end

