function [distTable,histCounts] = IBD_compareHistograms(par,measure,individual_ref,p_Lp,rmOutliers)
%==========================================================================
% [distTable,histCounts] = IBD_compareHistograms(par,measure,individual_ref,p_Lp,rmOutliers)
%==========================================================================
% Compare parameter distributions among clusters
%--------------------------------------------------------------------------
%-- input
% par:          struct parameter arrays per class
% measure:      distance measure to be used
% individual_ref
% p_Lp:         (optional) p for Lp-norm
% rmOutliers:   (optional) true/false remove outliers from distribution
%--------------------------------------------------------------------------
%-- output
% distTable:  	distance measure
% allHists:     histogram counts per parameter
%--------------------------------------------------------------------------
%-- sources:
% Short talk CMa, 7 March 2019
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

% Distance measure
switch measure
    case {'Lp','Lp-norm'}
        if ~exist('p_Lp','var')
            p_Lp = 2;
        end
        distMeasure = @(P,Q) Lp_norm(P,Q,p_Lp);
        
    case {'KL','Kullback-Leibler'}
        error('Kullback-Leibler distance is non-symmetric. Use Jensen-Shannon (JS) instead.')
        
    case {'JS','Jensen-Shannon'}
        distMeasure = @(P,Q) JS_divergence(P,Q);
        
    case {'Hellinger'}
        distMeasure = @(P,Q) Hellinger_dist(P,Q);
        
    case {'chi2'}
        distMeasure = @(P,Q) chi2_dist(P,Q);
        
    case {'overlap'}
        distMeasure = @(P,Q) overlap(P,Q);
        % Note: = Lp_1 norm /2
        
    otherwise
        error('Specified distance measure has not been implemented.')
end

% Remove outliers
if exist('rmOutliers','var') && rmOutliers
    q95 = quantile(par,0.95,2);
    par(par>q95) = q95;
end


% Number of parameters
classes = fieldnames(par)';
N_par   = size(par.(classes{1}),1);
N_class = length(fieldnames(par));

% Parameters or steady state concentrations?
if N_par==individual_ref.I.nrOfPar
    thisComparison = 'par';
else
    thisComparison = 'ss';
end

% Histogram counts struct
histCounts = struct;

% Distance table
distTable = array2table(nan(N_par,sum(1:(N_class-1))));
switch thisComparison
    case 'par'
        parName = individual_ref.uniqueParName(individual_ref.I);
    case 'ss'
        parName = individual_ref.uniqueStateName(individual_ref.I);
end
distTable.Properties.RowNames = parName;
z = 1;
for i = 1:N_class
    for j = (i+1):N_class
        distTable.Properties.VariableNames{z} = ['c',int2str(i),'to',int2str(j)];
        z = z+1;
    end
end

% Bin parameters into histograms
nbins = 20;

% For each parameter
for p = 1:N_par
    
    allPar = [];
    for i = 1:N_class
        allPar = [allPar,par.(classes{i})(p,:)];
    end
    
    % 1.) Bin all parameters to get edges
    [P,edges] = histcounts(allPar,nbins);
    
    % 2.) For each class: bin parameters using edges
    Q = nan(N_class,nbins);
    parMedian = nan(1,N_class);
    for c = 1:N_class
        [Q(c,:),~]  = histcounts(par.(classes{c})(p,:),edges);
        % Normalise by number of individuals in cluster
        Q(c,:) = Q(c,:)/size(par.(classes{c}),2);
        parMedian(c) = median(par.(classes{c})(p,:),'omitnan');
    end
    
    % Compare each to each
    for i = 1:N_class
        for j = (i+1):N_class
            distTable.(['c',int2str(i),'to',int2str(j)])(p) = distMeasure(Q(i,:),Q(j,:));
        end
    end
    
    % Save histogram counts
    histCounts.(parName{p})        	= struct;
    histCounts.(parName{p}).all   	= P;
    histCounts.(parName{p}).class	= array2table(Q,'RowNames',classes);
    histCounts.(parName{p}).edges 	= edges;
    histCounts.(parName{p}).median 	= array2table(parMedian,'VariableNames',classes);
    
end

end

%==========================================================================
% LOCAL FUNCTIONS

% Lp norm
function Lp = Lp_norm(P,Q,p)
    Lp = sum(abs(P-Q).^p)^(1/p);
end

% Jensen-Shannon divergence
function JS = JS_divergence(P,Q)
    delta = 1e-10;
    P = P+delta;
    Q = Q+delta;
    M = (P+Q)/2;
    JS = KL_divergence(P,M)+KL_divergence(Q,M);
end

% Kullback-Leibler divergence
function KL = KL_divergence(P,Q)
    KL = sum(P.*log(P./Q));
end

% Hellinger distance
function H = Hellinger_dist(P,Q)
    H = 1/sqrt(2)*sqrt(sum((sqrt(P)-sqrt(Q)).^2));
end

% Chi2 distance
function chi2 = chi2_dist(P,Q)
   chi2 = 1/2*sum(((P-Q).^2)/(P+Q));
end

% Overlap
function o = overlap(P,Q)
    P = reshape(P,1,[]);
    Q = reshape(Q,1,[]);
    o = 1-sum(min([P;Q],[],1));
end

%--------------------------------------------------------------------------