function [ko_a,ko_par] = IBD_knockout(model,type,extent)
%==========================================================================
% ko = IBD_knockout(model)
%==========================================================================
% Knockout of specific processes
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
% type:         what to knock out
% extent:       extent to which the specified processes are decreased
%               (0 = no decrease, 1 = full knockout)
%--------------------------------------------------------------------------
%-- output
% ko:            row vector to multiply (element-wise) with reaction rates
%==========================================================================

if ~exist('type','var')
    type = model.ko.type;
end
if ~exist('extent','var')
    extent = model.ko.extent;
end

if length(type)>1 && length(extent) == 1    % same extent for all
	extent = repmat(extent,[1,length(type)]);
end

%--------------------------------------------------------------------------
I      	= model.I;

ko_a 	= zeros(model.nrOfRct,model.I.nrOfBact);
ko_par 	= zeros(size(model.par));

%--------------------------------------------------------------------------

if strcmp(model.odeType,'rates')
    
    for i = 1:length(type)
        
        koRates = [];   % rates set to extent
        koParam = [];   % parameters set to extent
        koBact  = [];   % if specified, set only Bact-specific rates
                        % for parameters: specify directly in koParam
        koDescription = {};

        switch type{i}

            % Unfunctional iTreg --> no inhibition of DC and M antigen presentation
            case 'iTreg'
                koRates = [72,73,81,82,85,86,87,88,89];
                koParam = [I.wcyto_DeactM_Treg,I.wcyto_DeactDC_Treg];
                koDescription = 'iTreg functions (inhibition of DC and M antigen presentation, anti-inflammatory cytokines)';

            % No additional recruitment of neutrophils and macrophages by pro-inflammatory cytokines
            case 'recruitment'
                koRates = [38];
                koParam = [I.lambdaMmax];
                koDescription = 'additional recruitment of neutrophils and macrophages by pro-inflammatory cytokines';

            % No adaptive immune response (no T cells)
            case 'adaptive'
                koRates = [14,16];
                koParam = [];
                koDescription = 'adaptive immune response (T cells)';

            % No T helper cell effects
            case 'Th'
                koRates = [124:128];
                koParam = [I.wcyto_RecNeut_Th1,I.wcyto_RecNeut_Th17,...
                            I.wcyto_RecM_Th1,I.wcyto_RecM_Th17,...
                            I.wcyto_ActM_Th1,I.wcyto_ActM_Th17,...
                            I.wcyto_ActDC_Th1,I.wcyto_ActDC_Th17,...
                            I.wcyto_DeactM_Th2,I.wcyto_DeactDC_Th2,...
                            I.wcyto_DamageEpi_Th1,I.wcyto_DamageEpi_Th2,I.wcyto_DamageEpi_Th17,...
                            I.wcyto_DamageTis_Th1,I.wcyto_DamageTis_Th2,I.wcyto_DamageTis_Th17,...
                            I.wcyto_TisRemod_Th2];
                koDescription = 'T helper cell effects';

            % No Th1 effects
            case 'Th1'
                koRates = [124:128];
                koParam = [I.wcyto_RecNeut_Th1,...
                            I.wcyto_RecM_Th1,...
                            I.wcyto_ActM_Th1,...
                            I.wcyto_ActDC_Th1,...
                            I.wcyto_DamageEpi_Th1,...
                            I.wcyto_DamageTis_Th1];
                koDescription = 'Th1 effects';

            % No Th2 effects
            case 'Th2'
                koRates = [];
                koParam = [I.wcyto_DeactM_Th2,I.wcyto_DeactDC_Th2,...
                            I.wcyto_DamageEpi_Th2,...
                            I.wcyto_DamageTis_Th2,...
                            I.wcyto_TisRemod_Th2];
                koDescription = 'Th2 effects';

            % No Th17 effects
            case 'Th17'
                koRates = [];
                koParam = [I.wcyto_RecNeut_Th17,...
                            I.wcyto_RecM_Th17,...
                            I.wcyto_ActM_Th17,...
                            I.wcyto_ActDC_Th17,...
                            I.wcyto_DamageEpi_Th17,...
                            I.wcyto_DamageTis_Th17];
                koDescription = 'Th17 effects';

            % No neutrophil recruitment
            case 'Neut_rec'
                koRates = 38;
                koParam = [];
                koDescription = 'neutrophil recruitment';

            % No infection of macrophages by salmonellae
            case 'STm_macrophageInfection'
                koRates = [60:64,107:111,102:106];
                koBact  = I.STm;
                koParam = [];
                koDescription = 'infection of macrophages by salmonellae';

            % No elimination of bacteria by neutrophils
            case 'Neut_phago'
                koRates = [];
                koParam = [I.wPhagoLPNeut];
                koDescription = 'elimination of bacteria by neutrophils';

            % No elimination of bacteria by phagocytic cells
            case 'phago'
                koRates = [37];
                koParam = [];
                koDescription = 'elimination of bacteria by phagocytes';

            % No destruction of epithelial barrier by inflowing pathogens
            case 'epi_Bact'
                error('Implement this KO type!')

            % No destruction of epithelial barrier (and tissue?) by inflammation
            case 'epi_pro'
                koRates = [29];
                koParam = [];
                koDescription = 'epithelial destruction by inflammation';
            
          	% Less commensal bacteria
            case 'commensal'
                koRates = [33];
                koBact  = I.commensal;
                koParam = [];
                koDescription = 'commensal bacteria';

            otherwise
                warning('Specific knockout type not implemented. No knockout will be considered.')
        end
        
        fprintf('<strong>Knockout scenario: %s</strong>: %.0f %% knockout of %s\n',type{i},extent(i)*100,koDescription);
        
        % Evaluate knockout on parameters and rates
        if isempty(koBact)
            ko_a(koRates,:) = extent(i);
        else
            ko_a(koRates,koBact) = extent(i);
        end
        ko_par(koParam) = extent(i);
        
    end

else
    if ~isempty(type)
        warning('Knockout scenarios only implemented for ode type rates. No knockout will be considered.')
    end
end

% Reshape to match rates
ko_a  = reshape(ko_a,[],1);

%--------------------------------------------------------------------------

end


