function model = IBD_modelInfo(model)
%==========================================================================
% model = IBD_modelInfo(model)
%==========================================================================
% Specification of state names and parameter names
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

% Number of reactions without transit compartments
model.nrOfRctWoTransit_true = 135;
model.nrOfRctWoTransit      = model.nrOfRctWoTransit_true+70;       % 50 for extra information

%--------------------------------------------------------------------------
% States
model.stateTable    = IBD_defineStates();
model.stateNames    = model.stateTable.name(~~model.stateTable.simState)';
model.addStateNames = model.stateTable.name(~model.stateTable.simState)';

%--------------------------------------------------------------------------
% Parameters
[model.parTable,model.primParTable,model.auxParTable] = IBD_definePars();
model.parNames      = model.parTable.name';
model.primParNames  = model.primParTable.name';
model.auxParNames   = model.auxParTable.name';

%--------------------------------------------------------------------------
% Transit compartments
model.assignTransitNr   = @(par,I) assignTransitNr(par,I);
model.assignTransitSpec = @(transit,I) assignTransitSpec(transit,I);

%--------------------------------------------------------------------------
% Sum up states for comparison to literature data
model.sumStates = @(X,I,par) sumStates(X,I,par);

%--------------------------------------------------------------------------
% Print names
model.assignPrintName = @(I) assignPrintName(I);
model.uniqueStateName = @(I) uniqueStateName(I);
model.uniqueParName   = @(I) uniqueParName(I);

%--------------------------------------------------------------------------

end

%==========================================================================
% LOCAL FUNCTIONS

% Assigning transit compartment numbers
function transit = assignTransitNr(par,I)
    % Number of transit compartments
    nr.Tn2Treg_LN  	= par(I.nTn);
    nr.Tn2Th1_LN    = par(I.nTn);
    nr.Tn2Th2_LN    = par(I.nTn);
    nr.Tn2Th17_LN   = par(I.nTn);
    nr.Tcm2Temreg_LN= par(I.nTm);
    nr.Tcm2Tem1_LN  = par(I.nTm);
    nr.Tcm2Tem2_LN  = par(I.nTm);
    nr.Tcm2Tem17_LN = par(I.nTm);
    nr.Tem2Treg_LP 	= par(I.nTm);
    nr.Tem2Th1_LP   = par(I.nTm);
    nr.Tem2Th2_LP   = par(I.nTm);
    nr.Tem2Th17_LP  = par(I.nTm);
    transit.nr    	= nr;
    transit.nrOfRct = sum(cell2mat(struct2cell(transit.nr))*4);
end

% Sum up states for comparison to literature data
function X = sumStates(X,I,par)                                      
    X(:,I.DC_tot_LP)    = sum(X(:,[I.qDC_LP,I.tDC_LP',I.rDC_LP,I.sDC_LP',I.tDCi_LP,I.sDCi_LP]),2);	% total dendritic cells in lamina propria
    X(:,I.DC_tot_LN)    = sum(X(:,[I.tDC_LN',I.sDC_LN',I.tDCi_LN,I.sDCi_LN]),2);                   	% total dendritic cells in lymph node
    X(:,I.Th_tot_LN)    = sum(X(:,[reshape(I.Tn2Th1_LN,1,[]),...
        reshape(I.Tn2Th2_LN,1,[]),reshape(I.Tn2Th17_LN,1,[])]),2);              % T helper cells in lymph node
    X(:,I.iTreg_tot_LN) = sum(X(:,[reshape(I.Tn2Treg_LN,1,[])]),2);            	% induced regulatory T cells in lymph node
  	X(:,I.Th_tot_LP)    = sum(X(:,[I.Th1_LP',I.Th2_LP',I.Th17_LP',...
        reshape(I.Tem2Th1_LP,1,[]),reshape(I.Tem2Th2_LP,1,[]),...
        reshape(I.Tem2Th17_LP,1,[])]),2);                                       % T helper cells in lamina propria
    X(:,I.iTreg_tot_LP) = sum(X(:,[reshape(I.Tem2Treg_LP,1,[]),I.iTreg_LP']),2);            % induced regulatory T cells in lamina propria
    X(:,I.Tm_tot_LN)  	= sum(X(:,[I.Tcm_LN,reshape(I.Tcm2Temreg_LN,1,[]),...
        reshape(I.Tcm2Tem1_LN,1,[]),reshape(I.Tcm2Tem2_LN,1,[]),...
        reshape(I.Tcm2Tem17_LN,1,[])]),2);                                      % (central + effector) memory T cells in lymph node
    X(:,I.Temh_tot_LP)	= sum(X(:,[I.Tem1_LP',I.Tem2_LP',I.Tem17_LP']),2);     	% (effector) memory T cells (helper) in lamina propria
    X(:,I.Temreg_tot_LP)= sum(X(:,[I.Temreg_LP']),2);                         	% (effector) memory T cells (regulatory) in lamina propria
    X(:,I.Tm_tot_LP)    = sum(X(:,[I.Temreg_LP',I.Tem1_LP',I.Tem2_LP',...
        I.Tem17_LP']),2);                                                       % (effector) memory T cells in lamina propria
    X(:,I.MP1_tot_LP)  	= sum(X(:,[I.MP1_LP,I.MP1a_LP',I.MP1ai_LP,I.MP1inf_LP]),2);             	% MP1 macrophages in lamina propria
    X(:,I.MP2_tot_LP)  	= sum(X(:,[I.MP2_LP,I.MP2a_LP',I.MP2ai_LP,I.MP2inf_LP]),2);              	% MP2 macrophages in lamina propria
    X(:,I.MP3_tot_LP)  	= sum(X(:,[I.MP3_LP,I.MP3a_LP',I.MP3ai_LP,I.MP3inf_LP]),2);                	% MP3 macrophages in lamina propria
    X(:,I.MP4_tot_LP) 	= sum(X(:,[I.MP4_LP,I.MP4a_LP',I.MP4ai_LP,I.MP4inf_LP]),2);             	% MP4 macrophages in lamina propria
    X(:,I.Meffero_tot_LP) = sum(X(:,[I.Meffero_LP,I.Mefferoa_LP',I.Mefferoai_LP,I.Mefferoinf_LP]),2);	% efferocytosis-type macrophages in lamina propria
    X(:,I.M_tot_LP)     = sum(X(:,[I.MP1_tot_LP,I.MP2_tot_LP,I.MP3_tot_LP,...
        I.MP4_tot_LP,I.Meffero_tot_LP]),2);                                     % total macrophages in lamina propria    
    X(:,I.SPM_LP)       = sum(X(:,[I.apoNeut_LP,I.Meffero_LP,I.Mefferoa_LP'])...
        .* repmat(par([I.wSPMLPNeut,repmat(I.wSPMLPMeffero,[1,1+I.nrOfBact])]),[size(X,1),1]),2);   % specialised pro-resolving mediators
    X(:,I.APCp_LN)      = X(:,I.sDC_LN);                                        % antigen-presenting cells with co-stimulatory molecules
    X(:,I.APCm_LN)      = X(:,I.tDC_LN);                                        % antigen-presenting cells without co-stimulatory molecules
 	X(:,I.MPhago_LP)    = sum(X(:,[I.MP1_LP,I.MP1a_LP',I.MP2_LP,I.MP2a_LP',I.MP3_LP,I.MP3a_LP',I.MP4_LP,I.MP4a_LP',I.Meffero_LP,I.Mefferoa_LP'])...
        .* repmat(par([I.wPhagoLPMP1,repmat(I.wPhagoLPMP1,[1,I.nrOfBact]),I.wPhagoLPMP2,repmat(I.wPhagoLPMP2,[1,I.nrOfBact]),I.wPhagoLPMP3,...
        repmat(I.wPhagoLPMP3,[1,I.nrOfBact]),I.wPhagoLPMP4,repmat(I.wPhagoLPMP4,[1,I.nrOfBact]),I.wPhagoLPMP4,repmat(I.wPhagoLPMP4,[1,I.nrOfBact])]),...
        [size(X,1),1]),2);
    X(:,I.Phago_LP)     = X(:,I.MPhago_LP)+...
        sum(X(:,[I.qDC_LP,I.rDC_LP,I.tDC_LP',I.sDC_LP',I.Neut_LP])...
        .* repmat(par([I.wPhagoLPqDC,I.wPhagoLPrDC,repmat(I.wPhagoLPtDC,[1,I.nrOfBact]),repmat(I.wPhagoLPsDC,[1,I.nrOfBact]),I.wPhagoLPNeut]),...
        [size(X,1),1]),2);
    
	for b = 1:I.nrOfBact
        X(:,I.APCp_LP(b))   = sum(X(:,[I.sDC_LP(b),I.MP1a_LP(b),I.MP2a_LP(b),I.MP3a_LP(b)])...
            .* repmat([1,repmat(par(I.bsPerM)/par(I.bsPerDC),[1 3])],[size(X,1),1]),2);             % antigen-presenting cells with co-stimulatory molecules
        X(:,I.APCm_LP(b))   = sum(X(:,[I.tDC_LP(b),I.MP4a_LP(b),I.Mefferoa_LP(b)])...
        .* repmat([1,repmat(par(I.bsPerM)/par(I.bsPerDC),[1 2])],[size(X,1),1]),2);                 % antigen-presenting cells without co-stimulatory molecules
        X(:,I.CNC_LP(b))  = par(I.pBact(b))*(1-sum(X(:,I.Bact_LP),2)/par(I.NmaxBact))...
            .*(par(I.KmPhago)/par(I.phagoRec(b))+sum(X(:,I.Bact_LP),2))/par(I.VmaxPhago);
        X(:,I.iTreg_eff_LN(b))  = sum(X(:,I.Tn2Treg_LN(b,2:end)),2);
        X(:,I.iTreg_eff_LP(b))  = sum(X(:,I.Tem2Treg_LP(b,2:end)),2) + X(:,I.iTreg_LP(b)) + X(:,I.Temreg_LP(b));
        X(:,I.Th1_eff_LP(b))    = sum(X(:,I.Tem2Th1_LP(b,2:end)),2) + X(:,I.Th1_LP(b)) + X(:,I.Tem1_LP(b));
        X(:,I.Th2_eff_LP(b))    = sum(X(:,I.Tem2Th2_LP(b,2:end)),2) + X(:,I.Th2_LP(b)) + X(:,I.Tem2_LP(b));
        X(:,I.Th17_eff_LP(b))   = sum(X(:,I.Tem2Th17_LP(b,2:end)),2) + X(:,I.Th17_LP(b)) + X(:,I.Tem17_LP(b));
        X(:,I.Th_eff_tot_LN(b))	= sum(X(:,I.Tn2Th1_LN(b,2:end)),2) + sum(X(:,I.Tn2Th2_LN(b,2:end)),2) + sum(X(:,I.Tn2Th17_LN(b,2:end)),2);
    end
    
    X(:,I.Th_eff_tot_LP)	= sum(X(:,I.Th1_eff_LP),2) + sum(X(:,I.Th2_eff_LP),2) + sum(X(:,I.Th17_eff_LP),2);
    
	if any(ismember(I.bactName,'STm'))
        b = I.STm;
        X(:,I.APCp_LP(b))   = X(:,I.APCp_LP(b)) +...
            sum(X(:,[I.MP1inf_LP,I.MP2inf_LP,I.MP3inf_LP]),2)*par(I.bsPerM)/par(I.bsPerDC);
        X(:,I.APCm_LP(b))   = X(:,I.APCm_LP(b)) +...
            sum(X(:,[I.MP4inf_LP,I.Mefferoinf_LP]),2)*par(I.bsPerM)/par(I.bsPerDC);
    end
     
end

% Assigning printable names
function printName = assignPrintName(I)
    printName = regexprep(I.stateName,'_',' ');
    printName = regexprep(printName,' LN','_{LN}');
    printName = regexprep(printName,' LP','_{LP}');
    printName = regexprep(printName,' Lu','_{Lu}');
end

%--------------------------------------------------------------------------