function primPar = IBD_primParameters(model)
%==========================================================================
% primPar = IBD_primParameters(model)
%==========================================================================
% Primary parameters (literature values)
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% primPar:   	primary parameter vector
%==========================================================================

fprintf('Assigning primary parameters (literature values)...\n')
primI   = model.I.prim;
primPar = nan(1,length(model.primParNames));

%--------------------------------------------------------------------------
%% Volumes
primPar(primI.VLN)                  = 0.03;         % [mL] (= 30 mg) volume of one mesenteric lymph node [ICRP1975]
primPar(primI.VLN_tot)              = 11;        	% [mL] total mesenteric lymph node volume [ICRP1975]
primPar(primI.VLP_tot)              = 87;         	% [mL] total lamina propria volume (small + large intestine), calculated from [Helander2014],[Dhesi1984]
primPar(primI.Vcell)                = 200e-12;      % [mL] mean cell volume (rough mean) [Chapman1981]

%% Steady state concentrations in healthy colon lamina propria
primPar(primI.concT_LP)           	= 3.74e8;   	% [1/mL] T cells (sigmoid colon) [Preza2015]
primPar(primI.ratioTB_LP)           = 5.7;       	% [] ratio T:B (colon) [Sathaliyawala2013]
primPar(primI.ratioCD4CD8_LP)    	= 2.2;        	% [] ratio CD4:CD8 (colon) [Sathaliyawala2013]
primPar(primI.fractionTmCD4_LP)  	= 0.873;     	% [] fraction of CD4+ memory T cells from CD4+ T cells (colon, age 30-50) [Sathaliyawala2013]
primPar(primI.fractionTregLy_LP)  	= 0.054;        % [] fraction of regulatory T cells from LP lymphocytes (colon) [Saruta2007]
primPar(primI.fractionNTregTreg_LP)	= 0.294;        % [] fraction of Helios+ from FOXP3+ T cells in colon [Lord2015a]
primPar(primI.fractionTLPMC)        = 0.53;         % [] fraction of T cells from colon LPMC [Junker2009]
primPar(primI.fractionDCLPMC)     	= 0.008;        % [] fraction of dendritic cells from colon LPMC [Bernardo2016]
primPar(primI.ratioMDC)             = 3.5;          % [] ratio of macrophages to dendritic cells (small intestine, mouse) [Schulz2009]
primPar(primI.concBact_LP)          = 2.7e5;    	% [1/mL] total anaerobe count in sigmoid colon [Swidsinski 2002]
primPar(primI.concNeut_LP)          = 2e6;          % [1/mL] neutrophil concentration in healthy tissue (gaster) [Fu2016]

%% Steady state concentrations in mesenteric lymph node
primPar(primI.concCD4_totLN)     	= 3.2e8;        % [1/mL] concentration of CD4+ T cells in lymphoid tissue [Zhang1998]
primPar(primI.ratioTB_LN)           = 3.3;          % [] ratio T:B (MLN) [Sathaliyawala2013]
primPar(primI.ratioCD4CD8_LN)       = 3.7;          % [] ratio CD4:CD8 (MLN) [Sathaliyawala2013]
primPar(primI.fractionTnCD4_LN)   	= 0.29;         % [] fraction of naive CD4+ T cells from CD4+ T cells [Sathaliyawala2013]
primPar(primI.fractionTcmCD4_LN)   	= 0.48;         % [] fraction of central memory CD4+ T cells from CD4+ T cells [Sathaliyawala2013]
primPar(primI.fractionTemCD4_LN)  	= 0.31;         % [] fraction of effector memory CD4+ T cells from CD4+ T cells [Sathaliyawala2013]
primPar(primI.fractionTzoneLN)     	= 1/2;          % [] fraction of T cell zone in lymph node (ASSUMPTION)
primPar(primI.fractionTregLy_LN)  	= 0.093;        % [] fraction of regulatory T cells from MLN lymphocytes [Saruta2007]
primPar(primI.fractionNTregTreg_LN) = 0.57;         % [] fraction of Helios+ from FOXP3+ T cells in MLN, assumed to be similar to blood, where [Lord2015a]

%% Steady state concentrations in blood
primPar(primI.fractionTnCD4_bl) 	= 0.41;         % [] fraction of naive CD4+ T cells from CD4+ T cells (blood) [Sathaliyawala2013]
primPar(primI.fractionTmCD4_bl)  	= 0.51;         % [] fraction of memory CD4+ T cells from CD4+ T cells (blood, age 30-50) [Sathaliyawala2013] (--> caution: Tem+Tcm > Tm)
primPar(primI.fractionTemCD4_bl)  	= 0.19;         % [] fraction of effector memory CD4+ T cells from CD4+ T cells (blood) [Sathaliyawala2013] (--> caution: Tem+Tcm > Tm)
primPar(primI.fractionTcmCD4_bl)   	= 0.39;         % [] fraction of central memory CD4+ T cells from CD4+ (blood) [Sathaliyawala2013] (--> caution: Tem+Tcm > Tm)
primPar(primI.fractionTregLy_bl)   	= 0.059;        % [] fraction of regulatory T cells from peripheral blood lymphocytes [Saruta2007]
primPar(primI.ratioTB_bl)          	= 3.4;          % [] ratio T:B (blood) [Sathaliyawala2013]
primPar(primI.ratioCD4CD8_bl)       = 2.7;          % [] ratio CD4:CD8 (blood) [Sathaliyawala2013]
primPar(primI.fractionNTregTreg_bl)	= 0.57;         % [] fraction of Helios+ from FOXP3+ T cells in blood [Lord2015a]

%% T cells
primPar(primI.mrtTn_LN)             = 9.6;          % [h] mean residence time of naive CD4 T cell in mesenteric lymph node [Mandl2012]
primPar(primI.lifespanT_LP)        	= 164;          % [d] lifespan of effector memory T cells [Westera2013]
primPar(primI.muTeff)               = 0.5;          % [1/d] effector T cell death rate constant [DeBoer2001]

%% T cell proliferation
primPar(primI.nTn)                  = 18;         	% [] number of transit compartments for naive T cells
primPar(primI.nTm)                  = 18;         	% [] number of transit compartments for memory T cells
primPar(primI.muTprol)              = 0.047;      	% [1/h] death rate constant of proliferating T cells [Gett2000]
primPar(primI.suscApoLow)         	= 0.5;      	% [] susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th) (TEST)
primPar(primI.TfirstDivision)       = 40;           % [h] time to first division of activated naive T cells [Hawkins2007/Gett2000]
primPar(primI.TsubseqDivision)      = 9;            % [h] time for subsequent divisions of activated naive T cells [Hawkins2007/Gett2000]
primPar(primI.egressPerDivision)    = 0.1;       	% [] increase in egress rate per division (starting at division 4) [Pham2008]
primPar(primI.egressThreshold)      = 4;        	% [] minimal division number for egress [Pham2008]
primPar(primI.egressThresholdm)     = 1;        	% [] minimal division number for egress (memory T cells) (TEST)

%% Effector T cells
% Reference individual
primPar(primI.theta1host)        	= 1/3;
primPar(primI.theta2host)           = 1/3;
primPar(primI.theta17host)         	= 1/3;

%% Antigen specificities
primPar(primI.nTCRn)              	= 1e6;          % [] number of TCR specificities of naive CD4 T cells [Beltman2007], [Zhang1995], [Geiger2009]
primPar(primI.nTCRm)                = 1e6/166;     	% [] number of TCR specificities in naive T cells [Arstila1999]: 25*10^6 different TCRs (total) vs 1*10^5-2*10^5 in memory T cells
primPar(primI.beta)                 = 10;           % [] number of antigens per bacterium/presented per dendritic cell
primPar(primI.Tcontact)           	= 2.3;      	% [min] mean contact duration between DC and Tn/Tm [Cai 2017]

%% Dendritic cells
primPar(primI.hlDC)                 = 2;            % [d] half-life of DC [Merad2009], [Lanzavecchia2001], [Liu2007]
primPar(primI.hlDCantigen)          = 2;            % [d] time (as half-life) from antigen-unexperienced to antigen-experienced DC (ASSUMPTION)
primPar(primI.percentDCtoLN)        = 19;        	% [%/d] percent of LP DC that migrate to LN per day [Vuk Cerovic, unpublished]
primPar(primI.percentFromLN)        = 190;          % [%/d] percent of LN DC that leave the LN per day [Vuk Cerovic, unpublished]
primPar(primI.nuDCsMax)             = 0.03;        	% [1/h] maximal dendritic cell activation (TEST)

%% Contact rates
primPar(primI.kTDC_LN)              = 2e-5;         % [mL/h] contact rate constant between T cells and dendritic cells in lymph node, calculated from [Beltman2007]
primPar(primI.kTDC_LP)              = 2e-5/10;     	% [mL/h] contact rate constant between T cells and dendritic cells in lamina propria, set lower to lymph node (ASSUMPTION)
primPar(primI.bsPerDC)            	= 300;          % [] T cell binding sites per DC [Miller2004a]
primPar(primI.bsPerT)              	= 17.5;      	% [] DC binding sites per T cell [Miller2004a]
primPar(primI.bsPerM)               = 15;           % [] T cell binding sites per macrophage (TEST)

%% Macrophages
primPar(primI.muM)                  = 3.1223e-03;   % [1/h] death of macrophages (estimated from [Bain2013])
primPar(primI.nuMP12ss)            	= 4.8836e-02;   % [1/h] transition from macrophage compartment 1 to 2 in steady state (estimated from [Bain2013])
primPar(primI.nuMP23ss)            	= 7.8780e-02;   % [1/h] transition from macrophage compartment 2 to 3 in steady state (estimated from [Bain2013])
primPar(primI.nuMP34ss)             = 2.2087e-02;   % [1/h] transition from macrophage compartment 3 to 4 in steady state (estimated from [Bain2013])
primPar(primI.foldPhagoMP1)         = 0.034;        % [] phagocytic activity of P1 macrophages, relative to P4 macrophages [Bain2013]
primPar(primI.foldPhagoMP2)        	= 0.12;         % [] phagocytic activity of P2 macrophages, relative to P4 macrophages [Bain2013]
primPar(primI.foldPhagoMP3)        	= 0.31;         % [] phagocytic activity of P3 macrophages, relative to P4 macrophages [Bain2013]
primPar(primI.phagoMP4)            	= 1;            % [] phagocytic activity of P4 macrophages, relative to dendritic cells (ASSUMPTION: phagocytic activity of P4 macrophages equals dendritic cells)
primPar(primI.nuMphago)             = 0.1;       	% [] fraction of macrophages that move to anti-inflammatory state after phagocytosis of one apoptotic neutrophil (TEST) (<=1)
primPar(primI.facNuM)               = 1.25;       	% [] factor for nuM to ensure correct steady state fractions
primPar(primI.facRecM)              = 1;            % [] factor for cRecM to ensure correct steady state concentration

%% Neutrophils
primPar(primI.VmaxPhago)            = 22.2;     	% [1/h] maximal phagocytosis rate per neutrophil (estimated from [Li2004])
primPar(primI.KmPhago)              = 3.7e7;        % [1/mL] bacteria concentration of half-maximal phagocytosis rate per neutrophil (estimated from [Li2004])
primPar(primI.muNeutc)              = 1/(7*24);  	% [1/h] constitutive/spontaneous neutrophil apoptosis [Tak2013]
primPar(primI.muNeutPhago)         	= 1/50;        	% [] proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell --> = 1/number of bacteria that one neutrophil can eliminate [vanKessel2014]
primPar(primI.muNeutMax)            = 0.35;         % [1/h] maximal neutrophil apoptosis, stimulated by SPM (TEST)
primPar(primI.muAponeut)            = 1/48;         % [1/h] necrosis of apoptotic neutrophils (TEST)

%% S. typhimurium infection
primPar(primI.pSTmInt)              = 2.5e-4;    	% [1/s] intracellular growth rate of S.Tm [Gog2012]
primPar(primI.Nburst)               = 30;           % [] burst threshold: maximal number of bacteria per macrophage [Brown2006]

%% Bacteria
primPar(primI.NmaxBact)             = 1e10;         % [1/mL] maximal concentration of bacteria in LP (REF?)
primPar(primI.kBact)                = 3/24;         % [1/h] nutrients inflow, bacterial proliferation and death rate constant in lumen (TEST)

%% Mucus & epithelial barrier
primPar(primI.epsilonBact1)         = 3e8;          % [1/(mL*h)] inflow of bacteria without toxin (TEST)
primPar(primI.hlEpi)                = 3;            % [d] half-life of epithelium [ICRP1975]
primPar(primI.ssEpi)                = 1;            % [] steady state value of epithelium
primPar(primI.muEpiBact)            = 1e-10;      	% [mL] destruction of epithelium by bacteria with toxin (TEST)
primPar(primI.muEpiFac)             = 1;            % [] maximal relative increase of epithelium degradation
primPar(primI.hlMucus)              = 1.5;          % [h] half-life of mucus layer [Faderl2015]
primPar(primI.ssMucus)              = 0.9;          % [] steady state value of mucus (TEST)
primPar(primI.hlTis)                = 6;            % [d] half-life of tissue [ICRP1975]
primPar(primI.ssTis)                = 1;            % [] steady state value of tissue
primPar(primI.muTisFac)             = 1;            % [] maximal relative increase of tissue degradation
primPar(primI.epsilonFCP)           = 1e-5;      	% [mL*ug/(h*g)] outflow of neutrophils (FCP) into lumen
primPar(primI.ctt)                  = 18.2;         % [h] colorectal transit time [Haase2016]

%% Recruitment, activation, inhibition
primPar(primI.lambdaMax)            = 1e6;          % [1/(mL*h)] maximal cell (macrophage) inflow rate into LP (TEST)
primPar(primI.lambdaNeutMax)        = 1e8;          % [1/(mL*h)] maximal neutrophil inflow into LP
primPar(primI.HillRec)           	= 2;            % [] Hill factor for recruitment
primPar(primI.HillAct)              = 1;            % [] Hill factor for activation/de-activation
primPar(primI.wProLPBact)         	= 1e-6;         % [mL^(hill-1)] weight for bacteria concentration in neutrophil recruitment

%% Weights for phagocytosis
% --> relative to neutrophils (weight Neut = 1)
primPar(primI.wPhagoLPqDC)          = 1;
primPar(primI.wPhagoLPrDC)          = 1;
primPar(primI.wPhagoLPtDC)          = 1;
primPar(primI.wPhagoLPsDC)          = 1;
primPar(primI.wPhagoLPMP1)          = primPar(primI.phagoMP4)*primPar(primI.foldPhagoMP1);   	% caution: in nuMP12, nuMP23, nuMP34: assumption that wPhagoMP1 = wPhagoP2 etc. --> if different, 2 different parameters nuMP12 and nuMP12a needed!
primPar(primI.wPhagoLPMP2)          = primPar(primI.phagoMP4)*primPar(primI.foldPhagoMP2);
primPar(primI.wPhagoLPMP3)          = primPar(primI.phagoMP4)*primPar(primI.foldPhagoMP3);
primPar(primI.wPhagoLPMP4)          = primPar(primI.phagoMP4);% phagoMP4 relative to DC
primPar(primI.wPhagoLPNeut)         = 1;
% ! primPar(primI.phagoMP4) must be the same value!

%% Weights for cytokine production
primPar(primI.wcyto_RecNeut_Th1)    = 0;
primPar(primI.wcyto_RecNeut_Th17)   = 5e-8;
primPar(primI.wcyto_RecNeut_Neut)   = 2e-9;
primPar(primI.wcyto_RecNeut_M)      = 3e-8;

primPar(primI.wcyto_RecM_Th1)       = 1e-7;
primPar(primI.wcyto_RecM_Th17)      = 1e-8;
primPar(primI.wcyto_RecM_Neut)      = 2e-8;
primPar(primI.wcyto_RecM_M)         = 3e-8;

primPar(primI.wcyto_ActM_Th1)       = 2e-7;
primPar(primI.wcyto_ActM_Th17)      = 2e-8;
primPar(primI.wcyto_ActM_Neut)      = 2e-8;
primPar(primI.wcyto_ActM_M)         = 3e-8;

primPar(primI.wcyto_ActDC_Th1)      = 3e-8;
primPar(primI.wcyto_ActDC_Th17)     = 3e-9;
primPar(primI.wcyto_ActDC_Neut)     = 1e-7;
primPar(primI.wcyto_ActDC_M)        = 1e-7;

primPar(primI.wcyto_DeactM_Treg)    = 8e-9;
primPar(primI.wcyto_DeactM_Th2)     = 5e-9;
primPar(primI.wcyto_DeactM_M)       = 3e-8;

primPar(primI.wcyto_DeactDC_Treg)   = 8e-9;
primPar(primI.wcyto_DeactDC_Th2)    = 5e-9;
primPar(primI.wcyto_DeactDC_M)      = 3e-8;

primPar(primI.wcyto_DamageEpi_Th1)	= 1e-9;
primPar(primI.wcyto_DamageEpi_Th17)	= 1e-9;
primPar(primI.wcyto_DamageEpi_Th2)	= 2e-9;
primPar(primI.wcyto_DamageEpi_Neut)	= 5e-9;
primPar(primI.wcyto_DamageEpi_M)  	= 1e-9;

primPar(primI.wcyto_DamageTis_Th1)	= 1e-9;
primPar(primI.wcyto_DamageTis_Th17)	= 1e-9;
primPar(primI.wcyto_DamageTis_Th2)	= 2e-9;
primPar(primI.wcyto_DamageTis_Neut)	= 5e-9;
primPar(primI.wcyto_DamageTis_M)  	= 1e-9;

primPar(primI.wcyto_TisRemod_Th2)   = 2e-9;
primPar(primI.wcyto_TisRemod_M)     = 1e-9;

%% Weights of specialised pro-resolving mediator production
% --> relative to neutrophils (weight Neut = 1)
primPar(primI.wSPMLPNeut)           = 4.8e-7/430;     % [Dalli2012]
primPar(primI.wSPMLPMeffero)        = 4.8e-7;         

%% Bacteria-specific parameters     % commensal STm         extracellular
I = model.I;

% Commensal bacteria
if sum(strcmp('commensal',I.bactName))
    primPar(primI.nBact(I.commensal))              	= 100;     	% [] number of different bacteria in this bacterial subgroup (REF?)
    primPar(primI.TmRecognition(I.commensal))     	= 1;        % [] (partial) recognition by memory T cells (due to conserved structures) (set to 1 for secondary infection)
    primPar(primI.pBact(I.commensal))              	= 0.72;   	% [1/h] growth of bacteria in tissue [Li2004]
    primPar(primI.phagoRec(I.commensal))          	= 1;        % [] probability of recognition of bacteria by phagocytic cells (TEST)
    primPar(primI.foldpBactLu(I.commensal))       	= 1;    	% [] relative proliferation to commensal bacteria (TEST)
    primPar(primI.epsilonBact2(I.commensal))       	= 0;        % [1/(mL*h)] inflow of bacteria with toxin (TEST) (for STm and extracellular set to a value so that for initial Bact_Lu = 0.001 maximal infection)     
    primPar(primI.theta1bact(I.commensal))        	= 1/3;      % [] fraction of Th1 cells elicited by this bacterial species
    primPar(primI.theta2bact(I.commensal))        	= 1/3;      % [] fraction of Th2 cells elicited by this bacterial species
    primPar(primI.theta17bact(I.commensal))        	= 1/3;      % [] fraction of Th17 cells elicited by this bacterial species
    % for multiple commensal: sample fractions from lognormal distribution using MuBact,SigmaBact
end

% Salmonella typhimurium
if sum(strcmp('STm',I.bactName))
    primPar(primI.nBact(I.STm))                     = 1;      	% [] number of different bacteria in this bacterial subgroup (REF?)
    primPar(primI.TmRecognition(I.STm))             = 0.7;   	% [] (partial) recognition by memory T cells (due to conserved structures) (set to 1 for secondary infection)
    primPar(primI.pBact(I.STm))                     = 0;       	% [1/h] growth of bacteria in tissue [Li2004]
    primPar(primI.phagoRec(I.STm))                  = 1;      	% [] probability of recognition of bacteria by phagocytic cells (TEST)
    primPar(primI.foldpBactLu(I.STm))               = 0.8;    	% [] relative proliferation to commensal bacteria (TEST)
    primPar(primI.epsilonBact2(I.STm))              = 1e10;   	% [1/(mL*h)] inflow of bacteria with toxin (TEST) (for STm and extracellular set to a value so that for initial Bact_Lu = 0.001 maximal infection)
    primPar(primI.theta1bact(I.STm))                = 1;      	% [] fraction of Th1 cells elicited by this bacterial species
    primPar(primI.theta2bact(I.STm))                = 0;       	% [] fraction of Th2 cells elicited by this bacterial species
    primPar(primI.theta17bact(I.STm))               = 0;      	% [] fraction of Th17 cells elicited by this bacterial species
end

% Extracellular
if sum(strcmp('extracellular',I.bactName))
    primPar(primI.nBact(I.extracellular))        	= 1;      	% [] number of different bacteria in this bacterial subgroup (REF?)
    primPar(primI.TmRecognition(I.extracellular))  	= 0.7;   	% [] (partial) recognition by memory T cells (due to conserved structures) (set to 1 for secondary infection)
    primPar(primI.pBact(I.extracellular))         	= 0.72;  	% [1/h] growth of bacteria in tissue [Li2004] (TEST)
    primPar(primI.phagoRec(I.extracellular))     	= 0.1;   	% [] probability of recognition of bacteria by phagocytic cells (TEST)
    primPar(primI.foldpBactLu(I.extracellular))   	= 0.8;    	% [] relative proliferation to commensal bacteria (TEST)
    primPar(primI.epsilonBact2(I.extracellular))  	= 1e11;   	% [1/(mL*h)] inflow of bacteria with toxin (TEST) (for STm and extracellular set to a value so that for initial Bact_Lu = 0.001 maximal infection)
    primPar(primI.theta1bact(I.extracellular))      = 0;      	% [] fraction of Th1 cells elicited by this bacterial species
    primPar(primI.theta2bact(I.extracellular))      = 0;       	% [] fraction of Th2 cells elicited by this bacterial species
    primPar(primI.theta17bact(I.extracellular))     = 1;      	% [] fraction of Th17 cells elicited by this bacterial species
end

%--------------------------------------------------------------------------
%% Test if all parameters assigned
if any(isnan(primPar))
    fprintf(2,'The following primary parameters are not assigned: %s.\n',strjoin(model.I.prim.parName(isnan(primPar)),' '));
end

%--------------------------------------------------------------------------

end