function model = IBD_referenceIndividual(options)
%==========================================================================
% model = IBD_referenceIndividual()
%==========================================================================
% Get reference individual: parameters, healthy steady state
%--------------------------------------------------------------------------
%-- input
% options       additional optional options
%               BactNames
%               odeType
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)
clear fileName

[model.name,model.version] = IBD_modelVersion();

fprintf('<strong>Version %s</strong>\n',model.version)

%--------------------------------------------------------------------------
if ~exist('options','var')
    options = struct;
end

%--------------------------------------------------------------------------
% General
model           = IBD_modelInfo(model);
if isfield(options,'BactNames')
    model.BactNames = options.BactNames;
else
    model.BactNames = {'commensal'};    % 'commensal' | 'STm' | 'extracellular'
end

% Indexing (parameters)
model.I         = IBD_indexing(model);

% Parameters
[model.par,model.primPar,model.auxPar] = IBD_parameters(model);

% Logistic-normal distribution
model.Thfractions = VarConstraints_referenceParameters;

% Indexing (states)
model.transit   = model.assignTransitNr(model.par,model.I);
model.I         = IBD_indexing(model);
model.nrOfRct   = model.nrOfRctWoTransit + model.transit.nrOfRct;

% Initial values
model.X_ss    	= IBD_initialValues(model)';    % row vector
model.X0        = nan(size(model.X_ss))';       % column vector

% Time span
model.timespan	= [0 150*24];
model.biomarker.FCP.Tplus = (-1:10)*24; % Sampling points for biomarker FCP

% Definition of steady state
model.ss_small  = 1e-5;

% Options
if isfield(options,'odeType')
    model.odeType = options.odeType;
else
    model.odeType 	= 'rates';    	% 'RHS' (ODE right-hand side function) | 'rates' (reaction rates and stoichiometric matrix)
end
model           = IBD_options(model);
model.title     = '';

%--------------------------------------------------------------------------
% Helpful functions
model.evalKO    = @(model) evalKO(model);
model.resetKO   = @(model) resetKO(model);

%--------------------------------------------------------------------------
% Set infection scenario off
model.infection.Bact    = {};           % 'extracellular' | 'STm'
model.infection.initial = 0;            % initial amount of bacteria (fraction of commensal)
model.infection.epiDamage = 0;          % initial destruction of epithelium (no destruction = 0, maximal 1)
model.infection.tisDamage = 0;          % initial destruction of tissue (no destruction = 0, maximal 1)

%--------------------------------------------------------------------------
% Set knockout off
model.ko.type           = {};           % default: {}
model.ko.extent         = 0;            % 1 = full knockout
model.ko.ss             = false;     	% true: knockout considered in ss simulation | false: knockout only considered in infection/injury simulation
model                   = model.evalKO(model);

%--------------------------------------------------------------------------
% Simulate steady state = initial value for further simulations
model                   = IBD_runSteadyState(model);

% Steady state after infection (calculated later)
model.X_ss_after        = nan(size(model.X_ss));
model.Xadd_ss_after    	= nan(size(model.Xadd_ss));
model.T_ss_after        = nan;

ssData                  = IBD_steadyStateData(model.auxPar,model);
model.ssTable           = IBD_steadyStateTable(model.Xadd,model,ssData);

%--------------------------------------------------------------------------
% Numerical problems can occur in steady state calculation
model.problems          = false;

end

%==========================================================================
% LOCAL FUNCTIONS

% Evaluate knockout
function model = evalKO(model)
	[model.ko.a,model.ko.par] 	= IBD_knockout(model,model.ko.type,model.ko.extent);
end

% Reset knockout
function model = resetKO(model)
	model.ko.a   = zeros(model.nrOfRct,model.I.nrOfBact);
 	model.ko.a   = reshape(model.ko.a,[],1);
  	model.ko.par = zeros(size(model.par));
end
