function model = IBD_runInfection(model,simSs)
%==========================================================================
% model = IBD_runInfection(model,simSs)
%==========================================================================
% Simulate infection
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
% simSs:      	(optional): true/false: simulate new steady state
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

if ~exist('simSs','var')
    simSs = false;
end

tic_det                     = tic;
fprintf('Simulation of infection...')

model.X0 = model.X_ss';

% Knockout
model = model.evalKO(model);

% Add bacteria to initial values
for b = 1:length(model.infection.Bact)
    bac = model.infection.Bact{b};
    model.X0(model.I.Bact_Lu(model.I.(bac)))  = model.X0(model.I.Bact_Lu(model.I.(bac))) + model.infection.initial(b);
end

% Epithelial and tissue damage (independent of steady state!)
model.X0(model.I.epi)     	= min([1-model.infection.epiDamage,model.X0(model.I.epi)]);
model.X0(model.I.mucus) 	= min([(1-model.infection.epiDamage)*model.par(model.I.ssMucus)/model.par(model.I.ssEpi),model.X0(model.I.mucus)]);      % epi * ssMucus/ssEpi
model.X0(model.I.tissue)  	= min([1-model.infection.tisDamage,model.X0(model.I.tissue)]);

% Avoid bacterial proliferation due to numerical inaccuracies
X0      = model.X0';
par     = model.par;
par(model.I.pBact)    = par(model.I.pBact).*((X0(model.I.Bact_Lu)>1e-10) | (X0(model.I.Bact_LP)>1e-2));
if ~(ismember('STm',model.I.bactName)) || ((X0(model.I.Bact_Lu(model.I.STm))<1e-10) && (X0(model.I.Bact_LP(model.I.STm))<1e-2))
    par(model.I.pSTmInt) = 0;
end

% Solve ODEs
model.ode_par               = IBD_prepareSimulation(par,model);
[model.T,model.X]           = ode15s(model.ode_par,model.timespan,model.X0,model.ODEoptions);

fprintf(' took %.2f sec.\n',toc(tic_det));

% Add steady state as first time point (for plots)
model.T                     = [0;model.T];
model.X                     = [model.X_ss;model.X];

%--------------------------------------------------------------------------
% Calculate sums of cell types
model.Xadd                  = model.sumStates(model.X,model.I,par);

% Calculate all reaction rates at all time points and stoichiometric matrix
[model.A,model.nu]          = IBD_calcReactionRates(model);

%--------------------------------------------------------------------------
% Simulate new steady state
if simSs
    ss =  checkForSs(0,model.X(end,:)',model.ss_small,model.ode_par);
    if ss 
        % Steady state already reached
        model.X_ss_after  	= model.X(end,:);
        model.Xadd_ss_after	= model.Xadd(end,:);
        model.T_ss_after   	= model.T(end);
    else

        %----------------------------------------------------------------------
        % Simulation
        [T,X,~,~,ie]        = ode15s(model.ode_par,model.timespan_ss,model.X(end,:),model.ODEoptions_ss(model.ode_par,tic));
        % Check if/which event occurred
        if isempty(ie)
            warning('Steady state simulation unsuccessful (timespan too short) - new steady state may be inaccurate!');
            model.problems = true;
        elseif ismember(2,ie)
            warning('Steady state simulation unsuccessful (time limit exceeded) - new steady state may be inaccurate!');
            model.problems = true;
        end

        %----------------------------------------------------------------------
        % Calculate sums of cell types
        Xadd                    = model.sumStates(X,model.I,par);

        %----------------------------------------------------------------------
        % Save new steady state
        model.X_ss_after     	= X(end,:);
        model.Xadd_ss_after    	= Xadd(end,:);
        model.T_ss_after        = model.T(end)+T(end);
    end
end

%--------------------------------------------------------------------------
% Calculate biomarker measurements for given sampling points
% FCP: average since last sampling point
% [model.biomarker.FCP.T,model.biomarker.FCP.X] = IBD_biomarkerSamples(model.T,model.X(:,model.I.FCP),model.biomarker.FCP.Tplus);

end

%==========================================================================
% LOCAL FUNCTIONS

% Check if steady state is reached
function ssReached = checkForSs(t,x,xi,odefunction)
dx          = odefunction(t,x);
a           = abs(dx./x);
a(x<1e-5)   = 0;
[m,idx]     = max(a);
ssReached   = m<=xi;
end

%--------------------------------------------------------------------------