function model = IBD_runSteadyState(model)
%==========================================================================
% model = IBD_runSteadyState(model)
%==========================================================================
% Simulate steady state
%--------------------------------------------------------------------------
%-- input
% model:     	model information struct
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

tic_det                      	= tic;
fprintf('Simulation of healthy steady state...')

% Knockout
if model.ko.ss
    model = model.evalKO(model);
else
    model = model.resetKO(model);
end

parForss                      	= model.par;
parForss(model.I.pBact(2:end))	= 0;    % allow only commensal bacteria --> avoid proliferation of pathogenic bacteria due to numerical inaccuracies
parForss(model.I.pSTmInt)     	= 0;    % --> avoid proliferation of pathogenic bacteria due to numerical inaccuracies

model.ode_par                   = IBD_prepareSimulation(parForss,model);       % model.ode_par(t,X)

% Check if steady state already "reached"
ss =  checkForSs(0,model.X_ss',model.ss_small,model.ode_par);
if ss   
    % Steady state already reached
    model.T = 0;
    model.X = model.X_ss;
else
    
    %----------------------------------------------------------------------
    % Simulation
  	[model.T,model.X,~,~,ie] 	= ode15s(model.ode_par,model.timespan_ss,model.X_ss',model.ODEoptions_ss(model.ode_par,tic));
  	% Check if/which event occurred
  	if isempty(ie)
     	warning('Steady state simulation unsuccessful (timespan too short) - remove individual from further simulations!');
        model.problems = true;
    elseif ismember(2,ie)
        warning('Steady state simulation unsuccessful (time limit exceeded) - remove individual from further simulations!');
        model.problems = true;
    end
    
end

%--------------------------------------------------------------------------
% Calculate sums of cell types
model.Xadd              = model.sumStates(model.X,model.I,model.par);

% Calculate all reaction rates at all time points and stoichiometric matrix
[model.A,model.nu]      = IBD_calcReactionRates(model);

% New steady state
model.X_ss              = model.X(end,:);
model.Xadd_ss           = model.Xadd(end,:);
model.A_ss              = model.A(end,:);


fprintf(' (t = %.2e h)',model.T(end));
fprintf(' took %.2f sec.\n',toc(tic_det));

%--------------------------------------------------------------------------

end

%==========================================================================
% LOCAL FUNCTIONS

% Check if steady state is reached
function ssReached = checkForSs(t,x,xi,odefunction)
dx          = odefunction(t,x);
a           = abs(dx./x);
a(x<1e-5)   = 0;
[m,idx]     = max(a);
ssReached   = m<=xi;
end

%--------------------------------------------------------------------------