function model = IBD_runTreatment(model,duration,eta,affectedPar,affectedRates,newPar,simSs)
%==========================================================================
% model = IBD_runTreatment(model,duration,eta,affectedPar,affectedRates,simSs)
%==========================================================================
% Simulate treatment (constant treatment effects)
%--------------------------------------------------------------------------
%-- input
% model:        model information struct
% duration:     treatment duration
% eta:          constant treatment effect
% affectedPar:  parameters affected (= decreased) by eta
% affectedRates:reaction rates affected (= decreased) by eta
% newPar:       parameters that are replaced by eta
% simSs:     	(optional): true/false: simulate new steady state
%--------------------------------------------------------------------------
%-- output
% model:        model information struct
%==========================================================================

if ~exist('simSs','var')
    simSs = false;
end

tic_det                     = tic;
fprintf('Simulation of treatment...')

model.X0 = model.X_ss';

% Knockout
model = model.evalKO(model);

% Avoid bacterial proliferation due to numerical inaccuracies
X0      = model.X0';
par     = model.par;
par(model.I.pBact)    = par(model.I.pBact).*((X0(model.I.Bact_Lu)>1e-10) | (X0(model.I.Bact_LP)>1e-2));
if ~(ismember('STm',model.I.bactName)) || ((X0(model.I.Bact_Lu(model.I.STm))<1e-10) && (X0(model.I.Bact_LP(model.I.STm))<1e-2))
    par(model.I.pSTmInt) = 0;
end

% Treatment effects as knockout of parameters/rates
model_treatment        	= model;
etaOnPar             	= zeros(size(model.par));
etaOnRates           	= zeros(size(model.ko.a));
par_treatment           = model.par;

assert(length(eta)==length(affectedPar) && length(eta)==length(affectedRates) && length(eta)==length(newPar),'Give one vector of affected parameters/rates per eta!')

for i = 1:length(eta)
    etaOnPar(reshape(affectedPar{i},1,[]))    	= etaOnPar(reshape(affectedPar{i},1,[]))     + eta(i) - etaOnPar(reshape(affectedPar{i},1,[]))    *eta(i);       % combined effect
    etaOnRates(reshape(affectedRates{i},[],1))	= etaOnRates(reshape(affectedRates{i},[],1)) + eta(i) - etaOnRates(reshape(affectedRates{i},[],1))*eta(i);       % combined effect
    par_treatment(reshape(newPar{i},1,[]))      = eta(i);       % last treatment overruns the previous
end

model_treatment.par     = par_treatment;
model_treatment.ko.par	= model.ko.par + etaOnPar - model.ko.par.*etaOnPar;
model_treatment.ko.a 	= model.ko.a + etaOnRates - model.ko.a.*etaOnRates;

% Solve ODEs for time of treatment
model.ode_par               = IBD_prepareSimulation(par_treatment,model_treatment);
timespan                    = [model.timespan(model.timespan<duration),duration];
[T1,X1]                     = ode15s(model.ode_par,timespan,X0',model.ODEoptions);

% Solve ODEs for time after treatment
X0                          = X1(end,:);
model.ode_par               = IBD_prepareSimulation(par,model);
timespan                    = [duration,model.timespan(model.timespan>duration)];
[T2,X2]                     = ode15s(model.ode_par,timespan,X0',model.ODEoptions);

fprintf(' took %.2f sec.\n',toc(tic_det));

% Add steady state as first time point (for plots)
model.T                     = [0;T1;T2];
model.X                     = [model.X_ss;X1;X2];

%--------------------------------------------------------------------------
% Calculate sums of cell types
model.Xadd                  = model.sumStates(model.X,model.I,par);

% Calculate all reaction rates at all time points and stoichiometric matrix
[model.A,model.nu]          = IBD_calcReactionRates(model);

%--------------------------------------------------------------------------
% Simulate new steady state
if simSs
    ss =  checkForSs(0,model.X(end,:)',model.ss_small,model.ode_par);
    if ss 
        % Steady state already reached
        model.X_ss_after  	= model.X(end,:);
        model.Xadd_ss_after	= model.Xadd(end,:);
        model.T_ss_after   	= model.T(end);
    else

        %----------------------------------------------------------------------
        % Simulation
        [T,X,~,~,ie]        = ode15s(model.ode_par,model.timespan_ss,model.X(end,:),model.ODEoptions_ss(model.ode_par,tic));
        % Check if/which event occurred
        if isempty(ie)
            warning('Steady state simulation unsuccessful (timespan too short) - new steady state may be inaccurate!');
            model.problems = true;
        elseif ismember(2,ie)
            warning('Steady state simulation unsuccessful (time limit exceeded) - new steady state may be inaccurate!');
            model.problems = true;
        end

        %----------------------------------------------------------------------
        % Calculate sums of cell types
        Xadd                    = model.sumStates(X,model.I,par);

        %----------------------------------------------------------------------
        % Save new steady state
        model.X_ss_after     	= X(end,:);
        model.Xadd_ss_after    	= Xadd(end,:);
        model.T_ss_after        = model.T(end)+T(end);
    end
end

%--------------------------------------------------------------------------
% Calculate biomarker measurements for given sampling points
% FCP: average since last sampling point
% [model.biomarker.FCP.T,model.biomarker.FCP.X] = IBD_biomarkerSamples(model.T,model.X(:,model.I.FCP),model.biomarker.FCP.Tplus);

end

%==========================================================================
% LOCAL FUNCTIONS

% Check if steady state is reached
function ssReached = checkForSs(t,x,xi,odefunction)
    dx          = odefunction(t,x);
    a           = abs(dx./x);
    a(x<1e-5)   = 0;
    [m,idx]     = max(a);
    ssReached   = m<=xi;
end

%--------------------------------------------------------------------------