function par = IBD_secParameters(primPar,auxPar,model)
%==========================================================================
% par = IBD_secParameters(primPar,auxPar,model)
%==========================================================================
% Secondary parameters (calculated from primary/literature values)
%--------------------------------------------------------------------------
%-- input
% primPar:   	primary parameter vector
% auxPar:     	auxiliary parameter vector
% model:        model information struct
%--------------------------------------------------------------------------
%-- output
% par:          parameter vector
%==========================================================================

fprintf('Assigning secondary parameters...\n')
primI   = model.I.prim;
auxI    = model.I.aux;
I       = model.I;
par     = nan(1,length(model.parNames));

%--------------------------------------------------------------------------
%% Volumes
par(I.VLP)                  = primPar(primI.VLP_tot);                              	% [mL] volume of total lamina propria (small + large intestine)
par(I.VLN)                  = primPar(primI.VLN_tot)*primPar(primI.fractionTzoneLN);% [mL] volume of the T cell zone of total mesenteric lymph nodes
par(I.maxConc)              = 1/primPar(primI.Vcell);                               % [1/mL] maximal reasonable concentration

%% T cells
par(I.muT_LN)               = 1/primPar(primI.mrtTn_LN);                            % [1/h] outflow of T cells from MLN
par(I.muT_LP)               = 1/(primPar(primI.lifespanT_LP)*24);                	% [1/h] death of effector memory T cells
par(I.lambdaT_LN)           = auxPar(auxI.concTn_LN)*par(I.muT_LN)/...
    primPar(primI.fractionTnCD4_bl);                                                % [1/(mL*h)] rate constant (inflow rate constant * volume correction coefficient * concentration of CD4+ T cells in blood) for inflow of T cells into MLN
par(I.muTeff)               = primPar(primI.muTeff)/24;                             % [1/h] effector T cell death rate constant
par(I.fractionTnCD4_bl)     = primPar(primI.fractionTnCD4_bl);                      % [] fraction of naive CD4+ T cells from CD4+ T cells in blood
par(I.fractionTcmCD4_bl)    = primPar(primI.fractionTcmCD4_bl);                     % [] fraction of central memory CD4+ T cells from CD4+ in blood

%% T cell proliferation (transit compartments)
par(I.nTn)                  = primPar(primI.nTn);                                   % [] maximal number of transit compartments for naive T cells
par(I.nTm)                  = primPar(primI.nTm);                                	% [] number of transit compartments for differentiation/proliferation of memory T cells
par(I.muTprol)              = primPar(primI.muTprol);                            	% [1/h] death rate constant of proliferating T cells
par(I.suscApoLow)          	= primPar(primI.suscApoLow);                          	% [] susceptibility factor to apoptosis by activated Tregs, compared to T helper cells (<1 because more resistant than Th)
par(I.pTn1)                	= 1/primPar(primI.TfirstDivision);                   	% [1/h] proliferation rate constant of activated naive T cells (first division)
par(I.pTni)                 = 1/primPar(primI.TsubseqDivision);                     % [1/h] proliferation rate constant of activated naive T cells (subsequent divisions)
par(I.egressPerDivision)    = primPar(primI.egressPerDivision);                  	% [] increase in egress rate per division (starting at division 4)
par(I.egressThreshold)      = primPar(primI.egressThreshold);                   	% [] minimal division number for egress
par(I.egressThresholdm)     = primPar(primI.egressThresholdm);                   	% [] minimal division number for egress (memory T cells)

%% Effector T cells
par(I.theta1host)           = primPar(primI.theta1host);
par(I.theta2host)           = primPar(primI.theta2host);
par(I.theta17host)          = primPar(primI.theta17host);
par(I.theta1bact)           = primPar(primI.theta1bact);
par(I.theta2bact)           = primPar(primI.theta2bact);
par(I.theta17bact)          = primPar(primI.theta17bact);

%% Antigen specificities
par(I.beta)                 = primPar(primI.beta);                                  % [] number of antigens per bacterium/presented per dendritic cell
par(I.alphaTn)          	= 1/primPar(primI.nTCRn);                            	% [] frequency of antigen specificity in naive T cells
par(I.alphaTh)           	= 1./(primPar(primI.nBact).*par(I.beta));               % [] frequency of antigen specificity in effector T cells
par(I.alphaTm)           	= (1/primPar(primI.nTCRm))...
    .*primPar(primI.TmRecognition);                                                 % [] frequency of antigen specificity in memory T cells
par(I.Tcontact)             = primPar(primI.Tcontact)/24;                       	% [h] mean contact duration between DC and Tn/Tm

%% Bacteria in LP
par(I.pBact)                = primPar(primI.pBact);                                 % [1/h] growth of bacteria in tissue
par(I.NmaxBact)             = primPar(primI.NmaxBact);                              % [1/mL] maximal concentration of bacteria in LP
par(I.VmaxPhago)            = primPar(primI.VmaxPhago);                            	% [1/h] maximal phagocytosis rate of bacteria per neutrophil (/phagocytic cell)
par(I.KmPhago)              = primPar(primI.KmPhago)*primPar(primI.phagoRec(1));  	% [1/mL] bacteria concentration for half-maximal phagocytosis rate per neutrophil (/phagocytic cell)
par(I.phagoRec)             = primPar(primI.phagoRec);                              % [] probability of recognition of bacteria by phagocytic cell
par(I.pSTmInt)              = primPar(primI.pSTmInt)*60*24;                       	% [1/h] intracellular growth rate of S.Tm [Gog2012]
par(I.Nburst)               = primPar(primI.Nburst);                                % [] burst threshold: maximal number of bacteria per macrophage [Brown2006]

%% Dendritic cells
par(I.muDC)             	= log(2)/(primPar(primI.hlDC)*24);                      % [1/h] death rate constant of dendritic cells
par(I.muDC_LN)              = primPar(primI.percentFromLN)/100/24;                  % [1/h] migration rate of dendritic cells out of LN
par(I.nuDCa)                = log(2)/(primPar(primI.hlDCantigen)*24);               % [1/h] conversion rate constant from antigen-unexperienced to antigen-experienced dendritic cells (LP)
nu                          = par(I.nuDCa)+...
    (par(I.VmaxPhago)*primPar(primI.concBact_LP))/(par(I.KmPhago(1))/par(I.phagoRec(1))+primPar(primI.concBact_LP))...
    *primPar(primI.wPhagoLPqDC);
par(I.epsilonDC)        	= primPar(primI.percentDCtoLN)/100/24*...
    (par(I.muDC)+nu)/...
    (nu-primPar(primI.percentDCtoLN)/100/24);                                       % [1/h] migration of dendritic cells from LP to MLN
par(I.cRecDC)               = auxPar(auxI.concDC_LP)*...
    (par(I.muDC)+primPar(primI.percentDCtoLN)/100/24);                              % [1/(mL*h)] constant inflow of quiescent dendritic cells into LP
par(I.nuDCsMax)             = primPar(primI.nuDCsMax);                              % [1/h] maximal dendritic cell activation
par(I.HillProActDC)      	= primPar(primI.HillAct);                            	% [] Hill factor for dendritic cell activation stimulation by pro-inflammatory cytokines
par(I.HillAntiActDC)        = primPar(primI.HillAct);                           	% [] Hill factor for dendritic cell activation inhibition by anti-inflammatory cytokines

%% Contact rates
par(I.kTDC_LN)              = primPar(primI.kTDC_LN);                               % [mL/h] contact rate constant for T and DC in LN
par(I.kTDC_LP)              = primPar(primI.kTDC_LP);                             	% [mL/h] contact rate constant for T and DC in LP
par(I.bsPerDC)          	= primPar(primI.bsPerDC);                             	% [] T cell binding sites per DC
par(I.bsPerT)            	= primPar(primI.bsPerT);                                % [] DC binding sites per T cell
par(I.bsPerM)            	= primPar(primI.bsPerM);                                % [] T cell binding sites per macrophage

%% Macrophages
par(I.muM)                  = primPar(primI.muM);                                   % [1/h] death of macrophages
par(I.nuMP12ss)           	= primPar(primI.nuMP12ss)*primPar(primI.facNuM);       	% [1/h] transition from macrophage compartment 1 to 2 in steady state
par(I.nuMP23ss)            	= primPar(primI.nuMP23ss)*primPar(primI.facNuM);       	% [1/h] transition from macrophage compartment 2 to 3 in steady state
par(I.nuMP34ss)           	= primPar(primI.nuMP34ss)*primPar(primI.facNuM);      	% [1/h] transition from macrophage compartment 3 to 4 in steady state
par(I.phagoMP1)           	= primPar(primI.foldPhagoMP1)*primPar(primI.phagoMP4);	% [] phagocytic activity of P1 macrophages, relative to dendritic cells
par(I.phagoMP2)            	= primPar(primI.foldPhagoMP2)*primPar(primI.phagoMP4);	% [] phagocytic activity of P2 macrophages, relative to dendritic cells
par(I.phagoMP3)            	= primPar(primI.foldPhagoMP3)*primPar(primI.phagoMP4);	% [] phagocytic activity of P3 macrophages, relative to dendritic cells
par(I.phagoMP4)           	= primPar(primI.phagoMP4);                           	% [] phagocytic activity of P4 macrophages, relative to dendritic cells
par(I.lambdaMmax)           = primPar(primI.lambdaMax);                             % [1/(mL*h)] maximal macrophage inflow into LP
par(I.HillRecM)             = primPar(primI.HillRec);                            	% [] Hill factor for macrophage recruitment by pro-inflammatory cells
par(I.cRecM)                = par(I.muM)*auxPar(auxI.concM_LP)...
    *primPar(primI.facRecM);                                                        % [1/(mL*h)] constant macrophage inflow into LP
par(I.nuMphago)             = primPar(primI.nuMphago);                              % [] fraction of macrophages that move to anti-inflammatory state after phagocytosis of one apoptotic neutrophil
par(I.HillProActM)        	= primPar(primI.HillAct);                              	% [] Hill factor for macrophage transition inhibition by pro-inflammatory cytokines
par(I.HillAntiActM)       	= primPar(primI.HillAct);                               % [] Hill factor for macrophage transition stimulation by anti-inflammatory cytokines

%% Neutrophils
par(I.lambdaNeutMax)        = primPar(primI.lambdaNeutMax);                      	% [1/(mL*h)] maximal neutrophil inflow into LP
par(I.wProLPBact)         	= primPar(primI.wProLPBact);                          	% [mL^(hill-1)] weight for bacteria concentration in neutrophil recruitment
par(I.HillRecNeut)          = primPar(primI.HillRec);                             	% [] Hill factor for neutrophil recruitment
par(I.muNeutc)              = primPar(primI.muNeutc);                               % [1/h] constitutive/spontaneous neutrophil apoptosis
par(I.muNeutPhago)       	= primPar(primI.muNeutPhago);                       	% [] proportion of neutrophils undergoing apoptosis following phagocytosis of one bacterial cell
par(I.muNeutMax)            = primPar(primI.muNeutMax);                             % [1/h] maximal neutrophil apoptosis, stimulated by SPM
par(I.muAponeut)            = primPar(primI.muAponeut);                             % [1/h] necrosis of apoptotic neutrophils

%% Bacteria in lumen
par(I.pBactLu)              = primPar(primI.kBact)*primPar(primI.foldpBactLu);      % [1/h] proliferation of bacteria in lumen
par(I.muBactLu)             = primPar(primI.kBact);                                 % [1/h] death of bacteria in lumen
par(I.lambdaNutrients)      = primPar(primI.kBact);                                 % [1/h] inflow of nutrients

%% Mucus & epithelial barrier
par(I.epsilonBact1)         = primPar(primI.epsilonBact1);                          % [1/(mL*h)] inflow of bacteria without toxin
par(I.epsilonBact2)         = primPar(primI.epsilonBact2);                          % [1/(mL*h)] inflow of bacteria with toxin
par(I.muEpi)                = log(2)/(primPar(primI.hlEpi)*24);                   	% [1/h] degradation of epithelium
par(I.ssEpi)                = primPar(primI.ssEpi);                                 % [] steady state value of epithelium
par(I.muEpiBact)            = primPar(primI.muEpiBact);                             % [mL] destruction of epithelium by bacteria with toxin
par(I.muEpiFac)             = primPar(primI.muEpiFac);                              % [] maximal relative increase of epithelium degradation
par(I.muMucus)              = log(2)/primPar(primI.hlMucus);                        % [1/h] degradation of mucus layer
par(I.ssMucus)              = primPar(primI.ssMucus);                           	% [] steady state value of mucus
par(I.muTis)                = log(2)/(primPar(primI.hlTis)*24);                     % [1/h] degradation of tissue
par(I.ssTis)                = primPar(primI.ssTis);                                 % [] steady state value of tissue
par(I.muTisFac)             = primPar(primI.muTisFac);                              % [] maximal relative increase of tissue degradation
par(I.epsilonFCP)           = primPar(primI.epsilonFCP);                            % [mL*ug/(h*g)] outflow of neutrophils (FCP) into lumen
par(I.muFCP)                = 1/primPar(primI.ctt);                                 % [1/h] outflow of FCP from lumen

%% Weights for phagocytosis
% --> relative to neutrophils (weight Neut = 1)
par(I.wPhagoLPqDC)          = primPar(primI.wPhagoLPqDC);
par(I.wPhagoLPrDC)          = primPar(primI.wPhagoLPrDC);
par(I.wPhagoLPtDC)          = primPar(primI.wPhagoLPtDC);
par(I.wPhagoLPsDC)          = primPar(primI.wPhagoLPsDC);
par(I.wPhagoLPMP1)          = primPar(primI.wPhagoLPMP1);
par(I.wPhagoLPMP2)          = primPar(primI.wPhagoLPMP2);
par(I.wPhagoLPMP3)          = primPar(primI.wPhagoLPMP3);
par(I.wPhagoLPMP4)          = primPar(primI.wPhagoLPMP4);
par(I.wPhagoLPNeut)         = primPar(primI.wPhagoLPNeut);

%% Weights for cytokine production
par(I.wcyto_RecNeut_Th1)    = primPar(primI.wcyto_RecNeut_Th1);
par(I.wcyto_RecNeut_Th17)   = primPar(primI.wcyto_RecNeut_Th17);
par(I.wcyto_RecNeut_Neut)   = primPar(primI.wcyto_RecNeut_Neut);
par(I.wcyto_RecNeut_M)      = primPar(primI.wcyto_RecNeut_M);
par(I.wcyto_RecM_Th1)       = primPar(primI.wcyto_RecM_Th1);
par(I.wcyto_RecM_Th17)      = primPar(primI.wcyto_RecM_Th17);
par(I.wcyto_RecM_Neut)      = primPar(primI.wcyto_RecM_Neut);
par(I.wcyto_RecM_M)         = primPar(primI.wcyto_RecM_M);
par(I.wcyto_ActM_Th1)       = primPar(primI.wcyto_ActM_Th1);
par(I.wcyto_ActM_Th17)      = primPar(primI.wcyto_ActM_Th17);
par(I.wcyto_ActM_Neut)      = primPar(primI.wcyto_ActM_Neut);
par(I.wcyto_ActM_M)         = primPar(primI.wcyto_ActM_M);
par(I.wcyto_ActDC_Th1)      = primPar(primI.wcyto_ActDC_Th1);
par(I.wcyto_ActDC_Th17)     = primPar(primI.wcyto_ActDC_Th17);
par(I.wcyto_ActDC_Neut)     = primPar(primI.wcyto_ActDC_Neut);
par(I.wcyto_ActDC_M)        = primPar(primI.wcyto_ActDC_M);
par(I.wcyto_DeactM_Treg)    = primPar(primI.wcyto_DeactM_Treg);
par(I.wcyto_DeactM_Th2)     = primPar(primI.wcyto_DeactM_Th2);
par(I.wcyto_DeactM_M)       = primPar(primI.wcyto_DeactM_M);
par(I.wcyto_DeactDC_Treg)   = primPar(primI.wcyto_DeactDC_Treg);
par(I.wcyto_DeactDC_Th2)    = primPar(primI.wcyto_DeactDC_Th2);
par(I.wcyto_DeactDC_M)      = primPar(primI.wcyto_DeactDC_M);
par(I.wcyto_DamageEpi_Th1) 	= primPar(primI.wcyto_DamageEpi_Th1);
par(I.wcyto_DamageEpi_Th17)	= primPar(primI.wcyto_DamageEpi_Th17);
par(I.wcyto_DamageEpi_Th2)	= primPar(primI.wcyto_DamageEpi_Th2);
par(I.wcyto_DamageEpi_Neut)	= primPar(primI.wcyto_DamageEpi_Neut);
par(I.wcyto_DamageEpi_M)  	= primPar(primI.wcyto_DamageEpi_M);
par(I.wcyto_DamageTis_Th1) 	= primPar(primI.wcyto_DamageTis_Th1);
par(I.wcyto_DamageTis_Th17)	= primPar(primI.wcyto_DamageTis_Th17);
par(I.wcyto_DamageTis_Th2)	= primPar(primI.wcyto_DamageTis_Th2);
par(I.wcyto_DamageTis_Neut)	= primPar(primI.wcyto_DamageTis_Neut);
par(I.wcyto_DamageTis_M)  	= primPar(primI.wcyto_DamageTis_M);
par(I.wcyto_TisRemod_Th2)   = primPar(primI.wcyto_TisRemod_Th2);
par(I.wcyto_TisRemod_M)     = primPar(primI.wcyto_TisRemod_M);

%% Weights of specialised pro-resolving mediator production
% --> relative to neutrophils (weight Neut = 1)
par(I.wSPMLPNeut)           = primPar(primI.wSPMLPNeut);
par(I.wSPMLPMeffero)        = primPar(primI.wSPMLPMeffero);

%--------------------------------------------------------------------------
%% Test if all parameters are assigned
if any(isnan(par))
    fprintf(2,'The following parameters are not assigned: %s.\n',strjoin(model.I.parName(isnan(par)),' '));
end

%--------------------------------------------------------------------------

end