function f = IBD_plotIRindices(IR,tstarValues,model,N,inset,tikz,ax)
%==========================================================================
% f = IBD_plotIRindices(IR,individual,inset)
%==========================================================================
% Plot highest IR indices over time
%--------------------------------------------------------------------------
%-- input
% IR:           input-response indices
% individual:	model information struct
% N:            number of IR indices to plot
% inset:        inset limits
%               [] (no inset) | [xlim(1) xlim(2)] | [xlim(1) xlim(2) ylim(1) ylim(2)]
% tikz:         true/false
% ax:           (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output
% f:            figure
%--------------------------------------------------------------------------
%-- sources:
% -
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

if ~exist('inset','var')
    inset = [];
end

I = model.I;

%--------------------------------------------------------------------------
% Divide states into subprocesses (cell types)
stateNames      = I.stateName(1:I.nrOfStates);
[stateAnnot] 	= IBD_annotateStates(stateNames);

% Plot per process
processes       = unique(stateAnnot);

%--------------------------------------------------------------------------

if exist('tikz','var') && tikz
    printName   = IBD_translateToLatexCommands(model.I.stateName,true);
else
    printName   = model.assignPrintName(model.I);
end

lineSpec    = repmat({'-','--',':','-.'},[1 10]);

if ~exist('ax','var') || isempty(ax)
    f = figure;
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

%--------------------------------------------------------------------------
[~,idx]	= sort(max(IR),'descend');
colours	= IBD_colourMap('dark rainbow',N+1);

for i = 1:N
    plot(ax,tstarValues/24,IR(:,idx(i)),'Color',colours(i,:),'LineStyle',lineSpec{I.stateBact(idx(i))});
end

% Legend
if exist('tikz','var') && tikz
    legend(ax,printName(idx(1:N)),'Location','eastoutside','Interpreter','latex')
else
    legend(ax,printName(idx(1:N)),'Location','eastoutside')
end

legend boxoff
xlabel(ax,'Time [days]')
ylabel(ax,'IR index')

% Inset
if ~isempty(inset)
    ax2 = axes('Position',[.3 .4 .35 .5]);
    hold on
    box on
    for i = 1:N
        plot(ax2,tstarValues/24,IR(:,idx(i)),'Color',colours(i,:),'LineStyle',lineSpec{I.stateBact(idx(i))});
    end
    xlim(ax2,inset(1:2));
    if length(inset)==4
        ylim(ax2,inset(3:4))
    end
end

if makeFigure
    f = IBD_nicePlot(f);
    f.CurrentAxes = f.Children(end);
else
    f = nan;
end

%--------------------------------------------------------------------------