function f = IBD_plotIndividuals(individual,p,split,MQ)
%==========================================================================
% f = IBD_plotIndividuals(individual,p,split)
%==========================================================================
% Plot results from different individuals
%--------------------------------------------------------------------------
%-- input
% individual:	model information struct
% p:            struct of plot specifications
% split:        vector with one entry per individual, specifying to which
%               row this individual is to be plotted, alternatively:
%               1 --> split all individuals
%               0 --> do not split, plot all individuals together
% MQ:           true/false: mean & quantiles provided as individuals
%--------------------------------------------------------------------------
%-- output
% f:            figure
%--------------------------------------------------------------------------
%-- sources:
% -
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

% Split vector
if ~exist('split','var') || (length(split)==1 && split==1)
    split = 1:length(individual);
elseif length(split)==1 && split==0
    split = ones([length(individual),1]);
elseif length(split)~=length(individual)
    error('Split vector must have one entry per individual.')
end

% Mean and quantiles provided
if ~exist('MQ','var')
    MQ = false;
end
if MQ
    assert(mod(length(individual),3)==0,'Provide median, q5, q95 for each plot.')
    for i = 1:max(split)
        assert(sum(split==i)==3,'Provide median, q5, q95 for each plot.')
    end
end

% Replace missing numbers in split vector (to avoid empty rows)
a = sort(unique(split));
b = 1:length(a);
for i = 1:length(a)
    split(split==a(i)) = b(i);
end
clear a b i

thresholdPerPlot = 20;   % maximal number of individuals per plot - otherwise mean + 90% PI

% Rows:     individuals
% Columns:  different plots
n   = length(p);
m   = max(split);
sp  = gobjects(m,n);     % graphics handle to store subplot handles in the right order

% General
lineSpec    = repmat({'-','--',':','-.'},[1 10]);

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

titles = {};    % row titles

%--------------------------------------------------------------------------
%% Plots

% Rows
for s = 1:m
    idx_s  	= find(split==s);
    
    % Mean and 90% PI intervals (if too many individuals per plot)
    if length(idx_s) > thresholdPerPlot
        fprintf('Averaging individuals...')
        tic_mean = tic;
        idx_s  	= find(split==s);
        allX  	= zeros([size(individual(idx_s(1)).Xadd),length(idx_s)]);
        allA  	= zeros([size(individual(idx_s(1)).A),length(idx_s)]);
        for idx = 1:length(idx_s)
            ind = idx_s(idx);
            if size(individual(ind).Xadd,1) ~= size(individual(idx_s(1)).Xadd,1) || size(individual(ind).Xadd,2) ~= size(individual(idx_s(1)).Xadd,2)
                error('For plots of mean and 90% prediction intervals, the simulation time points and indices need to be identical between individuals.')
            end
            allX(:,:,idx)	= individual(ind).Xadd;
            allA(:,:,idx)   = individual(ind).A;
        end
        Xadd_median	= median(allX,3);
        Xadd_q5 	= quantile(allX,0.05,3);
        Xadd_q95    = quantile(allX,0.95,3);
        A_mean    	= mean(allA,3);
        A_q5        = quantile(allA,0.05,3);
        A_q95       = quantile(allA,0.95,3);
        plotMean    = true;
        fprintf(' took %.1f s.\n',toc(tic_mean));
        titles{s}   = ['N = ',int2str(length(idx_s))];
    elseif MQ
        Xadd_median = individual(idx_s(1)).Xadd;
        Xadd_q5     = individual(idx_s(2)).Xadd;
        Xadd_q95    = individual(idx_s(3)).Xadd;
        plotMean    = true;
        titles{s}   = individual(idx_s(1)).title;
        plotMean    = true;
    else
        plotMean    = false;
        titles{s}   = individual(idx_s(1)).title;
    end
    
    % Columns
    for i = 1:length(p)
        
        % Colours
        if ~isempty(p(i).colourMap)
            colours     = p(i).colourMap;
        else
            colours     = IBD_colourMap('dark rainbow',8);
        end
        
        % Subplot
        sp(s,i) = subplot(m,n,(s-1)*n+i);
        hold on
        
        % Save legend
        legendArray = {};
        
        % Bacteria (specific for each state)
        if isempty(p(i).Bact) || ~iscell(p(i).Bact{1})
            p(i).Bact = repmat({p(i).Bact},[1 length(p(i).states)+length(p(i).rates)]);
        end
        
        % Time: x axis
        switch p(i).xunit
            case {'h','hour','hours'}
                timeUnit    = 'h';
                unitFac     = 1;
            case {'min','minute','minutes'}
                timeUnit    = 'min';
                unitFac     = 60;
            case {'d','day','days'}
                timeUnit    = 'days';
                unitFac     = 1/24;
            case {'w','week','weeks'}
                timeUnit 	= 'weeks';
                unitFac     = 1/24/7; 
            otherwise
                warning('Specified time unit not implemented. Result shown in h.')
                timeUnit    = 'h';
                unitFac     = 1;
        end
        p(i).unitFac = unitFac;
        
        if isempty(p(i).xlim)
            p(i).xlim = [0 individual(idx_s(1)).T(end)];
        end
        xlimits = p(i).xlim*unitFac;
        xlinevalues = p(i).xline*unitFac;
        
        %------------------------------------------------------------------
        % States over time
        for j = 1:length(p(i).states)
            S       = p(i).states{j};
            Bact    = p(i).Bact{j};
            
            if plotMean
                % Mean + PI
                if MQ && isfield(individual(idx_s(1)),'Ired')
                    I = individual(idx_s(1)).Ired;
                else
                    I = individual(idx_s(1)).I;
                end
                T = [-(p(i).xlim(end)-p(i).xlim(1))/p(i).minusFactor+p(i).xlim(1);individual(idx_s(1)).T]*unitFac;
                
                % Prepare data to plot (sum over states, Bact, transit; normalisation to max/start value)
                X_mean  = prepareStatesToPlot(Xadd_median,S,Bact,I,p(i));
                X_q5    = prepareStatesToPlot(Xadd_q5,S,Bact,I,p(i));
                X_q95   = prepareStatesToPlot(Xadd_q95,S,Bact,I,p(i));
                
                % Plot
                for k = 1:size(X_mean,2)
                    
                    % Mean
                    if p(i).log
                        h = semilogy(T,X_mean(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle','-');
                    else
                        h = plot(T,X_mean(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle','-');
                    end
                    if k>1     % display only once in legend/exclude for k>=2
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    end
                    
                    % Prediction interval
                    h = fill([T' fliplr(T')], [X_q95(:,k)' fliplr(X_q5(:,k)')], colours(j,:),'FaceAlpha',p(1).alpha,'EdgeColor','none');
                    h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    if p(1).q5q95line
                        h = plot(T,X_q5,'LineWidth',p(i).lwd/2,'Color',colours(j,:),'LineStyle','--');
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                        h = plot(T,X_q95,'LineWidth',p(i).lwd/2,'Color',colours(j,:),'LineStyle','--');
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    end
                end
                
            else
                % Single individuals
                for ind_x = 1:length(idx_s)
                    ind = idx_s(ind_x);
                    
                    Xadd    = individual(ind).Xadd;
                    I       = individual(ind).I;
                    T       = [-(p(i).xlim(end)-p(i).xlim(1))/p(i).minusFactor+p(i).xlim(1);individual(ind).T]*unitFac;
                    
                    % Prepare data to plot (sum over states, Bact, transit; normalisation to max/start value)
                    Xplot   = prepareStatesToPlot(Xadd,S,Bact,I,p(i));
                    
                    % Plot
                    for k = 1:size(Xplot,2)
                        if isfield(individual(ind),'linespec')
                            thisLineSpec = individual(ind).linespec;
                        else
                            thisLineSpec = lineSpec{k};
                        end
                        
                        if p(i).log
                            h = semilogy(T,Xplot(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle',thisLineSpec);
                        else
                            h = plot(T,Xplot(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle',thisLineSpec);
                        end
                        if k>1     % display only once in legend/exclude for k>=2
                            h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                        end
                    end
                end
            end
            
            % X and Y label
            if ~strcmp(p(i).xlabel,'none')
                if isempty(p(i).xlabel)
                    xlabel(['Time [',timeUnit,']']);
                else
                    xlabel(p(i).xlabel);
                end
            end
            if ~strcmp(p(i).ylabel,'none')
                if isempty(p(i).ylabel)
                    ylabel('Concentration [1/mL]');
                else
                    ylabel(p(i).ylabel);
                end
            end
            
            % Legend
            if MQ
                printName   = individual(idx_s(1)).assignPrintName(individual(idx_s(1)).Ired);
            else
                printName   = individual(idx_s(1)).assignPrintName(individual(idx_s(1)).I);
            end
            if ~iscell(S)
                printName_tmp = printName(I.(S));
            else
                printName_tmp = {strjoin(cellfun(@(s) printName(I.(s)(1)),S),' + ')};
            end
            legendArray = [legendArray printName_tmp{1}];
            
        end
        
        %------------------------------------------------------------------
        % Reaction rates over time
        % as for states
        for j = 1:length(p(i).rates)
            S       = p(i).rates(j);
            Bact    = p(i).Bact{j};
            
            if plotMean
                % Mean + PI
                I = individual(idx_s(1)).I;
                T = [-(p(i).xlim(end)-p(i).xlim(1))/p(i).minusFactor+p(i).xlim(1);individual(idx_s(1)).T]*unitFac;
                
                % Prepare data to plot (sum over states, Bact; normalisation to max/start value)
                X_mean  = prepareRatesToPlot(A_mean,S,Bact,I,p(i),I.nrOfRct,I.nrOfBact);
                X_q5    = prepareRatesToPlot(A_q5,S,Bact,I,p(i),I.nrOfRct,I.nrOfBact);
                X_q95   = prepareRatesToPlot(A_q95,S,Bact,I,p(i),I.nrOfRct,I.nrOfBact);
                
                % Plot
                for k = 1:size(X_mean,2)
                    
                    % Mean
                    if p(i).log
                        h = semilogy(T,X_mean(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle','-');
                    else
                        h = plot(T,X_mean(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle','-');
                    end
                    if k>1     % display only once in legend/exclude for k>=2
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    end
                    
                    % Prediction interval
                    h = fill([T' fliplr(T')], [X_q95(:,k)' fliplr(X_q5(:,k)')], colours(j,:),'FaceAlpha',p(1).alpha,'EdgeColor','none');
                    h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    if p(1).q5q95line
                        h = plot(T,X_q5,'LineWidth',p(i).lwd/2,'Color',colours(j,:),'LineStyle','--');
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                        h = plot(T,X_q95,'LineWidth',p(i).lwd/2,'Color',colours(j,:),'LineStyle','--');
                        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                    end
                end
                
            else
                % Single individuals
                for ind = idx_s
                    
                    A       = individual(ind).A;
                    I       = individual(ind).I;
                    T       = [-(p(i).xlim(end)-p(i).xlim(1))/p(i).minusFactor+p(i).xlim(1);individual(ind).T]*unitFac;
                    
                    % Prepare data to plot (sum over states, Bact; normalisation to max/start value)
                    Xplot   = prepareRatesToPlot(A,S,Bact,I,p(i),individual(ind).nrOfRct,I.nrOfBact);
                    
                    % Plot
                    for k = 1:size(Xplot,2)
                        if isfield(individual(ind),'linespec')
                            thisLineSpec = individual(ind).linespec;
                        else
                            thisLineSpec = lineSpec{k};
                        end
                        if p(i).log
                            h = semilogy(T,Xplot(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle',thisLineSpec);
                        else
                            h = plot(T,Xplot(:,k),'Linewidth',p(i).lwd,'Color',colours(j,:),'LineStyle',thisLineSpec);
                        end
                        if k>1     % display only once in legend/exclude for k>=2
                            h.Annotation.LegendInformation.IconDisplayStyle = 'off';
                        end
                    end
                end
            end
            
            % X and Y label
            if ~strcmp(p(i).xlabel,'none')
                if isempty(p(i).xlabel)
                    xlabel(['Time [',timeUnit,']']);
                else
                    xlabel(p(i).xlabel);
                end
            end
            if ~strcmp(p(i).ylabel,'none')
                if isempty(p(i).ylabel)
                    ylabel('Reaction rate [1/(mL*h)]');
                else
                    ylabel(p(i).ylabel);
                end
            end
            
            % Legend
            legendArray = [legendArray sprintf('Reaction nr %i',S)];
            
        end
        
        %------------------------------------------------------------------
        % Rectangle (to draw attention to or zoom in specific part)
        if length(p(i).rectangle) == 4
            p(i).rectangle([1 3]) = p(i).rectangle([1 3])*unitFac;
            if p(i).rectangle(1) == 0
                p(i).rectangle(1) = T(1);
                p(i).rectangle(3) = p(i).rectangle(3)-T(1);
            end
            rectangle('Position',p(i).rectangle,'EdgeColor',[0.4 0.4 0.4],'LineWidth',p(i).lwd-1)
        end
        
        %----------------------------------------------------------------------
        % Legend
        if p(i).showLegend
            if p(i).tikz
                interpreter = 'latex';
                if isempty(p(i).tikzLegend)
                    thisLegend = p(i).legend;
                else
                    thisLegend	= p(i).tikzLegend;
                end
            else
                interpreter = 'tex';
                thisLegend	= p(i).legend;
            end
            if isempty(thisLegend)
                legend(legendArray,'Location',p(i).legendPos,'Interpreter',interpreter)
            else
                legend(thisLegend,'Location',p(i).legendPos,'Interpreter',interpreter)
            end
        end

        if p(i).grid
            grid on
        else
            grid off
        end
        
        % x/y lines
        if length(xlinevalues) == 1
            h = xline(xlinevalues,'Color',[0.4 0.4 0.4],'LineWidth',p(i).lwd);
            h.Annotation.LegendInformation.IconDisplayStyle = 'off';
        end
        if length(p(i).yline) == 1
            h = yline(p(i).yline,'Color',p(i).ylineCol,'LineWidth',p(i).lwd,'LineStyle',p(i).ylineLineStyle);
            h.Annotation.LegendInformation.IconDisplayStyle = 'off';
        end
        
        % Axis limits
        if length(xlimits) == 2
            xlim([-(xlimits(end)-xlimits(1))/p(i).minusFactor+xlimits(1) xlimits(end)])
        end
        if length(p(i).ylim) == 2
            ylim(p(i).ylim)
        elseif length(p(i).ylim) == 1
            ylim([0 p(i).ylim])
        end

        % Font size, line width, title
        set(gca,'FontSize',p(i).fontsize)
        if ~isempty(p(i).zValues) && p(i).log
            ax = gca;
            ax.XTickLabels = cellstr(num2str(ax.XTick(:),'10^{%.1d}'));
            ax.YTickLabels = cellstr(num2str(ax.YTick(:),'10^{%.1d}'));
        end
        set(gca,'LineWidth',p(i).lwd-1)

        set(gca,'TickDir','out')

        box off
        
    end
    
end

% Link axes, Titles
for i = 1:size(sp,2)
    if ~isempty(setdiff(1:size(sp,1),p(i).noLink))
        linkaxes(sp(setdiff(1:size(sp,1),p(i).noLink),i));
    end
    if ~isempty(p(i).main)
        a = subplot(m,n,i);
        yl = sp(1,i).YLim;
        xl = sp(1,i).XLim;
        switch p(i).titlePos
            case 'center'
                xpos = xl(2)/2;
            case 'left'
                xpos = xl(1);
            case 'right'
                xpos = xl(2);
        end
        if isempty(p(i).titleUp)
            xup = 1.22;
            % Check if 10^xx --> other factor
            if sp(1,i).YAxis.Exponent==0
                xup = 1.15;
            end
        else
            xup = p(i).titleUp;
        end
        title(sp(1,i),p(i).main);
        if p(i).tikz
            title(sp(1,i),p(i).main,'HorizontalAlignment',p(i).titlePos,'Position',[xpos (yl(2)-yl(1))*1.1+yl(1) 0]);
            if p(i).tikz
                text(sp(1,i),xpos,(yl(2)-yl(1))*xup+yl(1),regexprep(p(i).main,'  ','\\ \\ '),'HorizontalAlignment',p(i).titlePos,'FontSize',a.Title.FontSize,'FontWeight',a.Title.FontWeight,'Interpreter','latex')
            else
                text(sp(1,i),xpos,(yl(2)-yl(1))*xup+yl(1),regexprep(p(i).main,'  ','\\ \\ '),'HorizontalAlignment',p(i).titlePos,'FontSize',a.Title.FontSize,'FontWeight',a.Title.FontWeight)
            end
            title(sp(1,i),'')
        end
    end
end

% Filled background (e.g. for treatment)
for i = 1:size(sp,1)
    for j = 1:size(sp,2)
        yl = sp(i,j).YLim;
        if length(p(j).background)==2
            h = fill(sp(i,j),p(j).background([1 2 2 1])*p(j).unitFac,yl([1 1 2 2]),p(j).backgroundCol,'EdgeColor','none','FaceAlpha',p(1).alpha,'EdgeAlpha',0.3);
            uistack(h,'bottom')
            h.Annotation.LegendInformation.IconDisplayStyle = 'off';
        end
    end
end

% Rows/columns: titles, axis labels, legends
% Titles for rows
for s = 1:size(sp,1)
    yl = sp(s,end).YLim;
    xl = sp(s,end).XLim;
    text(sp(s,end),xl(2)*1.1,(yl(1)+yl(2))/2,titles{s},'HorizontalAlignment','center','Rotation',270,'FontSize',sp(s,end).Title.FontSize,'FontWeight',sp(s,end).Title.FontWeight)
end
% Remove x-labels for all but last row
for rows = 1:size(sp,1)-1
    for cols = 1:size(sp,2)
        xlabel(sp(rows,cols),'');
    end
end
% Remove x tick labels for all but last row
if p(1).removeXticks
    for rows = 1:size(sp,1)-1
        for cols = 1:size(sp,2)
            set(sp(rows,cols), 'XTickLabel', [])
        end
    end
end
% Remove y-labels for all but first column
for rows = 1:size(sp,1)
    for cols = 2:size(sp,2)
        ylabel(sp(rows,cols),'');
    end
end
% Remove legend in all but first (/user-specified) row
% User-specified row can also be a vector or 'all'
if strcmp(p(1).legendRow,'all')
    p(1).legendRow = 1:m;
end
if strcmp(p(1).legendRow,'none')
    p(1).legendRow = [];
end
for rows = setdiff(1:size(sp,1),p(1).legendRow)
    for cols = 1:size(sp,2)
        legend(sp(rows,cols),'hide');
    end
end

%--------------------------------------------------------------------------
% Move created figures into edges of screen
switch f.Number
    case 1
        pos = 'northwest';
    case 2
        pos = 'north';
    case 3
        pos = 'northeast';
    case 4
        pos = 'west';
    case 5
        pos = 'center';
    case 6
        pos = 'east';
    case 7
        pos = 'southwest';
    case 8
        pos = 'south';
    case 9
        pos = 'southeast';
    otherwise
        pos = 'center';
end
movegui(f,pos);

end


%==========================================================================
% Local functions
function Xplot = prepareStatesToPlot(Xadd,S,Bact,I,pi)
    
    % Sum over states and Bact and transit
    if iscell(S)
        Xplot = zeros(size(Xadd,1),1);
        for state = 1:length(S)
            Xplot = Xplot+sum(Xadd(:,I.(S{state})),2);      % 1 column
        end
    else
        % Sum over Bact and transit
        if isempty(Bact) && ~pi.transit
            Xplot = sum(Xadd(:,I.(S)),2);                   % 1 column
        % Sum over Bact but not transit
        elseif isempty(Bact) && pi.transit
            Xplot = [];
            for kx = 1:size(I.(S),2) % for each transit
                Xplot(:,kx) = sum(Xadd(:,I.(S)(:,kx)),2);   % sum over Bact
            end
        % Sum over transit but not Bact
        elseif ~isempty(Bact) && pi.transit
            Xplot = [];
            intersectBact = intersect(Bact,I.bactName,'stable');
            for kxx = 1:length(intersectBact)
                kx = I.(intersectBact{kxx});
                Xplot(:,kxx) = sum(Xadd(:,I.(S)(kx,:)),2);   % sum over transit
            end
        else
        % No summing
            if isfield(I,'bactName') && size(I.(S),1)==length(I.bactName)    % bacteria-specific state variable
                intersectBact = intersect(Bact,I.bactName,'stable');
                Bact_I = [];
                for kxx = 1:length(intersectBact)
                    kx = I.(intersectBact{kxx});
                    Bact_I = [Bact_I,kx];
                end
                Xplot = Xadd(:,I.(S)(Bact_I,:));
            else
                Xplot = Xadd(:,I.(S));
            end
            
        end
        
    end
    
    % Normalisation to max/start value
    if pi.normMax
        for kx = 1:size(Xplot,2)
            Xplot(:,kx) = Xplot(:,kx)/max(Xplot(:,kx));
        end
    end
    if pi.norm0
        Xplot = Xplot./Xplot(1,:);
    end
    
    % Add first line to match T
    Xplot = [Xplot(1,:);Xplot];

end

%--------------------------------------------------------------------------
function Xplot = prepareRatesToPlot(A,S,Bact,I,pi,nrOfRct,nrOfBact)
    A = A(:,S+nrOfRct*(0:nrOfBact-1));
    % Sum over Bact
    if isempty(Bact)
      	Xplot = sum(A,2);
    else
        % All Bact separately
        intersectBact = intersect(Bact,I.bactName,'stable');
        for kxx = 1:length(intersectBact)
            kx = I.(intersectBact{kxx});
            Xplot(:,kxx) = A(:,kx);
        end
    end
    
    % Normalisation to max/start value
    if pi.normMax
        for kx = 1:size(Xplot,2)
            Xplot(:,kx) = Xplot(:,kx)/max(Xplot(:,kx));
        end
    end
    if pi.norm0
        Xplot = Xplot./Xplot(1,:);
    end
    
    % Add first line to match T
    Xplot = [Xplot(1,:);Xplot];

end



