function [f,LSA] = IBD_plotLSA(LSA,model,output,plotIdx,absolute,tikz,ax)
%==========================================================================
% [f,LSA] = IBD_plotLSA(LSA,model,output,plotIdx,absolute,tikz,ax)
%==========================================================================
% Plot sensitivities of local sensitivity analysis
%--------------------------------------------------------------------------
%-- input
% LSA:         	LSA result table
% output:       which output to plot
% absolute: 	true/false
% tikz:         true/false
% ax:           (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output
% f:            figure
% LSA:          LSA result table
%--------------------------------------------------------------------------
%-- sources:
% -
%--------------------------------------------------------------------------
%-- dependencies:
% none
%==========================================================================

if ~exist('absolute','var')
    absolute = false;
end

LSA = LSA(strcmp(LSA.output,output),:);

%--------------------------------------------------------------------------
% Sort rows based on sensitivity
LSA.absS = abs(LSA.S);
LSA = sortrows(LSA,'absS','descend','MissingPlacement','last');
LSA.uniquePar = LSA.par;
LSA.uniquePar(~strcmp('commensal',LSA.bact)) = strcat(LSA.par(~strcmp('commensal',LSA.bact)),LSA.bact(~strcmp('commensal',LSA.bact)));
if exist('tikz','var') && tikz
    LSA.printName = IBD_translateToLatexCommands(LSA.par,true);
else
    LSA.printName = cellfun(@(s) regexprep(s,'_','\\_'),LSA.par,'UniformOutput',false);
    LSA.printName(~strcmp('commensal',LSA.bact)) = strcat(LSA.printName(~strcmp('commensal',LSA.bact)),{' ('},LSA.bact(~strcmp('commensal',LSA.bact)),{')'});
end

%--------------------------------------------------------------------------
% Plot
LSAx = LSA(plotIdx(end:-1:1),:);

if absolute
    LSAx.S = LSAx.absS;
end

% Colours according to processes
[parAnnot,colour]   = IBD_annotatePars(model.I.parName);
parAnnot            = parAnnot(LSAx.idx);
processes           = unique(parAnnot);

if ~exist('ax','var') || isempty(ax)
    f = figure;
    set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2, 0.6]);
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

% Divide parameters into processes
stacked = zeros(length(plotIdx),length(processes));
for p = 1:length(processes)
    thisStack   = zeros(length(plotIdx),1);
    thisProcess	= strcmp(parAnnot,processes{p});
    thisStack(thisProcess) = LSAx.S(thisProcess);
    stacked(:,p) = thisStack;
end
b = barh(ax,stacked,'stacked');
for p = 1:length(processes)
    b(p).FaceColor = colour.(processes{p});
    b(p).EdgeColor = colour.(processes{p});
end
yticks(ax,[])
yticklabels(ax,{})
box off
%ylabel('parameters')

if absolute
    xlabel(ax,'|sensitivity coefficient|')
else
    xlabel(ax,'sensitivity coefficient')
end

title(ax,output)

yticks(ax,plotIdx)
yticklabels(ax,LSAx.printName)
if exist('tikz','var') && tikz
    set(ax,'TickLabelInterpreter','latex')
end

% Change size of YTickLabels
yl = get(gca,'YLabel');
ylFontSize = get(yl,'FontSize');
yAX = get(gca,'YAxis');
set(yAX,'FontSize', ylFontSize/2)
set(yl, 'FontSize', ylFontSize);

if makeFigure
    f = IBD_nicePlot(f);
else
    f = nan;
end

%--------------------------------------------------------------------------
end






