function f = IBD_plotParDist(par,individual_ref,whichClasses,whichPars,options)
%==========================================================================
% f = IBD_plotParDist(par,individual_ref,whichClasses,whichPars,classDefinition,options)
%==========================================================================
% Plot distribution of parameters among different classes
%--------------------------------------------------------------------------
%-- input
% par:              struct of parameter values per class
% individual_ref:   reference individual
% whichClasses:     which classes to plot
% whichPars:        which parameters to plot
% options:          additional options
%--------------------------------------------------------------------------
%-- output
% f:                figure
%==========================================================================

if ~exist('options','var')
    options = struct;
end

nbins       = 20;

% Figure
if isfield(options,'ncolrow')
    n = options.ncolrow(1);
    m = options.ncolrow(2);
else
    [m,n] = IBD_getNrOfColsAndRows(length(whichPars),5,5);
end
sp          = gobjects(m,n);     % graphics handle to store subplot handles in the right order

f_counter   = 0;

parFieldNames = fieldnames(par);

if isfield(options,'colours')
    colours     = options.colours;
else
    colours     = IBD_colourMap('dark rainbow',length(parFieldNames)+1);
end

% Parameters or states?
if size(par.(parFieldNames{1}),1)==individual_ref.I.nrOfPar
    parName     = IBD_uniqueParName(individual_ref.I);
    parOrState  = 'par';
else
    parName     = IBD_uniqueStateName(individual_ref.I);
    parOrState  = 'state';
end

par_original = par;

% Plot per parameter
for i = 1:length(whichPars)
    
    % Subplot/new figure
    if mod(i,m*n)==1
        if f_counter>0
            % Make previous figure nice
            f(f_counter) = IBD_nicePlot(f(f_counter));
        end
        f_counter = f_counter+1;
        f(f_counter) = figure;
        set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);
        
        sp(1,1) = subplot(m,n,1);
    else
        sp(ceil(i/n),mod(i-1,n)+1) = subplot(m,n,i-(f_counter-1)*m*n);
    end
    
    legendArray = {};
    
    hold on
    
    % Remove outliers
    allPar = [];
    for c = 1:length(whichClasses)
        allPar = [allPar,par.(whichClasses{c})(whichPars(i),:)];
    end
    if isfield(options,'threshold')
        threshold = quantile(allPar,options.threshold(i))*1.5;
    else
        threshold = quantile(allPar,0.95)*1.5;
    end
    for c = 1:length(whichClasses)
        thisPar = par.(whichClasses{c})(whichPars(i),:);
        thisPar(thisPar>threshold) = nan;
        par.(whichClasses{c})(whichPars(i),:) = thisPar;
    end
    max(thisPar)
    
    % Bins
    allPar = [];
    for c = 1:length(whichClasses)
        allPar = [allPar,par.(whichClasses{c})(whichPars(i),:)];
    end
    [~,edges] = histcounts(allPar,nbins);
    
    % Histograms
    if isfield(options,'density') && options.density
        all_fi = [];
        for c = 1:length(whichClasses)
            [fi{c},xi{c}] = ksdensity(par.(whichClasses{c})(whichPars(i),:));
            all_fi = [all_fi,fi{c}];
        end
        for c = 1:length(whichClasses)
            if isfield(options,'removeYTicks') && options.removeYTicks
                fi{c} = fi{c}/max(all_fi);
            end
            plot(xi{c},fi{c},'Color',colours(c,:))
            legendArray = [legendArray,strrep(whichClasses{c},'_',' ')];
        end
    else
        for c = 1:length(whichClasses)
            histogram(par.(whichClasses{c})(whichPars(i),:),edges,'EdgeColor',colours(c,:),'FaceColor',colours(c,:),'FaceAlpha',0.3,'Normalization','probability');
            legendArray = [legendArray,strrep(whichClasses{c},'_',' ')];
        end
    end
    
    % Median
    for c = 1:length(whichClasses)
        h = xline(median(par_original.(whichClasses{c})(whichPars(i),:),'omitnan'),'Color',colours(c,:));
        set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
    end
    
    % Reference parameter
    if ~isfield(options,'plotReference') || options.plotReference
        switch parOrState
            case 'par'
                h = xline(individual_ref.par(whichPars(i)),'Color',[0 0 0]);
                set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
            case 'state'
                h = xline(individual_ref.Xadd_ss(whichPars(i)),'Color',[0 0 0]);
                set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
        end
    end
    
    if i==1 && ~(isfield(options,'removeLegend') && options.removeLegend) % legend only in first plot
        legend(legendArray)
    end
    
%     if isfield(options,'moveExponent') && options.moveExponent
%         hAxes = gca;
%         if (hAxes.XRuler.Exponent ~=0)
%             set(hAxes.XRuler.SecondaryLabel, 'String','', 'FontAngle','italic', 'Visible','on');
%             xl = xlim;
%             yl = ylim;
%             text(xl(2)*1,yl(2)*0,['\cdot 10^{',int2str(hAxes.XRuler.Exponent),'}'],'HorizontalAlignment','right','VerticalAlignment','bottom')
%         end
%     end
    
    ax = gca;
    ax.YLim(1) = 0;
    
    % Axis labels, title
    xlabel('parameter value')
    ylabel('density')
    if isfield(options,'title')
        title(options.title{i},'Interpreter',options.Interpreter)
    else
        if isfield(options,'tikz') && options.tikz
            yl = ylim;
            xl = xlim;
            t = title(IBD_translateToLatexCommands(parName{whichPars(i)},true,true,false),'Interpreter','latex','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
            text(xl(1),(yl(2)-yl(1))*1.22+yl(1),t.String,'HorizontalAlignment',t.HorizontalAlignment,'FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
            title('')
        else
            title(parName{whichPars(i)},'Interpreter','none')
        end
    end
    
 	if isfield(options,'removeYTicks') && options.removeYTicks
        yticklabels('')
    end
    
    if isfield(options,'removeXLabel') && options.removeXLabel
        xlabel('')
    end
    
    if isfield(options,'addText')
        xl = xlim;
        yl = ylim;
        if isfield(options,'addText_position')
            if iscell(options.addText_position)
                horizontalAlignment = options.addText_position{i};
            else
                horizontalAlignment = options.addText_position;
            end
        else
            horizontalAlignment = 'right';
        end
        if strcmp(horizontalAlignment,'right')
            text(1,1,options.addText{i},'HorizontalAlignment','right','VerticalAlignment','top','Interpreter','latex','Units','normalized')
        else
            text(0,1,options.addText{i},'HorizontalAlignment','left','VerticalAlignment','top','Interpreter','latex','Units','normalized')
        end
    end
    
end


% Remove x-labels for all but last row
for rows = 1:size(sp,1)-1
    for cols = 1:size(sp,2)
        if isfield(options,'tikz') && options.tikz
            %xlabel(sp(rows,cols),{'','','','',''});
            xlabel(sp(rows,cols),{'',''});
        else
            xlabel(sp(rows,cols),{''});
        end
    end
end

% Remove y-labels for all but first column
for rows = 1:size(sp,1)
    for cols = 2:size(sp,2)
        ylabel(sp(rows,cols),'');
    end
end

% Make last figure nice
f(f_counter) = IBD_nicePlot(f(f_counter));

%--------------------------------------------------------------------------
end
