function f = IBD_violinPlot(x,labels,options,ax)
%==========================================================================
% f = IBD_violinPlot(x,labels,options,ax)
%==========================================================================
% Violin plot
%--------------------------------------------------------------------------
%-- input
% x:            data (nr of data points x nr of labels)
% labels:       cell array of strings, one string per column of x
% options:      optional struct of additional options
%                   colours:            colour matrix
%                   adjustedDistance:   adjust distance between violin plots based on widths
%               	normaliseSeparately:normalise all violins individually
%                   logY:               logarithmise the data
%                   boxplot:            print boxplot on top of violinplot (default: true)
%                   boxplotShifted:     print boxplot next to violinplot (and not on top)
%                   nrOfPts:            nr of points at which to evaluate the density function
% ax:           (optional) axis to plot into (otherwise: figure created)
%--------------------------------------------------------------------------
%-- output
% f:            figure
%==========================================================================

if ~exist('options','var') || isempty(options)
    options = struct;
end

if isfield(options,'colours') && ~isempty(options.colours)
    colours = options.colours;
else
    colours = repmat([0 0 0],[length(labels)+1,1]);
end

if isfield(options,'adjustedDistance') && options.adjustedDistance
    adjustedDistance = true;
else
    adjustedDistance = false;
end

if isfield(options,'logY') && options.logY
    x = log(x);
    x(isinf(abs(x))) = 1e-10;
end

if isfield(options,'normaliseSeparately') && options.normaliseSeparately
    normaliseSeparately = true;
else
    normaliseSeparately = false;
end

if isfield(options,'nrOfPts')
    nrOfPts = options.nrOfPts;
else
    nrOfPts = 999;
end

if ~exist('ax','var') || isempty(ax)
    f = figure;
    set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*length(labels)/2, 0.3]);
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

fi              = {};
allmaxfi        = [];
xi              = {};
IQR             = {};
Median          = {};
LowerWhisker	= {};
UpperWhisker    = {};


for i = 1:length(labels)
    
    % Violinplot
    pts = min(x(:,i)):(max(x(:,i))-min(x(:,i)))/nrOfPts:max(x(:,i));
    [fi{i},xi{i}] = ksdensity(x(:,i),pts);
    allmaxfi = [allmaxfi,max(fi{i})];
    
    % Boxplot
    IQR{i}        	= quantile(x(:,i),[0.25,0.75]);
    Median{i}      	= median(x(:,i),'omitnan');
    LowerWhisker{i}	= min(x(x(:,i)>(IQR{i}(1)-(IQR{i}(2)-IQR{i}(1))*1.5),i));
    UpperWhisker{i}	= max(x(x(:,i)<(IQR{i}(2)+(IQR{i}(2)-IQR{i}(1))*1.5),i));
    
end

maxfi = max(allmaxfi);
minfi = min(allmaxfi);

xvalue	= 0;
xvalues	= nan([1,length(labels)]);
indfi   = nan([1,length(labels)]);

for i = 1:length(labels)
    if adjustedDistance
        xvalue = xvalue+max(fi{i});
        indfi(i) = max(fi{i});
        boxplotWidth = minfi/2;
    elseif normaliseSeparately
        xvalue = i;
        % Normalise all to width=0.4
        fi{i} = fi{i}*0.4/allmaxfi(i);
        boxplotWidth = 0.06;
    else
        xvalue = i;
        % Normalise to width=0.5 of the widest
        fi{i} = fi{i}*0.5/maxfi;
        boxplotWidth = 0.06;
    end
    xvalues(i) = xvalue;
    
    % Violinplot
	fill(ax,[xvalue+fi{i} fliplr(xvalue-fi{i})],[xi{i} fliplr(xi{i})],colours(i,:),'FaceAlpha',0.3)
    
    % Boxplot on top of violinplot
    if (~isfield(options,'boxplot') || options.boxplot) && ~(isfield(options,'boxplotShifted') && options.boxplotShifted)
        fill(ax,xvalue+boxplotWidth/2*[1 1 -1 -1],[IQR{i} fliplr(IQR{i})],[1 1 1],'EdgeColor',colours(i,:))
        plot(ax,[xvalue-boxplotWidth/2 xvalue+boxplotWidth/2],[Median{i} Median{i}],'Color',colours(i,:))
%       plot(ax,[i i],[IQR{i}(1),LowerWhisker{i}],'Color',colours(i,:))
%       plot(ax,[i i],[IQR{i}(2),UpperWhisker{i}],'Color',colours(i,:))
    end
    
    % Boxplot next to violinplot
    if isfield(options,'boxplotShifted') && options.boxplotShifted
        fill(ax,xvalue+boxplotWidth/2*[1 1 -1 -1]+3*boxplotWidth,[IQR{i} fliplr(IQR{i})],[1 1 1],'EdgeColor',colours(i,:))
        plot(ax,[xvalue-boxplotWidth/2 xvalue+boxplotWidth/2]+3*boxplotWidth,[Median{i} Median{i}],'Color',colours(i,:))
%       plot(ax,[i i],[IQR{i}(1),LowerWhisker{i}],'Color',colours(i,:))
%       plot(ax,[i i],[IQR{i}(2),UpperWhisker{i}],'Color',colours(i,:))
    end
    
    xvalue = xvalue+max(fi{i})+maxfi/10;
end

if adjustedDistance
    xlim(ax,[xvalues(1)-indfi(1) xvalues(end)+indfi(end)])
else
	xlim(ax,[0.5 length(labels)+0.5])
end
xticks(ax,xvalues)
xticklabels(ax,labels)

if makeFigure
    f = IBD_nicePlot(f);
else
    f = nan;
end

end