%==========================================================================
% IBD_AnalyseLSAoverTime
%==========================================================================
% (Visual) analysis of local sensitivity analysis (time-resolved)
% 23 March 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.RunLSAoverTime)

%--------------------------------------------------------------------------

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Plots
outputs = fieldnames(LSA);
N       = 10;

colours	= IBD_colourMap('dark rainbow',N+1);

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*2, 0.3*3]);
minusFactor = 30;
Tend        = 100;
Tbefore     = -150/30;

for o = 1:length(outputs)
    
    % Sort by maximal value
    maxValue    = [];
    for i = 1:length(LSA.(outputs{o}))
        maxValue = [maxValue,max(abs(LSA.(outputs{o}){i}.S))];
    end
    [~,xidx] = sort(maxValue,'descend');
    xidx = xidx(1:N);
    
    s(o) = subplot(length(outputs),1,o);
    hold on
    xlim([Tbefore Tend])
    h = yline(0,'Color',IBD_myColours('yline'));
	set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
    legendList = {};
    
    for i = 1:length(xidx)
        j = xidx(i);
        xvalues         = [Tbefore;LSA.(outputs{o}){j}.T/24];
        t_idx           = find(xvalues>Tend,1);
        xvalues         = xvalues(1:t_idx);
        yvalues         = LSA.(outputs{o}){j}.S([1,1:end]);
        yvalues         = yvalues(1:t_idx);
        plot(xvalues,yvalues,'Color',colours(i,:))
        if save2tikz
            legendList = [legendList,IBD_translateToLatexCommands(LSA.(outputs{o}){j}.par(1,:),true,false)];
        else
            legendList = [legendList,LSA.(outputs{o}){j}.par(1,:)];
        end
    end
    
    if save2tikz
        l(o) = legend(legendList,'Location','eastoutside','Interpreter','latex');
    else
        l(o) = legend(legendList,'Location','eastoutside');
    end
    legend boxoff
    xlabel('Time [days]')
    ylabel('S')
    
    switch outputs{o}
        case 'Thtot'
            realName = 'Th_tot_LP';
        case 'Mtot'
            realName = 'M_tot_LP';
        case 'Neut'
            realName = 'Neut_LP';
    end
    if save2tikz
        t = title(IBD_translateToLatexCommands(realName,true,true),'Interpreter','latex');
        xl = xlim;
        yl = ylim;
        text(xl(1),(yl(2)-yl(1))*1.22+yl(1),t.String,'HorizontalAlignment','left','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('');
    else
        title(realName)
    end
    
    yl = ylim;
    ylim(yl*1.1);
end

f = IBD_nicePlot(f);

% Make plots/legend same size for all subplots
for o = 2:length(s)
    s(o).Position(3) = s(1).Position(3);
    l(o).Position(1) = l(1).Position(1);
end

% Save figure
if save2pdf
    IBD_saveFigure(f,['LSAoverTime'],'pdf')
end
if save2tikz
    IBD_saveFigure(f,['LSAoverTime'],'tikz')
end
