%==========================================================================
% IBD_CytokineWeights
%==========================================================================
% Simulation of mucosal injury with plots for cytokine production by 
% different cell types per process
% 5 March 2020
%--------------------------------------------------------------------------
%-- prerequisites
% Uncomment lines 531-587 of IBD_reactionRates.m before the execution of this script
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).infection.epiDamage               = 1;
individual(1).infection.tisDamage               = 1;

% individual(1)                                   = individual_ref;
% individual(1).infection.Bact                    = {'STm'};
% individual(1).infection.initial                 = 0.01;

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind));
end

%==========================================================================
%% Plots

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

default         = IBD_plotSpecReference(individual(1));
default.xunit   = 'd';
default.ylabel  = 'cytokine value';
default.titlePos= 'left';
default.grid    = false;
default.tikz    = save2tikz;
default.yline 	= 1;
default.Bact  	= {};
tmpColourMap    = IBD_colourMap('dark rainbow',8);
tmpColourMap    = [0 0 0;tmpColourMap];

x = individual(1).nrOfRctWoTransit_true;

i = 1;
p(i)            = default;
p(i).rates      = x+([2 4 5 6]);
p(i).main       = 'cytoRecNeut';
p(i).legend     = {'total','Th17','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thseventeeneff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 3 4 5],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(7:11);
p(i).main       = 'cytoRecM';
p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 2 3 4 5],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(12:16);
p(i).main       = 'cytoActM';
p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 2 3 4 5],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(17:21);
p(i).main       = 'cytoActDC';
p(i).legend     = {'total','Th1','Th17','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 2 3 4 5],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(22:25);
p(i).main       = 'cytoDeactM';
p(i).legend     = {'total','Treg','Th2','Manti'};
p(i).tikzLegend = {'total','$\iTregeffLP$','$\Thtwoeff$','$\Mantiaix$'};
p(i).colourMap  = tmpColourMap([1 6 7 8],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(26:29);
p(i).main       = 'cytoDeactDC';
p(i).legend     = {'total','Treg','Th2','Manti'};
p(i).tikzLegend = {'total','$\iTregeffLP$','$\Thtwoeff$','$\Mantiaix$'};
p(i).colourMap  = tmpColourMap([1 6 7 8],:);

i = i+1;
p(i)            = default;
p(i).rates      = x+(30:35);
p(i).main       = 'cytoDamageEpi';
p(i).legend     = {'total','Th1','Th17','Th2','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Thtwoeff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 2 3 7 4 5],:);
p(i).yline      = [];

i = i+1;
p(i)            = default;
p(i).rates      = x+(36:41);
p(i).main       = 'cytoDamageTis';
p(i).legend     = {'total','Th1','Th17','Th2','Neut','Mpro'};
p(i).tikzLegend = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Thtwoeff$','$\Neut$','$\Mproaix$'};
p(i).colourMap  = tmpColourMap([1 2 3 7 4 5],:);
p(i).yline      = [];

i = i+1;
p(i)            = default;
p(i).rates      = x+(45:47);
p(i).main       = 'cytoTisRemod';
p(i).legend     = {'total','Th2','Meff'};
p(i).tikzLegend = {'total','$\Thtwoeff$','$\Mantiaix$'};
p(i).colourMap  = tmpColourMap([1 7 8],:);
p(i).yline      = [];

orderPlots = [1 2 0 3 4 0 5 7 9];

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*3, 0.3*3]);
for i = 1:length(p)
    o = orderPlots(i);
    subplot(3,3,i)
    if o>0
        hold on
        for j = 1:length(p(o).rates)
            saveLines(i,j) = plot([-5;individual(1).T/24],[individual(1).A(1,p(o).rates(j));individual(1).A(:,p(o).rates(j))],'Color',p(o).colourMap(j,:));
        end
        if ~isempty(p(o).yline)
            yline(p(o).yline,'Color',[0.5 0.5 0.5])
        end
        xl = xlim;
        yl = ylim;
        if ~isempty(p(o).yline) && yl(2)<1.2
            ylim([0,1.2])
            yl = ylim;
        end
        a = gca;
        xup = 1.22;
            % Check if 10^xx --> other factor
            if a.YAxis.Exponent==0 && yl(2)>0.05
                xup = 1.15;
            end
        title(p(o).main,'HorizontalAlignment',p(o).titlePos,'Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
        text(xl(1),(yl(2)-yl(1))*xup+yl(1),regexprep(p(o).main,'  ','\\ \\ '),'HorizontalAlignment',p(o).titlePos,'FontSize',a.Title.FontSize,'FontWeight',a.Title.FontWeight,'Interpreter','latex')
        title('')
        if mod(i,3)==1
            ylabel('Cytokine value')
        end
        if 9-i <3
            xlabel('Time [days]')
        else
            xlabel({' '})
        end
    end
end

% Legend
h = subplot(3,3,[3 6],'replace');
hold on
for i = 1:8
    plot(1,1,'Color',tmpColourMap(i,:))
end
leg = legend({'total','Th1eff','Th17eff','Neut','Mproa','iTregeff_{LP}','Th2eff','Mantia'},'Location','east');
axis off

f = IBD_nicePlot(f);

if save2pdf
	IBD_saveFigure(f,'submodels_cytokineWeights','pdf')
end

if save2tikz
    % Legend
    leg.String = {'total','$\Thoneeff$','$\Thseventeeneff$','$\Neut$','$\Mproaix$','$\iTregeffLP$','$\Thtwoeff$','$\Mantiaix$'};
    leg.Interpreter = 'latex'
    % Titles
    a = findall(gcf,'Type','text')
    for i = 1:length(a)
        s{i} = a(i).String;
    end
	idx = cellfun(@(x) ~isempty(strfind(x,'cyto')) &~iscell(x), s);
    for i = find(idx)
        a(i).String = ['$\boldsymbol{\',a(i).String,'}$'];
    end
    IBD_saveFigure(f,'submodels_cytokineWeights','tikz')
end

%--------------------------------------------------------------------------