%==========================================================================
% IBD_SimSubmodels
%==========================================================================
% Simulation of salmonella infection and mucosal injury with plots for all
% submodels
% 17 June 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','STm','extracellular'};
individual_ref = IBD_referenceIndividual(options);
I = individual_ref.I;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).infection.Bact                    = {'STm'};
individual(1).infection.initial                 = 0.01;
individual(1).title                             = 'salmonellae';

individual(2)                                   = individual_ref;
individual(2).infection.epiDamage               = 1;
individual(2).infection.tisDamage               = 1;
individual(2).title                             = 'injury';

individual(3)                                   = individual_ref;
individual(3).infection.Bact                    = {'extracellular'};
individual(3).infection.initial                 = 0.1;
individual(3).title                             = 'extracellular';
% (plot only in overview)

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run infection scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind));
end

%==========================================================================
% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

default         = IBD_plotSpecReference(individual(1));
default.xunit   = 'd';
default.ylabel  = 'Conc. [1/mL]';
default.titlePos= 'left';
default.grid    = false;
default.tikz    = save2tikz;

% Overview
p = IBD_plotDatabase('overview_woBarrier',individual(1));
f = IBD_plotIndAndSave(individual,p,'submodels_overview',save2pdf,save2tikz);
clear p

% Dendritic cells
p(1)          	= default;
p(1).states     = {'qDC_LP',{'tDC_LP','tDCi_LP'},'rDC_LP',{'sDC_LP','sDCi_LP'}};
p(1).tikzLegend = {'$\qDC$','$\tDCLP$','$\rDC$','$\sDCLP$'};
p(1).Bact       = {};
p(1).main       = 'Dendritic cells in LP';
p(1).legendPos  = 'east';
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_DC',save2pdf,save2tikz);
clear p

% Macrophages: deactivation
p(1)          	= default;
p(1).states     = {'MP1_tot_LP','MP2_tot_LP','MP3_tot_LP','MP4_tot_LP','Meffero_tot_LP'};
p(1).tikzLegend = {'$\Monetot$','$\Mtwotot$','$\Mthreetot$','$\Mfourtot$','$\Mefferotot$'};
p(1).main       = 'Macrophage populations';
p(1).legendPos  = 'northeast';
p(1).legendRow  = 2;
p(2)          	= default;
p(2).states     = {{'MP1_LP','MP2_LP','MP3_LP','MP4_LP','Meffero_LP'},...
                   {'MP1a_LP','MP2a_LP','MP3a_LP','MP4a_LP','Mefferoa_LP',...
                    'MP1ai_LP','MP2ai_LP','MP3ai_LP','MP4ai_LP','Mefferoai_LP',...
                    'MP1inf_LP','MP2inf_LP','MP3inf_LP','MP4inf_LP','Mefferoinf_LP'}};
p(2).tikzLegend = {'unexperienced','experienced'};
p(2).main       = 'Macrophages: antigen uptake';
p(2).legendPos  = 'northeast';
p(2).legendRow  = 2;
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_M',save2pdf,save2tikz);
clear p

% Neutrophils
p(1)          	= default;
p(1).states     = {'Neut_LP','Meffero_tot_LP'};
p(1).tikzLegend = {'$\Neut$','$\Meffero$'};
p(1).main       = 'Neutrophils';
p(1).legendPos  = 'northeast';
p(1).legendRow  = 2;
extraCode.Axis  = 'clip=true';
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_Neut',save2pdf,save2tikz,extraCode);
clear p

% Barrier
p(1)          	= default;
p(1).states     = {'tissue','epi','mucus'};
p(1).tikzLegend = {'$\tissue$','$\epi$','$\mucus$'};
p(1).main       = 'Barrier';
p(1).legendPos  = 'southeast';
p(1).yline      = 1;
p(1).ylabel     = 'State variable value';
p(1).ylim       = [0 1.3];
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_barrier',save2pdf,save2tikz);
clear p

% Regulatory T cells
p(1)          	= default;
p(1).states     = {'Th_eff_tot_LP','iTreg_eff_LP'};
p(1).tikzLegend = {'$\TheffLP$','$\iTregeffLP$'};
p(1).main       = 'Regulatory T cells in LP';
p(1).legendPos  = 'northeast';
p(1).Bact       = {};
p(1).ylim       = [0 1.7e8];
p(2)          	= default;
p(2).states     = {'Th_eff_tot_LN','iTreg_eff_LN'};
p(2).tikzLegend = {'$\TheffLN$','$\iTregeffLN$'};
p(2).main       = 'Regulatory T cells in LN';
p(2).legendPos  = 'northeast';
p(2).Bact       = {};
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_Treg',save2pdf,save2tikz);
clear p

% pMHC2-depleted APCs
p(1)          	= default;
p(1).states     = {'tDC_LP','tDCi_LP','sDC_LP','sDCi_LP'};
p(1).tikzLegend = {'$\tDCLP$','$\tDCiLP$','$\sDCLP$','$\sDCiLP$'};
p(1).main       = 'pMHCII-depleted APCs in LP';
p(1).legendPos  = 'northeast';
p(1).Bact       = {};
p(2)          	= default;
p(2).states     = {'tDC_LN','tDCi_LN','sDC_LN','sDCi_LN'};
p(2).tikzLegend = {'$\tDCLN$','$\tDCiLN$','$\sDCLN$','$\sDCiLN$'};
p(2).main       = 'pMHCII-depleted APCs in LN';
p(2).legendPos  = 'northeast';
p(2).Bact       = {};
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_depletedAPC',save2pdf,save2tikz);
clear p
% Percentages of pMHC2-depleted APCs:
depletedStates = {'tDCi_LN','sDCi_LN','tDCi_LP','sDCi_LP','MP1ai_LP','MP2ai_LP','MP3ai_LP','MP4ai_LP','Mefferoai_LP'};
originalStates = {'tDC_LN' ,'sDC_LN' ,'tDC_LP' ,'sDC_LP' ,'MP1a_LP' ,'MP2a_LP' ,'MP3a_LP' ,'MP4a_LP' ,'Mefferoa_LP' };
percentageDepleted = array2table(nan(length(depletedStates),1),'VariableNames',{'percent'},'RowNames',depletedStates);
for i = 1:length(depletedStates)
    percentageDepleted.percent(i) = individual_ref.ssTable{depletedStates{i},'simulation'}/(individual_ref.ssTable{originalStates{i},'simulation'}+individual_ref.ssTable{depletedStates{i},'simulation'})*100;
end

% Bacteria in lumen
p(1)          	= default;
p(1).states     = {'Bact_Lu'};
p(1).tikzLegend = {'$\BactLu$'};
p(1).main       = 'Bacteria LP';
p(1).legendPos  = 'northeast';
p(1).ylim       = [0 0.1];
f = IBD_plotIndAndSave(individual(1:3),p,'submodels_BactLu',save2pdf,save2tikz);
clear p

% Specialised pro-resolving mediators
p(1)          	= default;
p(1).states     = {'SPM_LP'};
p(1).tikzLegend = {'SPM'};
p(1).main       = 'SPM';
p(1).legendPos  = 'northeast';
p(1).yline      = 1;
f = IBD_plotIndAndSave(individual(1:2),p,'submodels_SPM',save2pdf,save2tikz);
clear p

%--------------------------------------------------------------------------
% Peak of neutrophil concentration
[~,i_STm] = max(individual(1).X(:,I.Neut_LP));      % salmonellae
[~,i_inj] = max(individual(2).X(:,I.Neut_LP));      % injury
fprintf('Neutrophil concentration peaks at\n\tt = %.2f h after salmonellae infection\n\tt = %.2f h after mucosal injury\n',individual(1).T(i_STm),individual(1).T(i_inj))

%--------------------------------------------------------------------------
%% Macrophage populations
% resting, day2, day4, day6
f1      = figure;
idx     = [I.MP1_tot_LP I.MP2_tot_LP I.MP3_tot_LP I.MP4_tot_LP I.Meffero_tot_LP];
colours	= IBD_colourMap('dark rainbow',length(idx)+1);
x       = 0.7;
colours(length(idx),:) = colours(length(idx),:)*x+colours(length(idx)-1,:)*(1-x);
labels  = {'$\Monetot$','$\Mtwotot$','$\Mthreetot$','$\Mfourtot$','$\Mefferotot$'};   % use latex commands
rowTitle={'salmonellae','injury'};
m       = 3;
n       = 3;

% Mucosal injury & salmonellae
z = 1;
for ind = [1 2]
    for day = [0 4 6]
        s(z) = subplot(m,n,z);
        tx = find(individual(ind).T<=day*24,1,'last');
        if ind==1 && day==0
            p = pie(individual(ind).Xadd(tx,idx),{'','','','',''});
            for i = 1:2:length(p)
                p(i).EdgeColor = [1 1 1];
            end
            leg = legend(labels,'EdgeColor',[1 1 1],'Interpreter','latex');
        else
            p = pie(individual(ind).Xadd(tx,idx),{'','','','',''});
        end
        for i = 1:length(idx)
            p(2*i-1).FaceColor  = colours(i,:);
            p(2*i).Color        = colours(i,:);
        end
        if ind==1
            t = title(['Day ',int2str(day)]);
        end
        z = z+1;
    end
    ax = gca;
    yl = ax.YLim;
    xl = ax.XLim;
    text(xl(2)*2,(yl(1)+yl(2))/2,rowTitle{ind},'HorizontalAlignment','center','Rotation',270,'FontSize',t.FontSize,'FontWeight',t.FontWeight)
end

% Data from [Bain 2013] (without P5) 
% Figure 4. Effects of inflammation on composition of colonic myeloid cell populations.
% (e) Absolute numbers of CX3CR1-defined P1, P2, P3, P4, and P5 subsets of colonic CD11b + cells during colitis.
infl.day0(1)	= 1.06e4;       % [nr per colon]
infl.day4(1) 	= 9.31e4;
infl.day6(1) 	= 24.84e4;
infl.day0(2) 	= 1.38e4;
infl.day4(2)  	= 14.82e4;
infl.day6(2) 	= 20e4;
infl.day0(3)    = 2.08e4;
infl.day4(3)  	= 4.22e4;
infl.day6(3)  	= 10.04e4;
infl.day0(4)    = 13.29e4;
infl.day4(4)  	= 11.78e4;
infl.day6(4)	= 6.69e4;

for day = [0 4 6]
    s(z) = subplot(m,n,z);
    pieData = infl.(['day',int2str(day)]);
    
    % Stripes for P4
    pieData2 = pieData(1:3);
    thickness = sum(pieData)/60;
    while sum(pieData2(4:end))<pieData(4)
        pieData2 = [pieData2,thickness];
    end
    pieData2(end) = pieData(4)-sum(pieData2(4:end-1));
    
    p = pie(pieData2,repmat({''},1,length(pieData2)));
    for i = length(pieData2):-1:1
        if i < 4
            p(2*i-1).FaceColor  = colours(i,:);
            p(2*i-1).EdgeColor  = [0 0 0];
            p(2*i).Color        = colours(i,:);
        else
            if mod(i,2)
                p(2*i-1).FaceColor  = colours(4,:);
                p(2*i).Color        = colours(4,:);
            else
                p(2*i-1).FaceColor  = colours(5,:);
                p(2*i).Color        = colours(5,:);
            end
        end
        p(2*i-1).EdgeAlpha = 0;
    end
    hold on
    p2 = pie(pieData,repmat({''},1,length(pieData)));
    for i = 1:length(pieData)
        p2(2*i-1).FaceAlpha = 0;
    end
    
  	z = z+1;
end
ax = gca;
yl = ax.YLim;
xl = ax.XLim;
text(xl(2)*2,(yl(1)+yl(2))/2,{'exp.\ colitis','(Bain et al.)'},'HorizontalAlignment','center','Rotation',270,'FontSize',t.FontSize,'FontWeight',t.FontWeight)

% Subplot positions
pos_n = [0.1 0.32 0.55];
pos_m = [0.59 0.34 0.1];
for z = 1:length(s)
    [x,y] = ind2sub([m,n],z);
    s(z).Position(1) = pos_n(x);
    s(z).Position(2) = pos_m(y);
end

f1 = IBD_nicePlot(f1,2);
if save2tikz
    IBD_saveFigure(f1,'macrophagePiecharts','tikz')
end
if save2pdf
    leg.String = {'M1_{tot}','M2_{tot}','M3_{tot}','M4_{tot}','Meffero_{tot}'};
    leg.Interpreter = 'tex';
    leg.FontSize = 12;
    IBD_saveFigure(f1,'macrophagePiecharts','pdf')
end

%--------------------------------------------------------------------------