%==========================================================================
% IBD_Tproliferation
%==========================================================================
% Proliferation of naive T cells
% 17 February 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
options.BactNames = {'commensal','extracellular'};
individual_ref = IBD_referenceIndividual(options);
I  	= individual_ref.I;
par = individual_ref.par;

%--------------------------------------------------------------------------
for i = 1:2
    individual(i)	= individual_ref;
    individual(i)   = IBD_runSteadyState(individual(i));
    individual(i).timespan = unique(sort([0:100,31:0.1:32,13:0.1:14]));
end

% Scenario: add one proliferating T helper cell (1/mL) specific for extracellular pathogen
individual(1).X_ss(I.Tn2Th1_LN(I.extracellular,1))      = 1;
individual(2).X_ss(I.Tcm2Tem1_LN(I.extracellular,1)) 	= 1;

for i = 1:2
    individual(i).par(I.muTeff) = 0;
    individual(i).par(I.muT_LP) = 0;
end

% Run scenario
for i = 1:2
	individual(i)	= IBD_runInfection(individual(i));
end

%--------------------------------------------------------------------------
%% Plots
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

colours = IBD_colourMap('dark rainbow',par(I.nTn)+1);
f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*3, 0.3*1]);

% Naive T cells
s1 = subplot(1,3,1);
hold on
for i = 1:par(I.nTn)
    x = individual(1).T;
    y = individual(1).X(:,I.Tn2Th1_LN(I.extracellular,i));
    h = plot(x(x<=100),y(x<=100),'Color',colours(i,:));
    if ~ismember(i,[1 5 10])
     	set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
    end
end
x = individual(1).T;
y = individual(1).X(:,I.Th1_LP(I.extracellular))*par(I.VLP)/par(I.VLN);
plot(x(x<=100&y<=1),y(x<=100&y<=1),'k--');
xlim([0 100])
ylim([0 1])
yl = ylim;
xl = xlim;
xlabel('Time [h]')
ylabel('# cells per activated cell')
title('Prol.\ naive T cells','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0])
t1 = text(xl(1),(yl(2)-yl(1))*1.15+yl(1),s1.Title.String,'HorizontalAlignment','left','FontSize',s1.Title.FontSize,'FontWeight',s1.Title.FontWeight);
title('')
if save2tikz
    legend({'$i=1$','$i=5$','$i=10$'},'Interpreter','latex')
else
    legend({'i = 1','i = 5','i = 10'})
end

% Memory T cells
s2 = subplot(1,3,2);
hold on
for i = 1:par(I.nTm)
    x = individual(2).T;
    y = individual(2).X(:,I.Tcm2Tem1_LN(I.extracellular,i));
    h = plot(x(x<=100),y(x<=100),'Color',colours(i,:));
    if ~ismember(i,[1 5 10])
     	set(get(get(h,'Annotation')','LegendInformation'),'IconDisplayStyle','off');
    end
end
x = individual(2).T;
y = individual(2).X(:,I.Tem1_LP(I.extracellular))*par(I.VLP)/par(I.VLN);
plot(x(x<=100&y<=1),y(x<=100&y<=1),'k:');
xlim([0 100])
ylim([0 1])
yl = ylim;
xl = xlim;
xlabel('Time [h]')
title('Prol.\ memory T cells','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0])
t2 = text(xl(1),(yl(2)-yl(1))*1.14+yl(1),s2.Title.String,'HorizontalAlignment','left','FontSize',s2.Title.FontSize,'FontWeight',s2.Title.FontWeight);
title('')
if save2tikz
    legend({'$i=1$','$i=5$','$i=10$'},'Interpreter','latex')
else
    legend({'i = 1','i = 5','i = 10'})
end

% Resulting effector cells
s3 = subplot(1,3,3);
hold on
x = individual(1).T;
y = individual(1).X(:,I.Th1_LP(I.extracellular))*par(I.VLP)/par(I.VLN);
plot(x(x<=100),y(x<=100),'k--');
x = individual(2).T;
y = individual(2).X(:,I.Tem1_LP(I.extracellular))*par(I.VLP)/par(I.VLN);
plot(x(x<=100),y(x<=100),'k:');
xlim([0 100])
yl = ylim;
xl = xlim;
xlabel('Time [h]')
title('Effector T cells','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0])
t3 = text(xl(1),(yl(2)-yl(1))*1.15+yl(1),s3.Title.String,'HorizontalAlignment','left','FontSize',s3.Title.FontSize,'FontWeight',s3.Title.FontWeight);
title('')
legend({'naive','memory'},'Location','southeast')

linkaxes([s1 s2])

f = IBD_nicePlot(f);
if save2tikz
    IBD_saveFigure(f,'TcellProliferation','tikz')
end

s1.Title.String = 'Prol. naive T cells';
s1.Title.Position = [0 s1.YLim(2) 0];
t1.String = '';
s2.Title.String = 'Prol. memory T cells';
s2.Title.Position = [0 s2.YLim(2) 0];
t2.String = '';
s3.Title.String = 'Effector T cells';
s3.Title.Position = [0 s3.YLim(2) 0];
t3.String = '';

if save2pdf
    IBD_saveFigure(f,'TcellProliferation','pdf')
end

fprintf('Naive T cells: %.2f effector cells per activated naive T cell\n',individual(1).X(end,I.Th1_LP(I.extracellular))*par(I.VLP)/par(I.VLN))
fprintf('Memory T cells: %.2f effector cells per activated memory T cell\n',individual(2).X(end,I.Tem1_LP(I.extracellular))*par(I.VLP)/par(I.VLN))

%--------------------------------------------------------------------------