%==========================================================================
% IBD_AnalyseCDEIS
%==========================================================================
% Analyse CDEIS calculation and distribution to ensure good translation of
% model results to clinical study endpoints
% 29 November 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

whichTreatment = 'TNF';

% Load data
load(fileNameList.ConstantTreatment.(whichTreatment),'X','ssT4','ssT12','ssT24','ssAT','etas','individual_ref');
IBD     = load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','ssMI');
healthy = load(strrep(fileNameList.CombinePopulation,'xxx','healthy'),'ss0','ssMI');

N_IBD   = size(IBD.ss0,2);
I       = individual_ref.I;

% Temporary (until IBD_ConstantTreatment after 28 Nov 19)
if ~exist('etas','var')
    switch whichTreatment
        case 'TNF'
            etas = [0.1 0.2 0.3 0.4 0.5];
        case 'integrin'
            etas = [0.1 0.2 0.3 0.4 0.5];
        case 'S1P'
            etas = [-0.5,-1,-2,-3];
    end
end
nrOfEtas = length(etas);

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
%% Tissue, epi and neutrophil distributions in healthy and IBD patients
colours = IBD_colourMap('dark rainbow',7);
f1 = figure;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*6/2, 0.3*3])
states = {'tissue','epi','Neut_LP'};
for i = 1:length(states)
    x   = [healthy.ss0(I.(states{i}),1:N_IBD);IBD.ssMI(I.(states{i}),:)]';
    ax(i) = subplot(3,1,i);
    [~] = IBD_violinPlot(x,{'healthy','IBD'},colours([4,7],:),true,false,ax(i));
    pause(1)
    title(states{i})
    ylabel([states{i},' value'])
end
f1 = IBD_nicePlot(f1);

%% Quantiles of tissue, epi and neutrophil distribution in pre-IBD and IBD patients
p = [0.01,0.05,0.1,0.5,0.9,0.95,0.99];
quantiles = array2table([quantile(healthy.ss0(I.tissue,:),p);quantile(IBD.ssMI(I.tissue,:),p);...
                         quantile(healthy.ss0(I.epi,:),p);   quantile(IBD.ssMI(I.epi,:),p);...
                         quantile(healthy.ss0(I.Neut_LP,:),p);quantile(IBD.ssMI(I.Neut_LP,:),p)],...
                         'VariableNames',strrep(compose('q%.2f',p),'.','_'),...
                         'RowNames',{'tissueHealthy','tissueIBD','epiHealthy','epiIBD','NeutHealthy','NeutIBD'});
disp(quantiles)

% Take thresholds/values for CDEIS calculation based on distributions
fprintf('Tissue upper threshold (q0.01 of healthy): %.2f\n',quantiles{'tissueHealthy','q0_01'})
fprintf('Tissue lower threshold (q0.01 of IBD):     %.2f\n',quantiles{'tissueIBD','q0_01'})
fprintf('Epi upper threshold (q0.01 of healthy): %.2f\n',quantiles{'epiHealthy','q0_01'})
fprintf('Epi lower threshold (q0.01 of IBD):     %.2f\n',quantiles{'epiIBD','q0_01'})

score = @(Km,h,Neut) 10*Neut^h/(Km^h+Neut^h);
Kmvalues = linspace(quantiles{'NeutHealthy','q0_99'},quantiles{'NeutIBD','q0_99'},15);
hvalues = 1:10;
scoreHealthy    = nan(length(hvalues),length(Kmvalues));    % score for q0.99 of healthy
scoreIBD        = nan(length(hvalues),length(Kmvalues));    % score for q0.99 of IBD
for i = 1:length(Kmvalues)
    for j = 1:length(hvalues)
        scoreHealthy(j,i) = score(Kmvalues(i),hvalues(j),quantiles{'NeutHealthy','q0_99'});
        scoreIBD(j,i) = score(Kmvalues(i),hvalues(j),quantiles{'NeutIBD','q0_99'});
    end
end

for j = 1:length(hvalues)
    %disp([scoreHealthy(j,:);scoreIBD(j,:)]);
end

Km = Kmvalues(6);
h = hvalues(2);

fprintf('Diseased surface: Km = %.2e, h = %i\n',Km,h)
fprintf('\t resulting in score %.2f for q0.99 of healthy and %.2f for q0.99 of IBD\n',score(Km,h,quantiles{'NeutHealthy','q0_99'}),score(Km,h,quantiles{'NeutIBD','q0_99'}))

fprintf('Tissue threshold for stenosis (q0.99 of healthy): %.2f\n',quantiles{'tissueHealthy','q0_99'})
fprintf('\t resulting in %.1f%% of IBD patients with stenosis\n',sum(IBD.ssMI(I.tissue,:)>1.1)/N_IBD*100)
fprintf('Tissue/epi threshold for ulcerated stenosis: 5\n')

%--------------------------------------------------------------------------
%% CDEIS
[CDEIS.healthy,details_healthy] = IBD_CDEIS(healthy.ss0,I);
[CDEIS.ss0,details_ss0]         = IBD_CDEIS(IBD.ss0,I);
[CDEIS.ssMI,details_ssMI]       = IBD_CDEIS(IBD.ssMI,I);
for e = 1:nrOfEtas
    [CDEIS.ssT4(:,e),~]         = IBD_CDEIS(squeeze(ssT4(:,e,:)),I);
    [CDEIS.ssT12(:,e),~]        = IBD_CDEIS(squeeze(ssT12(:,e,:)),I);
    [CDEIS.ssT24(:,e),~]        = IBD_CDEIS(squeeze(ssT24(:,e,:)),I);
    [CDEIS.ssAT(:,e),~]         = IBD_CDEIS(squeeze(ssAT(:,e,:)),I);
end

% Violinplots of CDEIS contributions
x = [details_ssMI.deepUlcerations,details_ssMI.superficialUlcerations,details_ssMI.surfaceDisease,details_ssMI.surfaceUlcerations,details_ssMI.CDEIS];
f2 = IBD_violinPlot(x,{'deepUlcers','supUlcers','surfDisease','surfUlcers','CDEIS'},IBD_colourMap('dark rainbow',7),false,false);
pause(1)
ylabel('log CDEIS')
pause(1)

% Compare CDEIS distribution with clinical studies
fprintf('Mean CDEIS of all IBD patients: %.2f\n',mean(details_ssMI.CDEIS))
fprintf('Mean CDEIS of included IBD patients: %.2f\n',mean(details_ssMI.CDEIS(details_ssMI.CDEIS>=6)))
fprintf('Mean CDEIS in Colombel et al. (2017): 14.3+-6.9 or 13.4+-6.0\n')
