%==========================================================================
% IBD_AnalyseNecessaryParChanges
%==========================================================================
% Analyse necessary parameter changes for IBD
% 9 September 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombineNecessaryParChanges)
I       = individual_ref.I;
N_IBD   = size(minimalPar,2);

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Distinguish necessary parameters by class when set back
for ind = 1:N_IBD
    thisMinimalParIdx           = minimalParIdx{ind};
    thisClassWhenSetBack        = classWhenSetBack(thisMinimalParIdx,ind);
    minParIdx.healthy{ind}      = thisMinimalParIdx(thisClassWhenSetBack==1);
    minParIdx.problems{ind}     = thisMinimalParIdx(thisClassWhenSetBack==0);
    minParIdx.chronic{ind}      = thisMinimalParIdx(thisClassWhenSetBack>2);
    if ~sum(thisClassWhenSetBack==2)==0
        error('Something went wrong here!')
    end
end

% Number of parameters changed per individual for each group
nrOf.problems  	= cellfun(@length,minParIdx.problems);
nrOf.healthy   	= cellfun(@length,minParIdx.healthy);
nrOf.chronic   	= cellfun(@length,minParIdx.chronic);
nrOf.all        = cellfun(@length,minimalParIdx);

%--------------------------------------------------------------------------
% For each group of parameters separately: analyse parameters/frequencies

% Command line output: statistics
fprintf('Population of %i parameter sets (=IBD patients):\n\t%i (%.2f%%) contain problem parameters\n\t%i (%.2f%%) contain chronic parameters\n\t%i (%.2f%%) contain neither\n',N_IBD,sum(nrOf.problems>0),sum(nrOf.problems>0)/N_IBD*100,sum(nrOf.chronic>0),sum(nrOf.chronic>0)/N_IBD*100,sum(nrOf.chronic==0&nrOf.problems==0),sum(nrOf.chronic==0&nrOf.problems==0)/N_IBD*100)
fprintf('Those containing problem parameters contain between %i and %i problem parameters, mean: %.2f, median: %i\n',min(nrOf.problems(nrOf.problems>0)),max(nrOf.problems(nrOf.problems>0)),mean(nrOf.problems(nrOf.problems>0)),median(nrOf.problems(nrOf.problems>0)))
fprintf('Those containing chronic parameters contain between %i and %i chronic parameters, mean: %.2f, median: %i\n',min(nrOf.chronic(nrOf.chronic>0)),max(nrOf.chronic(nrOf.chronic>0)),mean(nrOf.chronic(nrOf.chronic>0)),median(nrOf.chronic(nrOf.chronic>0)))
fprintf('The number of required parameters ranges between\n\t(without problems/chronic:) %i and %i, mean: %.2f, median: %i\n\t(with problems/chronic:)    %i and %i, mean: %.2f, median: %i\n',min(nrOf.healthy),max(nrOf.healthy),mean(nrOf.healthy),median(nrOf.healthy),min(nrOf.all),max(nrOf.all),mean(nrOf.all),median(nrOf.all))


%% Parameters resulting in healthy if changed back
thisParGroup    = 'healthy';
nrOfThisGroup   = nrOf.(thisParGroup);
thisMinParIdx   = minParIdx.(thisParGroup);

% Command line output
fprintf('\nCompared to %s: \n',thisParGroup)
fprintf('Minimal nr of disease-relevant parameter changes: %i\nMaximal nr of disease-relevant parameters changes: %i\nMedian nr of disease-relevant parameter changes: %i\n',min(nrOfThisGroup),max(nrOfThisGroup),median(nrOfThisGroup))
[~,minIdx] = find(nrOfThisGroup==1);
singlePar = {};
for i = 1:length(minIdx)
    singlePar = [singlePar,individual_ref.I.parName(minParIdx.(thisParGroup){minIdx(i)})];
end
changedBy = [];
whichPar = {};
minIdx_corrected = [];
for i = 1:length(minIdx)
    if isempty(cell2mat(minParIdx.problems(minIdx(i))))     % no parameters causing problems
        whichPar = [whichPar,singlePar{i}];
        changedBy = [changedBy,minimalPar(thisMinParIdx{minIdx(i)},minIdx(i))/individual_ref.par(thisMinParIdx{minIdx(i)})];
        minIdx_corrected = [minIdx_corrected,minIdx(i)];
    end
end
fprintf('Parameters leading to IBD on their own (%i cases, i.e. %.1f%% of IBD patients):\n',length(whichPar),length(whichPar)/N_IBD*100)
whichPar_unique = unique(whichPar);
for p = 1:length(whichPar_unique)
    fprintf('\t%s changed by factor %.2f - %.2f\n',whichPar_unique{p},min(minimalPar(I.HillProActM,minIdx_corrected)),max(minimalPar(I.HillProActM,minIdx_corrected)))
end

% Relative macrophage deactivation rate over cytokines for different Hill factors
% Cytokine concentrations from reference individual's steady state (IBD_runSteadyState(individual_ref) with uncommented cyto_... in IBD_reactionRates)
par = individual_ref.par;
cyto_DeactM = 1.3213;
cyto_ActM   = 0.2895;
nuMP12_ref 	= par(I.nuMP12ss)*cyto_DeactM^par(I.HillAntiActM)/((1+cyto_ActM^par(I.HillProActM))+cyto_DeactM^par(I.HillAntiActM));       % inactivation rate per MP1 macrophage
nuMP12      = @(cyto,h) par(I.nuMP12ss)*cyto_DeactM^par(I.HillAntiActM)./((1+cyto.^h)+cyto_DeactM^par(I.HillAntiActM));
cyto_range  = 0:0.01:2;
h_range     = 1:1:7;
f0 = figure;
hold on
colours = IBD_colourMap('dark rainbow',8);
l = {};
for i = 1:length(h_range)
    plot(cyto_range,nuMP12(cyto_range,h_range(i)),'Color',colours(i,:))
    l = [l,sprintf('h=%i',h_range(i))];
end
legend(l,'Location','south west')
xlabel('Pro-inflammatory cytokine concentration')
ylabel('Macrophage deactivation rate')
f0 = IBD_nicePlot(f0);
plotName = ['NecessaryParChanges_Hill'];
if save2pdf
    IBD_saveFigure(f0,plotName,'pdf')
end
if save2tikz    
    IBD_saveFigure(f0,plotName,'tikz')
end

% Histogram
f1 = necParCh_histogram(nrOfThisGroup,thisParGroup,true);
plotName = ['NecessaryParChanges_histogram_',thisParGroup];
if save2pdf
    IBD_saveFigure(f1,plotName,'pdf')
end
if save2tikz    
    f1a = necParCh_histogram(nrOfThisGroup,thisParGroup,false);
    IBD_saveFigure(f1a,plotName,'tikz')
    close(f1a)
end

% Barplot
f2 = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,true,10,false);
plotName = ['NecessaryParChanges_barplot_',thisParGroup];
if save2pdf
    IBD_saveFigure(f2,plotName,'pdf')
end
if save2tikz
    f2a = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,false,10,true);
    IBD_saveFigure(f2a,plotName,'tikz')
    close(f2a)
end

% Average extent of parameter changes
f3 = necParCh_extentVsNumber(minimalPar,thisMinParIdx,nrOf,thisParGroup,N_IBD,individual_ref,true);
plotName = ['NecessaryParChanges_extentVsNumber_',thisParGroup];
if save2pdf
    IBD_saveFigure(f3,plotName,'pdf')
end
if save2tikz    
    f3a = necParCh_extentVsNumber(minimalPar,thisMinParIdx,nrOf,thisParGroup,N_IBD,individual_ref,false);
    extraCode = struct;
    extraCode.Axis = 'clip mode=individual';
    IBD_saveFigure(f3a,plotName,'tikz',extraCode)
    close(f3a)
end


%% Parameters resulting in problems if changed back
thisParGroup    = 'problems';
nrOfThisGroup   = nrOf.(thisParGroup);
thisMinParIdx   = minParIdx.(thisParGroup);

% Command line output
fprintf('In %.1f %% of patients, at least one further parameter change causes problems.\n',(1-sum(nrOf.(thisParGroup)==0)/N_IBD)*100)

% Histogram
f1 = necParCh_histogram(nrOfThisGroup,thisParGroup,true);
plotName = ['NecessaryParChanges_histogram_',thisParGroup];
if save2pdf
    IBD_saveFigure(f1,plotName,'pdf')
end
if save2tikz    
    f1a = necParCh_histogram(nrOfThisGroup,thisParGroup,false);
    IBD_saveFigure(f1a,plotName,'tikz')
    close(f1a)
end

% Barplot
f2 = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,true);
plotName = ['NecessaryParChanges_barplot_',thisParGroup];
if save2pdf
    IBD_saveFigure(f2,plotName,'pdf')
end
if save2tikz    
    f2a = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,false);
    IBD_saveFigure(f2a,plotName,'tikz')
    close(f2a)
end

%% Parameters resulting in chronic inflammation/infection if changed back
thisParGroup    = 'chronic';
nrOfThisGroup   = nrOf.(thisParGroup);
thisMinParIdx   = minParIdx.(thisParGroup);

% Command line output
fprintf('In %.1f %% of patients, at least one parameter change is required to avoid chronic infection/inflammation.\n',(1-sum(nrOf.(thisParGroup)==0)/N_IBD)*100)

% Histogram
f1 = necParCh_histogram(nrOfThisGroup,thisParGroup,true);
plotName = ['NecessaryParChanges_histogram_',thisParGroup];
if save2pdf
    IBD_saveFigure(f1,plotName,'pdf')
end
if save2tikz    
    f1a = necParCh_histogram(nrOfThisGroup,thisParGroup,false);
    IBD_saveFigure(f1a,plotName,'tikz')
    close(f1a)
end

% Barplot
f2 = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,true);
plotName = ['NecessaryParChanges_barplot_',thisParGroup];
if save2pdf
    IBD_saveFigure(f2,plotName,'pdf')
end
if save2tikz    
    f2a = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,false);
    IBD_saveFigure(f2a,plotName,'tikz')
    close(f2a)
end

%--------------------------------------------------------------------------
%% Parameter combinations
minParBool = zeros(I.nrOfPar,N_IBD);
for ind = 1:N_IBD
    minParBool(minParIdx.healthy{ind},ind) = 1;
end
minParBool = minParBool';       % each row = one individual

%--------------------------------------------------------------------------
% Search for frequent combinations of 2 or 3 parameters
nrOfPar = individual_ref.I.nrOfPar;
combi2  = nan([nrOfPar,nrOfPar]);
combi3  = nan([nrOfPar,nrOfPar,nrOfPar]);
fprintf('Analysing parameter combinations...\n')
for i = 1:nrOfPar
    %fprintf('\tParameter %i/%i\n',i,nrOfPar)
    for j = i+1:nrOfPar
        combi2(i,j) = sum(minParBool(:,i)==1 & minParBool(:,j)==1);
        for k = j+1:nrOfPar
            combi3(i,j,k) = sum(minParBool(:,i)==1 & minParBool(:,j)==1 & minParBool(:,k)==1);
        end
    end
end

% Most frequent combination of 2 parameters
[x1,x2] = find(combi2==max(max(combi2)));
fprintf('Most frequent combination of 2 parameters: %s, %s (%.1f%%)\n',individual_ref.I.parName{x1},individual_ref.I.parName{x2},max(max(combi2))/N_IBD*100)

% Most frequent combination of 3 parameters
ind = find(combi3==max(max(max(combi3))));
[x1,x2,x3] = ind2sub(size(combi3),ind);
fprintf('Most frequent combination of 3 parameters: %s, %s, %s (%.1f%%)\n',individual_ref.I.parName{x1},individual_ref.I.parName{x2},individual_ref.I.parName{x3},max(max(max(combi3)))/N_IBD*100)

%--------------------------------------------------------------------------
%% Stratify parameters into processes/cell types
[grp,grpIdx] = IBD_stratifyPars(individual_ref);

minParPerGroup = zeros(N_IBD,grpIdx.nrOfGroups);
for i = 1:grpIdx.nrOfGroups
    tmp = minParBool(:,grp==grpIdx.(grpIdx.grpName{i}));
    minParPerGroup(:,i) = sum(tmp,2);
end
minParPerGroup          = array2table(minParPerGroup,'VariableNames',grpIdx.grpName);
minParBoolPerGroup      = minParPerGroup;
minParBoolPerGroup{:,:} = ~~minParBoolPerGroup{:,:};

% Which cell types are affected how often?
fprintf('\nWhich cell types/processes are affected most often?\n')
affected = table(grpIdx.longName',nan(grpIdx.nrOfGroups,1),'VariableNames',{'name','percent'});
for i = 1:grpIdx.nrOfGroups
    affected.percent(i) = sum(minParBoolPerGroup{:,i})/N_IBD*100;
end
affected = sortrows(affected,'percent','descend');
for i = 1:grpIdx.nrOfGroups
    fprintf('%s is affected in %.1f %% of IBD patients\n',affected.name{i},affected.percent(i))
end

% Group individuals by changed processes
[indGroups,ia,ic]   = unique(minParBoolPerGroup);
nrOfGroups          = length(ia);
grpPerInd           = ic;
indGroups.nrOfInd   = zeros(nrOfGroups,1);
indGroups.grpIdx    = zeros(nrOfGroups,1);
for i = 1:nrOfGroups
    indGroups{i,'nrOfInd'}  = sum(grpPerInd==i);
    indGroups{i,'grpIdx'}   = i;
end
indGroups.percent           = indGroups.nrOfInd/N_IBD*100;
indGroups.processes         = arrayfun(@(i) join(grpIdx.grpName(find(indGroups{i,1:grpIdx.nrOfGroups}))),1:nrOfGroups)';
indGroups.processes_long    = arrayfun(@(i) join(grpIdx.longName(find(indGroups{i,1:grpIdx.nrOfGroups})),' + '),1:nrOfGroups)';
indGroups = sortrows(indGroups,'nrOfInd','descend');    % sort the groups by frequency

N = 10;
for i = 1:N
    fprintf('Combination <strong>%s</strong>: %.1f %% of IBD patients\n',indGroups.processes_long{i},indGroups.percent(i))
end

% Barplot of affected processes/cell types
f3 = figure;
h = bar(affected.percent);
h.FaceColor = IBD_myColours('histogram1');
ylabel('Frequency affected [%]')
xticklabels(affected.name);
xtickangle(45);
f3 = IBD_nicePlot(f3);
plotName = 'NecessaryParChanges_processes';
if save2pdf
    IBD_saveFigure(f3,plotName,'pdf')
end
if save2tikz    
    IBD_saveFigure(f3,plotName,'tikz')
end

%% Pieplot of most frequent combinations
N = 5;
f4 = figure;
indGroups_short             = indGroups(1:N,{'processes','processes_long','percent'});
indGroups_short{end+1,1:2}  = {'rest','rest'};
indGroups_short{end,3}      = 100-sum(indGroups_short.percent);
p = pie(indGroups_short.percent,indGroups_short.processes);
colours = IBD_colourMap('dark rainbow',N+1);
for i = 1:size(indGroups_short,1)
    p(2*i-1).FaceColor  = colours(i,:);
    p(2*i).Color        = colours(i,:);
end
f4 = IBD_nicePlot(f4);
plotName = 'NecessaryParChanges_processCombinations';
if save2pdf
    IBD_saveFigure(f4,plotName,'pdf')
end
if save2tikz
    f4a = figure;
    indGroups_short.latex = strcat('\',strrep(indGroups_short.processes,' ',''));
    % Don't forget to add the following code in your LaTeX document:
    
    p = pie(indGroups_short.percent,indGroups_short.latex);
    for i = 1:size(indGroups_short,1)
        p(2*i-1).FaceColor  = colours(i,:);
        p(2*i).Color        = colours(i,:);
    end
    extraCode.Axis = 'xmin=-1.5,xmax=1.5,ymin=-1.5,ymax=1.5,';

    IBD_saveFigure(f4a,plotName,'tikz',extraCode)
    %close(f4a)
    
end


%==========================================================================
% LOCAL FUNCTIONS

% Distribution of numbers of parameters needed
function f = necParCh_histogram(nrOfThisGroup,thisParGroup,makeTitle)
f = figure;
h = histogram(nrOfThisGroup,-0.5:1:max(nrOfThisGroup)+0.5);
h.FaceColor = IBD_myColours('histogram1');
xlabel('Number of disease-relevant parameter changes')
ylabel('Frequency')
if makeTitle
    title(['Otherwise: ',thisParGroup])
end
f = IBD_nicePlot(f);
end

%--------------------------------------------------------------------------
% Barplot of most frequently changed parameters
function f = necParCh_barplot(thisMinParIdx,thisParGroup,N_IBD,I,makeTitle,N,tikz)
allChanges                  = cat(1,thisMinParIdx{:});
nrOfTimesChanged        	= array2table(tabulate(allChanges),'VariableNames',{'idx','nr','percent'});
nrOfTimesChanged.percent   	= nrOfTimesChanged.nr/N_IBD*100;
if exist('tikz','var') && tikz
    nrOfTimesChanged.par    = IBD_translateToLatexCommands(I.parName',true);
else
    nrOfTimesChanged.par   	= I.parName';
end
nrOfTimesChanged            = sortrows(nrOfTimesChanged,'nr','descend');
if ~exist('N','var')
    N = 10;
end
f = figure;
h = barh(nrOfTimesChanged.percent(N:-1:1));
yticklabels(nrOfTimesChanged.par(N:-1:1));
h.FaceColor = IBD_myColours('histogram1');
if exist('tikz','var') && tikz
    set(gca,'TickLabelInterpreter','latex')
end
xlabel('Frequency of parameter among disease-relevant [%]')
if makeTitle
    title(['Otherwise: ',thisParGroup])
end
f = IBD_nicePlot(f);
end

%--------------------------------------------------------------------------
% Average extent of change vs number of changes
function f = necParCh_extentVsNumber(minimalPar,thisMinParIdx,nrOf,thisParGroup,N_IBD,individual_ref,makeTitle,includeProblems)
extent = nan(1,N_IBD);
for i = 1:N_IBD
    change = minimalPar(thisMinParIdx{i},i)./individual_ref.par(thisMinParIdx{i})';
    change(change<1) = 1./change(change<1);
    extent(i) = mean(change);
end
f = figure;
hold on
if exist('includeProblems','var') && includeProblems
    % Those with problems/chronic
    plot(nrOf.healthy(nrOf.chronic>0 | nrOf.problems>0),extent(~(~nrOf.chronic & ~nrOf.problems)),'x','Color',IBD_myColours('crosses2'));
end

% Those without problems/chronic
xvalues = nrOf.healthy(nrOf.chronic==0 & nrOf.problems==0);
yvalues = extent(~nrOf.chronic & ~nrOf.problems);

reducePoints = false;
if reducePoints
    idx = 1:5:length(xvalues);
else
    idx = 1:length(xvalues);
end
plot(xvalues(idx),yvalues(idx),'x','Color',IBD_myColours('crosses1'));

xlabel('Number of parameter changes')
ylabel('Average extent of parameter changes')
if makeTitle
	title(['Otherwise: ',thisParGroup])
end
if exist('includeProblems','var') && includeProblems
    legend({'+ problems/chronic','complete'})
end

% Add average line
xnumbers        = sort(unique(xvalues));
averageExtent   = nan(size(xnumbers));
for i = 1:length(xnumbers)
    if sum(xvalues==xnumbers(i))<5
        break
    end
    averageExtent(i) = mean(yvalues(xvalues==xnumbers(i)));
end
plot(xnumbers(~isnan(averageExtent)),averageExtent(~isnan(averageExtent)),'k');

f = IBD_nicePlot(f);

end

%--------------------------------------------------------------------------

