%==========================================================================
% IBD_AnalyseResponders
%==========================================================================
% Compare responders and non-responders (constant treatment effects)
% 2 October 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

whichTreatment = 'integrin';

% Load data
load(strrep(fileNameList.CombinePopulation,'xxx','IBD'),'ss0','ssMI','par','IBDtype','individual_ref');
load(fileNameList.AnalyseConstantTreatment.(whichTreatment),'responders','nonResponders','responders_relapse','responders_longTerm','exclude','CDEIS')
load(fileNameList.ConstantTreatment.(whichTreatment),'ssT24');

N_IBD   = size(ss0,2);
I       = individual_ref.I;
nrOfEtas = length(responders);


%--------------------------------------------------------------------------
for e = 1:nrOfEtas
    assert(length(nonResponders{e})+length(responders_longTerm{e})+length(responders_relapse{e})+length(exclude) == N_IBD,'Responders and non-responders do not add up to number of patients!')
end

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
colours         = IBD_colourMap('dark rainbow',4);  % non-responders - responders/relapse - responders/longterm
colours(4,:)    = mean(colours(2:3,:),1);           % responders (total)

%%%
e = 3;      % eta=0.3
%%%

responders          = responders{e};
nonResponders       = nonResponders{e};
responders_longTerm = responders_longTerm{e};
responders_relapse  = responders_relapse{e};

%--------------------------------------------------------------------------
% Match responders and non-responders by CDEIS
matchCDEIS = false;

if matchCDEIS
    CDEISbeforeTreatment    = round(CDEIS.ssMI);
    responderTable          = tabulate(round(CDEISbeforeTreatment(responders)));
    nonResponderTable       = tabulate(round(CDEISbeforeTreatment(nonResponders)));
    
    responderTable   (responderTable(end,1)+1:nonResponderTable(end,1),1) = responderTable(end,1)+1:nonResponderTable(end,1);
    nonResponderTable(nonResponderTable(end,1)+1:responderTable(end,1),1) = nonResponderTable(end,1)+1:responderTable(end,1);
    
    % Adjust responders & non-responders
    responders_new      = [];
    nonResponders_new   = [];
    for i = responderTable(:,1)'
        CDEIS_i         = find(CDEISbeforeTreatment==i);
        nr_i            = min(responderTable(i,2),nonResponderTable(i,2));
        responders_i    = intersect(responders,CDEIS_i);
        responders_new 	= [responders_new;responders_i(1:nr_i)];
        nonResponders_i = intersect(nonResponders,CDEIS_i);
        nonResponders_new = [nonResponders_new;nonResponders_i(1:nr_i)];
    end
    responders_new      = sort(responders_new);
    nonResponders_new   = sort(nonResponders_new);
    
    % Adjust responders with relapse
    responders_relapse  = intersect(responders_relapse,responders_new);
    
    % Adjust responders without relapse
    responders_longTerm = intersect(responders_longTerm,responders_new);
    
    responders          = responders_new;
    nonResponders       = nonResponders_new;
    
end

%--------------------------------------------------------------------------
% Compare CDEIS before treatment between responders and non-responders
f1 = figure;
hold on
edges = floor(min(CDEIS.ssMI(setdiff(1:length(CDEIS.ssMI),exclude)))):1:ceil(max(CDEIS.ssMI(setdiff(1:length(CDEIS.ssMI),exclude))));
histogram(CDEIS.ssMI(responders),edges,'EdgeColor',mean(colours(2:3,:),1),'FaceColor',mean(colours(2:3,:),1),'FaceAlpha',0.3);
histogram(CDEIS.ssMI(nonResponders),edges,'EdgeColor',colours(1,:),'FaceColor',colours(1,:),'FaceAlpha',0.3);
xlabel('CDEIS')
legend({'responders','non-responders'})
f1 = IBD_nicePlot(f1);
if save2tikz || save2pdf
    IBD_saveFigure(f1,'CDEIS_respondersVsNonresponders',save2tikz)
end

%--------------------------------------------------------------------------
% Compare CDEIS before treatment between responders with/without relapse and non-responders
f2 = figure;
hold on
edges = floor(min(CDEIS.ssMI(setdiff(1:length(CDEIS.ssMI),exclude)))):1:ceil(max(CDEIS.ssMI(setdiff(1:length(CDEIS.ssMI),exclude))));
histogram(CDEIS.ssMI(responders_longTerm),edges,'EdgeColor',mean(colours(3,:),1),'FaceColor',mean(colours(3,:),1),'FaceAlpha',0.3);
histogram(CDEIS.ssMI(responders_relapse),edges,'EdgeColor',mean(colours(2,:),1),'FaceColor',mean(colours(2,:),1),'FaceAlpha',0.3);
histogram(CDEIS.ssMI(nonResponders),edges,'EdgeColor',colours(1,:),'FaceColor',colours(1,:),'FaceAlpha',0.3);
xlabel('CDEIS before treatment')
legend({'responders without relapse','responders with relapse','non-responders'})
f2 = IBD_nicePlot(f2);
if save2tikz || save2pdf
    IBD_saveFigure(f2,'CDEIS_respondersRelapseVsNonresponders',save2tikz)
end

%--------------------------------------------------------------------------
% Influence of CDEIS at end of treatment on relapse
f3 = figure;
hold on
edges = floor(min(CDEIS.ssT24(e,responders))):0.2:ceil(max(CDEIS.ssT24(e,responders)));
histogram(CDEIS.ssT24(e,responders_longTerm),edges,'EdgeColor',mean(colours(3,:),1),'FaceColor',mean(colours(3,:),1),'FaceAlpha',0.3);
histogram(CDEIS.ssT24(e,responders_relapse),edges,'EdgeColor',mean(colours(2,:),1),'FaceColor',mean(colours(2,:),1),'FaceAlpha',0.3);
xlabel('CDEIS at end of treatment')
legend({'no relapse','relapse'})
f3 = IBD_nicePlot(f3);
if save2tikz || save2pdf
    IBD_saveFigure(f3,'CDEIS_RelapseOverCDEISatEOT',save2tikz)
end

%--------------------------------------------------------------------------
% Parameter differences between responders and non-responders
classDefinition.I.className = {'nonresponders','responders_relapse','responders_noRelapse','responders'};
classDefinition.I.nrOfClasses = length(classDefinition.I.className);
parX.responders             = par(:,responders);
parX.nonresponders          = par(:,nonResponders);
parX.responders_relapse     = par(:,responders_relapse);
parX.responders_noRelapse   = par(:,responders_longTerm);

parComparison = array2table(nan(individual_ref.I.nrOfPar,classDefinition.I.nrOfClasses-1),'VariableNames',classDefinition.I.className(2:end),'RowNames',IBD_uniqueParName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing parameter distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfPar
        [~,parComparison{p,thisClass}] = kstest2(parX.nonresponders(p,:),parX.(thisClass)(p,:));
    end
end

[~,parIdx] = sortrows(parComparison,'responders');
N = 25;

f4 = IBD_plotParDist(parX,individual_ref,{'responders','nonresponders'},parIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f4,'ParDist_responders',save2tikz)
end

%--------------------------------------------------------------------------
% IBD steady state differences between responders and non-responders
stateX.responders             = ssMI(:,responders);
stateX.nonresponders          = ssMI(:,nonResponders);
stateX.responders_relapse     = ssMI(:,responders_relapse);
stateX.responders_noRelapse   = ssMI(:,responders_longTerm);

stateComparison = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1),'VariableNames',classDefinition.I.className(2:end),'RowNames',IBD_uniqueStateName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing state distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfStatesAdd
        [~,stateComparison{p,thisClass}] = kstest2(stateX.nonresponders(p,:),stateX.(thisClass)(p,:));
    end
end

[~,stateIdx] = sortrows(stateComparison,'responders');
N = 25;

f5 = IBD_plotParDist(stateX,individual_ref,{'responders','nonresponders'},stateIdx(1:N),classDefinition);
if save2tikz || save2pdf
    IBD_saveFigure(f5,'EOTstateDist_responders',save2tikz)
end

%--------------------------------------------------------------------------
