%==========================================================================
% IBD_CompareNecessaryParChangesResponders
%==========================================================================
% Compare necessary parameter changes for IBD between responders and
% non-responders to single treatments
% 13 January 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombineNecessaryParChanges,'classWhenSetBack','minimalParIdx');
load(fileNameList.ClinicalIBDpopulation,'include','individual_ref');
I = individual_ref.I;

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end


%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Only clinical IBD population (CDEIS<6)
classWhenSetBack    = classWhenSetBack(:,include);
minimalParIdx       = minimalParIdx(include);

%--------------------------------------------------------------------------
% Distinguish necessary parameters by class when set back
N_IBD = sum(include);
for ind = 1:N_IBD
    thisMinimalParIdx           = minimalParIdx{ind};
    thisClassWhenSetBack        = classWhenSetBack(thisMinimalParIdx,ind);
    minParIdx.healthy{ind}      = thisMinimalParIdx(thisClassWhenSetBack==1);
    minParIdx.problems{ind}     = thisMinimalParIdx(thisClassWhenSetBack==0);
    minParIdx.chronic{ind}      = thisMinimalParIdx(thisClassWhenSetBack>2);
    if ~sum(thisClassWhenSetBack==2)==0
        error('Something went wrong here!')
    end
end

%--------------------------------------------------------------------------
% Compare only parameters resulting in healthy,
% between responders and non-responders
% to each scenario

thisParGroup    = 'healthy';
thisMinParIdx   = minParIdx.(thisParGroup);

N_IBD = length(thisMinParIdx);
minParBool = zeros(I.nrOfPar,N_IBD);
for ind = 1:N_IBD
    minParBool(thisMinParIdx{ind},ind) = 1;
end

f = figure;
n = 1;
m = 7;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

percentChanged = struct;

for i = 1:length(scenarios)
    scenario = scenarios{i};
    
    % Response rate 30 %        % Change to 50 % to see if same results
    if isnan(S.(scenario).idx30)
        continue
    end
    responders = S.(scenario).CDEIS.ssEOT(S.(scenario).idx30,:)<4;
    nonresponders = ~responders;
    
    subplot(m,n,i)
    ax = gca;
    options = struct;
    options.tikz = save2tikz;
  	options.omitLegend = true;
    if i<7
        options.omitXLabel = true;
    else
        options.omitXLabel = false;
    end
    options.omitXTicks = true;
    if i==4
        options.omitYLabel = false;
    else
        options.omitYLabel = true;
    end
    options.title = scenarioNames{i};
    [~,percentChanged.(scenario)] = compareBarplot(thisMinParIdx,responders,I,10,options,ax,minParBool);
    
end

f = IBD_nicePlot(f);

if save2pdf
    IBD_saveFigure(f,'NecParChanges_Responders','pdf')
end
if save2tikz
    IBD_saveFigure(f,'NecParChanges_Responders','tikz')
end


%==========================================================================
% LOCAL FUNCTIONS

% Barplot of most frequently changed parameters
function [f,percentChanged] = compareBarplot(thisMinParIdx,responders,I,N,options,ax,minParBool)

if ~exist('options','var')
    options = struct;
end

% Full population:
allChanges                      = cat(1,thisMinParIdx{:});
tmpTable                        = array2table(tabulate(allChanges),'VariableNames',{'idx','nr','percent'});
percentChanged                  = tmpTable(:,'idx');
percentChanged.all              = tmpTable.nr/length(thisMinParIdx)*100;

% Responders:
allChanges                      = cat(1,thisMinParIdx{responders});
tmpTable                        = array2table(tabulate(allChanges),'VariableNames',{'idx','nr','percent'});
percentChanged.responders       = tmpTable.nr/sum(responders)*100;

% Non-responders:
allChanges                      = cat(1,thisMinParIdx{~responders});
tmpTable                        = array2table(tabulate(allChanges),'VariableNames',{'idx','nr','percent'});
percentChanged.nonresponders   	= tmpTable.nr/sum(~responders)*100;

if isfield(options,'tikz') && options.tikz
    percentChanged.par          = IBD_translateToLatexCommands(I.parName',true);
    percentChanged.parName      = I.parName';
else
    percentChanged.par          = I.parName';
    percentChanged.parName      = I.parName';
end

% Chi square test for difference
percentChanged.pvalue = nan(size(percentChanged,1),1);
if exist('minParBool','var')
    for i = 1:size(percentChanged,1)
        [~,~,percentChanged.pvalue(i)] = crosstab(minParBool(I.(percentChanged.parName{i}),:),responders);
    end
end

% Relative difference respondes/nonresponders
percentChanged.diff  = (percentChanged.responders-percentChanged.nonresponders)./percentChanged.all;

if isfield(options,'sortBy')
    sortBy = options.sortBy;
else
    sortBy = 'all';
end
percentChanged   	= sortrows(percentChanged,sortBy,'descend','MissingPlacement','last');

if ~exist('N','var')
    N = 10;
end

if ~exist('ax','var') || isempty(ax)
    f = figure;
    ax = gca;
    makeFigure = true;
    hold(ax,'on')
else
    makeFigure = false;
    hold on
end

b = bar(ax,percentChanged{1:N,{'responders','nonresponders'}});
b(1).FaceColor = IBD_myColours('responders');
b(2).FaceColor = IBD_myColours('nonresponders');
if ~isfield(options,'omitXLabel') || ~options.omitXLabel
    xticks(ax,1:N)
    xticklabels(ax,percentChanged.par(1:N))
    xtickangle(45)
    if isfield(options,'tikz') && options.tikz
        set(ax,'TickLabelInterpreter','latex')
    end
else
    xticklabels(ax,{})
end
if ~isfield(options,'omitYLabel') || ~options.omitYLabel
    ylabel('Frequency of parameter changed [%]')
end
if ~isfield(options,'omitYTicks') || ~options.omitYTicks
    yticks(ax,[0 50 100])
else
    yticks(ax,[])
end
if ~isfield(options,'omitLegend') || ~options.omitLegend
    legend(ax,{'responders','nonresponders'})
end
if ~isfield(options,'title')
    options.title = '';
end
if ~isempty(options.title)
    if isfield(options,'tikz') && options.tikz
        yl = ylim;
        xl = xlim;
        t = title(options.title,'Interpreter','latex','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
        text(xl(1),(yl(2)-yl(1))*1.1+yl(1),t.String,'HorizontalAlignment',t.HorizontalAlignment,'FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('')
    else
        title(options.title)
    end
end

if exist('tikz','var') && tikz
    set(gca,'TickLabelInterpreter','latex')
end

if makeFigure
    f = IBD_nicePlot(f);
else
    f = nan;
end

% Command line output:
% fprintf('%s\n',options.title)
% fprintf('P values:\n')
% for i = 1:N
%     fprintf('\t%s: %.1e\n',percentChanged.parName{i},percentChanged.pvalue(i))
% end

% for i = 1:N
%     if percentChanged.pvalue(i)>0.001
%         fprintf('%s: %s - %.1e\n',options.title,percentChanged.parName{i},percentChanged.pvalue(i))
%     end
% end

end

%--------------------------------------------------------------------------

