%==========================================================================
% IBD_CompareParametersResponders
%==========================================================================
% Compare parameter distributions between non-responders and responders for
% the different single treatments (with 50 % and 30 % response rates)
% 8 January 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
load(fileNameList.ClinicalIBDpopulation,'par','individual_ref');
scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end

%--------------------------------------------------------------------------
% Compare parameter distributions between responders and non-responders
defTable 	= array2table(nan(individual_ref.I.nrOfPar,length(scenarios)),'VariableNames',scenarios,'RowNames',IBD_uniqueParName(individual_ref.I));
t_KS_50     = defTable;
p_KS_50     = defTable;
t_cor_50    = defTable;
p_cor_50    = defTable;
t_KS_30     = defTable;
p_KS_30     = defTable;
t_cor_30    = defTable;
p_cor_30    = defTable;

for i = 1:length(scenarios)
    scenario = scenarios{i};
    fprintf('Comparing parameter distributions of responders and non-responders to %s...\n',scenarioNames{i})
    
    % Response rate 30 %
    if isnan(S.(scenario).idx30)
        continue
    end
    responders = S.(scenario).CDEIS.ssEOT(S.(scenario).idx30,:)<4;
    nonresponders = ~responders;
    for p = 1:individual_ref.I.nrOfPar
        [~,p_KS_30{p,scenario},t_KS_30{p,scenario}]    = kstest2(par(p,responders),par(p,nonresponders));
    end
    [t_cor_30.(scenario),p_cor_30.(scenario)] = corr([par(:,responders)';par(:,nonresponders)'],[ones(sum(responders),1);zeros(sum(nonresponders),1)]);
    
    % Response rate 50 %
    if isnan(S.(scenario).idx50)
        continue
    end
    responders = S.(scenario).CDEIS.ssEOT(S.(scenario).idx50,:)<4;
    nonresponders = ~responders;
    for p = 1:individual_ref.I.nrOfPar
        [~,p_KS_50{p,scenario},t_KS_50{p,scenario}]    = kstest2(par(p,responders),par(p,nonresponders));
    end
    [t_cor_50.(scenario),p_cor_50.(scenario)] = corr([par(:,responders)';par(:,nonresponders)'],[ones(sum(responders),1);zeros(sum(nonresponders),1)]);
end

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'p_cor_30','t_cor_30','p_KS_30','t_KS_30','p_cor_50','t_cor_50','p_KS_50','t_KS_50','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------