%==========================================================================
% IBD_CompareStates
%==========================================================================
% Compare pre-trigger steady state distributions between classes
% Return: measure of difference for each state variable between healthy and
% other classes, steady state values for 20 most different parameters
% 16 September 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();
ss0 = struct;

% Load data
for i = classDefinition.I.allClasses
    thisClass     	= classDefinition.I.className{i};
    S           	= load(strrep(fileNameList.CombinePopulation,'xxx',thisClass),'ss0','individual_ref');
    I            	= S.individual_ref.I;
    allStates   	= [S.individual_ref.stateNames,S.individual_ref.addStateNames];
    
    % Sum up transit compartments
    ss0_tmp                     = S.ss0;
    for j = 1:length(allStates)
        state                   = allStates{j};
        idx                     = reshape(I.(state),1,[]);
        ss0_tmp(idx(1),:)       = sum(ss0_tmp(idx(:),:),1);
        ss0_tmp(idx(2:end),:)   = 0;
    end
    
    ss0.(thisClass) = ss0_tmp;
end
individual_ref      = S.individual_ref;

%--------------------------------------------------------------------------
% Compare parameter distributions between classes (vs healthy)
t_KS    = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueStateName(individual_ref.I));
p_KS    = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueStateName(individual_ref.I));
t_cor   = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueStateName(individual_ref.I));
p_cor   = array2table(nan(individual_ref.I.nrOfStatesAdd,classDefinition.I.nrOfClasses-1+2),'VariableNames',[classDefinition.I.className(2:end),'IBDvs_chronic_inflammation','IBDvs_chronic_infection'],'RowNames',IBD_uniqueStateName(individual_ref.I));
for i = 2:classDefinition.I.nrOfClasses
    thisClass = classDefinition.I.className{i};
    fprintf('Comparing pre-trigger steady state distributions of %s to healthy...\n',thisClass)
    for p = 1:individual_ref.I.nrOfStatesAdd
        [~,p_KS{p,thisClass},t_KS{p,thisClass}]    = kstest2(ss0.healthy(p,:),ss0.(thisClass)(p,:));
    end
    [t_cor.(thisClass),p_cor.(thisClass)] = corr([ss0.(thisClass)';ss0.healthy'],[ones(size(ss0.(thisClass),2),1);zeros(size(ss0.healthy,2),1)]);
end

% IBD vs chronic inflammation/infection
[t_cor.IBDvs_chronic_inflammation,p_cor.IBDvs_chronic_inflammation] = corr([ss0.IBD';ss0.chronic_inflammation'],[ones(size(ss0.IBD,2),1);zeros(size(ss0.chronic_inflammation,2),1)]);
[t_cor.IBDvs_chronic_infection,   p_cor.IBDvs_chronic_infection]    = corr([ss0.IBD';ss0.chronic_infection'   ],[ones(size(ss0.IBD,2),1);zeros(size(ss0.chronic_infection,   2),1)]);

% IBD vs healthy
p_table                          	= p_cor(:,'IBD');
p_table.Properties.VariableNames	= {'p_cor'};
p_table.p_KS                        = p_KS.IBD;
p_table.t_cor                       = t_cor.IBD;
p_table.t_KS                        = t_KS.IBD;
p_table.absCor                      = abs(p_table.t_cor);
[p_table_sortedCor,idx_cor]         = sortrows(p_table,'absCor','descend','MissingPlacement','last');
[p_table_sortedKS, idx_KS]          = sortrows(p_table,'t_KS','descend','MissingPlacement','last');

N = 20;     % return all parameters that are among the lowest N p values in either measure
idx_all = union(idx_cor(1:N),idx_KS(1:N));

returnStates.healthy        	= ss0.healthy;
returnStates.IBD                = ss0.IBD;
idx_rest                        = setdiff(1:individual_ref.I.nrOfStates,idx_all);
returnStates.healthy(idx_rest,:)= zeros(length(idx_rest),size(ss0.healthy,2));
returnStates.IBD(idx_rest,:)    = zeros(length(idx_rest),size(ss0.IBD,2));
returnStates.healthy            = sparse(returnStates.healthy);
returnStates.IBD                = sparse(returnStates.IBD);
ss0                             = returnStates;

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'p_cor','t_cor','p_KS','t_KS','p_table','ss0','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------