%==========================================================================
% IBD_CompareStatesCytoS1PRResponders
%==========================================================================
% Compare pre-treatment steady state distributions between responders to
% cytokine inhibitor and responders to S1PR modulator
% 19 April 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
load(fileNameList.ClinicalIBDpopulation,'ssMI','individual_ref');
scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end

%--------------------------------------------------------------------------
% Sum up transit compartments
I                       = individual_ref.I;
allStates               = [individual_ref.stateNames,individual_ref.addStateNames];
for i = 1:length(allStates)
    state               = allStates{i};
    idx                 = reshape(I.(state),1,[]);
    ssMI(idx(1),:)      = sum(ssMI(idx(:),:),1);
    ssMI(idx(2:end),:)  = 0;
end

%--------------------------------------------------------------------------
% Compare pre-treatment steady state distributions between responders and non-responders
defTable 	= array2table(nan(individual_ref.I.nrOfStatesAdd,length(scenarios)),'VariableNames',scenarios,'RowNames',IBD_uniqueStateName(individual_ref.I));
t_KS_50     = defTable;
p_KS_50     = defTable;
t_cor_50    = defTable;
p_cor_50    = defTable;
t_KS_30     = defTable;
p_KS_30     = defTable;
t_cor_30    = defTable;
p_cor_30    = defTable;

% 30 %
respondersCyto = S.cytokineInhibitor.CDEIS.ssEOT(S.cytokineInhibitor.idx30,:)<4;
respondersS1PR = S.S1PRmodulator.CDEIS.ssEOT(S.S1PRmodulator.idx30,:)<4;
respondersBoth = respondersCyto & respondersS1PR;
respondersCyto = respondersCyto & ~respondersBoth;
respondersS1PR = respondersS1PR & ~respondersBoth;
for p = 1:individual_ref.I.nrOfPar
    [~,p_KS_30{p,'S1PRmodulator'},t_KS_30{p,'S1PRmodulator'}]    = kstest2(ssMI(p,respondersCyto),ssMI(p,respondersS1PR));
end
[t_cor_30.S1PRmodulator,p_cor_30.S1PRmodulator] = corr([ssMI(:,respondersCyto)';ssMI(:,respondersS1PR)'],[ones(sum(respondersCyto),1);zeros(sum(respondersS1PR),1)]);

% 50 %
respondersCyto = S.cytokineInhibitor.CDEIS.ssEOT(S.cytokineInhibitor.idx50,:)<4;
respondersS1PR = S.S1PRmodulator.CDEIS.ssEOT(S.S1PRmodulator.idx50,:)<4;
respondersBoth = respondersCyto & respondersS1PR;
respondersCyto = respondersCyto & ~respondersBoth;
respondersS1PR = respondersS1PR & ~respondersBoth;
for p = 1:individual_ref.I.nrOfPar
    [~,p_KS_50{p,'S1PRmodulator'},t_KS_50{p,'S1PRmodulator'}]    = kstest2(ssMI(p,respondersCyto),ssMI(p,respondersS1PR));
end
[t_cor_50.S1PRmodulator,p_cor_50.S1PRmodulator] = corr([ssMI(:,respondersCyto)';ssMI(:,respondersS1PR)'],[ones(sum(respondersCyto),1);zeros(sum(respondersS1PR),1)]);

%--------------------------------------------------------------------------
% Save
fullFileName    = ['Data/',thisFile,'_',date,'.mat'];
save(fullFileName,'p_cor_30','t_cor_30','p_KS_30','t_KS_30','p_cor_50','t_cor_50','p_KS_50','t_KS_50','ssMI','respondersCyto','respondersS1PR','individual_ref');
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile) = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------