%==========================================================================
% IBD_CorrelationOfReponseToIBDtype
%==========================================================================
% Analyse the influence of the IBD type on the response to different single
% treatments
% 20 January 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

% Load data
load(fileNameList.ClinicalIBDpopulation,'IBDtype','individual_ref');
scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
responsePerIBDtype = table('Size',[10,0]);

% 1. Correlation coefficient between IBD type and response
rho = struct;
pval = struct;

% 2. Histogram of IBD type in responders and non-responders
f1 = figure;
n = 1;
m = 7;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

for i = 1:length(scenarios)
    scenario = scenarios{i};
    
    % Response rate 30 %
    if isnan(S.(scenario).idx30)
        continue
    end
    responders = S.(scenario).CDEIS.ssEOT(S.(scenario).idx30,:)<4;
    nonresponders = ~responders;
    
    [rho.(scenario),pval.(scenario)] = corr([IBDtype(responders)';IBDtype(nonresponders)'],[ones(sum(responders),1);zeros(sum(nonresponders),1)]);
    
    subplot(m,n,i)
    histogram(IBDtype(responders),0.5:1:10.5,'FaceColor',IBD_myColours('responders'),'FaceAlpha',0.5,'Normalization','probability')
    hold on
    histogram(IBDtype(nonresponders),0.5:1:10.5,'FaceColor',IBD_myColours('nonresponders'),'FaceAlpha',0.5,'Normalization','probability')
    
    if i==7
        xticks(1:max(IBDtype))
        xlabel('IBD type')
    else
        xticks([])
    end
    
    ylim([0 0.3])
    yticks([])
    title(scenarioNames{i})
    
    % Response per IBD type and treatment
    response = nan(10,1);
    for type = 1:10
        response(type) = sum(IBDtype(responders)==type)/sum(IBDtype==type);
    end
    responsePerIBDtype.(scenario) = response;
end

f1 = IBD_nicePlot(f1);

if save2pdf
    IBD_saveFigure(f1,'IBDtype_Responders','pdf')
end
if save2tikz
    IBD_saveFigure(f1,'IBDtype_Responders','tikz')
end

% Response per IBD type
rho2 = struct;
pval2 = struct;
f2 = figure;
n = 3;
m = 3;
set(f2, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);
for i = 1:length(scenarios)-1
    subplot(m,n,i);
    if ismember(scenarios{i},responsePerIBDtype.Properties.VariableNames)
        plot(1:10,responsePerIBDtype.(scenarios{i})*100,'x','Color',IBD_myColours('line1'))
        ylim([0 40])
        yl = ylim;
        xl = xlim;
        t = title([scenarioNames{i},'\phantom{y}'],'Interpreter','latex','HorizontalAlignment','left','Position',[xl(1) (yl(2)-yl(1))*1.1+yl(1) 0]);
        text(xl(1),(yl(2)-yl(1))*1.22+yl(1),t.String,'HorizontalAlignment',t.HorizontalAlignment,'FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
        title('')
        xlabel({'IBD type',''})
        [rho2.(scenarios{i}),pval2.(scenarios{i})] = corr((1:10)',responsePerIBDtype.(scenarios{i}));
        text(4,5,sprintf('\\rho = %.3f',rho.(scenarios{i})))
        if ismember(i,[1 4 7])
            ylabel('Response rate [%]')
        end
    end
end
f2 = IBD_nicePlot(f2);
if save2pdf
    IBD_saveFigure(f2,'ResponsePerIBDtype','pdf')
end
if save2tikz
    IBD_saveFigure(f2,'ResponsePerIBDtype','tikz')
end