%==========================================================================
% IBD_CorrelationsOfResponsiveness
%==========================================================================
% Analyse correlations of responsiveness of the patients to different
% single treatments
% 15 December 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

scenarios = fieldnames(fileNameList.constantTreatment)';

% Load data
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
%% Analysis of correlations for targeted response of 30% and 50%
targetResponseValues = [30 50];

for r = 1:length(targetResponseValues)
    targetResponse = targetResponseValues(r);
    
    % Pairwise correlations
    pairwise.(['r',num2str(targetResponse)])        = struct;
    emptyTable                                      = table('Size',[length(scenarios),length(scenarios)],'VariableTypes',repmat({'double'},[1 length(scenarios)]),...
        'VariableNames',scenarios,'RowNames',scenarios);
    difference.(['r',num2str(targetResponse)])      = emptyTable;
    intersection.(['r',num2str(targetResponse)])    = emptyTable;
    union.(['r',num2str(targetResponse)])           = emptyTable;
    condProb.(['r',num2str(targetResponse)])        = emptyTable;
    correlation.(['r',num2str(targetResponse)])  	= emptyTable;
    
    for i = 1:length(scenarios)
        pairwise.(['r',num2str(targetResponse)]).(scenarios{i}) = struct;
        for j = 1:length(scenarios)
            
            if isnan(S.(scenarios{i}).idx(r)) || isnan(S.(scenarios{j}).idx(r))
                continue    % when for one of the treatments this response rate was not achieved
            end
            
            A = S.(scenarios{i}).response(S.(scenarios{i}).idx(r),:);
            B = S.(scenarios{j}).response(S.(scenarios{j}).idx(r),:);
            
            responseTable = table('Size',[3 3],'VariableTypes',repmat({'double'},[1 3]),...
                'VariableNames',{[scenarios{j},'_responders'],[scenarios{j},'_nonresponders'],[scenarios{j},'_total']},...
                'RowNames',{[scenarios{i},'_responders'],[scenarios{i},'_nonresponders'],[scenarios{i},'_total']});
            
            responseTable{1,1} = sum( A &  B);
            responseTable{1,2} = sum( A & ~B);
            responseTable{2,1} = sum(~A &  B);
            responseTable{2,2} = sum(~A & ~B);
            responseTable{3,1} = sum(responseTable{1:2,1});
            responseTable{3,2} = sum(responseTable{1:2,2});
            responseTable{1,3} = sum(responseTable{1,1:2});
            responseTable{2,3} = sum(responseTable{2,1:2});
            assert(sum(responseTable{3,1:2})==sum(responseTable{1:2,3}))
            % Conditional probability
            condProb.(['r',num2str(targetResponse)]){scenarios{i},scenarios{j}} = responseTable{2,1}/responseTable{2,3};
            % Normalise to sum = 1
            responseTable{3,3} = sum(responseTable{3,1:2});
            responseTable{:,:} = responseTable{:,:}/responseTable{3,3};
            pairwise.(['r',num2str(targetResponse)]).(scenarios{i}).(scenarios{j}) = responseTable;
            difference.(['r',num2str(targetResponse)]){scenarios{i},scenarios{j}} = min([responseTable{1,2},responseTable{2,1}]);
            intersection.(['r',num2str(targetResponse)]){scenarios{i},scenarios{j}} = responseTable{1,1};
            union.(['r',num2str(targetResponse)]){scenarios{i},scenarios{j}} = 1-responseTable{2,2};
            correlation.(['r',num2str(targetResponse)]){scenarios{i},scenarios{j}} = corr(A',B');
        end
    end
    
    % Heatmap of difference between responsiveness
    f1 = figure;
    % Exclude rows/columns with only zeros
    exclude = all(condProb.(['r',num2str(targetResponse)]){:,:}==0);
    heatmap(scenarios(~exclude),scenarios(~exclude),condProb.(['r',num2str(targetResponse)]){~exclude,~exclude}*100);
    ax = gca;
    axp = struct(ax);
    axp.Axes.XAxisLocation = 'top';
    title(sprintf('%% Response to B of non-responders to A (single response: %i %%)',targetResponse))
    xlabel('Treatment B')
    ylabel('Treatment A')
    if save2pdf
        IBD_saveFigure(f1,['correlationHeatmap_r',num2str(targetResponse)],'pdf')
    end
    fprintf('Response to B (columns) of non-responders to A (rows) for single response rates of %i%%:\n',targetResponse)
    disp(scenarios(~exclude))
    disp(condProb.(['r',num2str(targetResponse)]){~exclude,~exclude}*100)
end

%--------------------------------------------------------------------------
%% Patients responding to all/none of the single treatments
% with methotrexate
singleTreatments = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};

% without methotrexate
singleTreatments = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','azathioprine','antibiotics'};
N_IBD = size(S.cytokineInhibitor.response,2);
response30 = nan(length(singleTreatments),N_IBD);
response50 = nan(length(singleTreatments),N_IBD);
for i = 1:length(singleTreatments)
    scenario    = singleTreatments{i};
    if ~isnan(S.(scenario).idx30)
        response30(i,:)  = S.(scenario).response(S.(scenario).idx30,:);
    end
    if ~isnan(S.(scenario).idx50)
        response50(i,:)  = S.(scenario).response(S.(scenario).idx50,:);
    end
end
% All single treatments (except antibiotics/...)
all30   = sum(sum(response30,1,'omitnan')==sum(~isnan(response30(:,1))))/N_IBD*100;
none30  = sum(sum(response30,1,'omitnan')==0)/N_IBD*100;
all50   = sum(sum(response50,1,'omitnan')==sum(~isnan(response50(:,1))))/N_IBD*100;
none50  = sum(sum(response50,1,'omitnan')==0)/N_IBD*100;

%--------------------------------------------------------------------------