%==========================================================================
% IBD_ExamplePatients
%==========================================================================
% Exemplary patient profiles
% - mucosal injury
% - treatment with cytokine inhibitor
% 9 December 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.ClinicalIBDpopulation)
scenario = 'cytokineInhibitor';
load(fileNameList.constantTreatment_CDEIS.(scenario),'options','effects','CDEIS','FCP','individual_ref')
I = individual_ref.I;

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Define treatment: cytokine inhibitor, response rate 50 %
eta     = 0.2258;       % see IBD_treatmentDatabase
% eta = options.eta50;
i_eta   = find(options.etas==eta);

% Responders:
responders      = CDEIS.ssEOT(i_eta,:)<4;
nonresponders   = CDEIS.ssEOT(i_eta,:)>=4;
relapse         = CDEIS.ssPT(i_eta,:)>=4 & CDEIS.ssEOT(i_eta,:)<4;

%--------------------------------------------------------------------------
% Requirements:
% 2 patients, different IBD types, 1 responder/1 non-responder
% Cytokine inhibitor with eta=0.2258 --> response rate 50 %
% IBD type 2, IBD type 9

patientA = 28;  % IBD type 8, responder, no relapse
patientB = 31;  % IBD type 3, non-responder

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
individual(1)                                   = individual_ref;
individual(1).par                               = par(:,patientA)';
individual(1).infection.epiDamage               = 1;
individual(1).infection.tisDamage               = 1;
individual(1).title                             = 'Patient A';

individual(2)                                   = individual_ref;
individual(2).par                               = par(:,patientB)';
individual(2).infection.epiDamage               = 1;
individual(2).infection.tisDamage               = 1;
individual(2).title                             = 'Patient B';

individual(3)                                   = individual(1);
individual(4)                                   = individual(2);
for i = [3 4]
   individual(i).infection.epiDamage          	= 0.5;
   individual(i).infection.tisDamage          	= 0.5;
end

%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run mucosal injury
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind),true);
end

%--------------------------------------------------------------------------
% Plot mucosal injury
p           = IBD_plotDatabase('overview',individual_ref);
f_MI        = IBD_plotIndividuals(individual,p);

if save2pdf
    IBD_saveFigure(f_MI,'ExamplePatients_IBDtypes','pdf')
end

if save2tikz
    [p.tikz]    = deal(true);
    f_MI_tikz   = IBD_plotIndividuals(individual,p);
    IBD_saveFigure(f_MI_tikz,'ExamplePatients_IBDtypes','tikz')
end

clear p

%--------------------------------------------------------------------------
individual = individual(1:2);       % different mucosal injury extents non-relevant
% For each individual: run treatment scenario
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind).X_ss = individual(ind).X_ss_after;
    individual(ind) = IBD_runTreatment(individual(ind),options.duration,options.etas(:,i_eta),...
        effects.affectedPar,effects.affectedRates,effects.newPar,false);
end

%--------------------------------------------------------------------------
%% Plot treatment
p           = IBD_plotDatabase('overview',individual_ref);
p(4)        = p(3);
p(4).states = {'FCP'};
p(4).legend = {'FCP'};
p(4).tikzLegend = {'FCP'};
p(4).main   = 'FCP';
p(4).colourMap = IBD_myColours('FCP');
for i = 1:length(p)
    p(i).background     = [0 options.duration];
    p(i).backgroundCol  = IBD_myColours('treatmentBackground');
end
p(2).ylabel = p(1).ylabel;
p = p(2:4);    % do not show bacteria
f_treatment = IBD_plotIndividuals(individual,p);

if save2pdf
    IBD_saveFigure(f_treatment,'ExamplePatients_cytokineInhibitor','pdf')
end

if save2tikz
    [p.tikz]            = deal(true);
    f_treatment_tikz    = IBD_plotIndividuals(individual,p);
    IBD_saveFigure(f_treatment_tikz,'ExamplePatients_cytokineInhibitor','tikz')
end

clear p

%--------------------------------------------------------------------------
