%==========================================================================
% IBD_PlotIBDtypes
%==========================================================================
% Analyse distribution of and differences between IBD types
% 28 September 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.CombinePopulation_averageIBD)
load(fileNameList.CompareIBDtypes)

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
%% Distribution of IBD types
f1 = figure;
histogram(IBDtype,0.5:1:10.5,'FaceColor',IBD_myColours('histogram1'))
xticks(1:max(IBDtype))
xlabel('IBD type')
ylabel('Number of patients')
f1 = IBD_nicePlot(f1);
tabulate(IBDtype)
plotName = 'IBDtype_hist';
if save2pdf
    IBD_saveFigure(f1,plotName,'pdf')
end
if save2tikz
    IBD_saveFigure(f1,plotName,'tikz')
end

%--------------------------------------------------------------------------
%% Differences in time course between IBD types
f2 = figure;
colours = IBD_colourMap('dark rainbow',max(IBDtype)+1);
t = {};

% Bact
subplot(2,3,1)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.Bact_LP,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{1} = title('Bacteria');
xlabel({'',''})
ylabel('Conc. / value')

% Epi
subplot(2,3,2)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.epi,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{2} = title('Epithelium');
xlabel({'',''})

% Tissue
subplot(2,3,3)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.tissue,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{3} = title('Tissue');
xlabel({'',''})

% Th
subplot(2,3,4)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.Th_tot_LP,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{4} = title('T helper cells');
xlabel('Time [days]')
ylabel('Conc. / value')

% Macrophages
subplot(2,3,5)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.M_tot_LP,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{5} = title('Macrophages');
xlabel('Time [days]')

% Neutrophils
subplot(2,3,6)
hold on
for i = 1:max(IBDtype)
    plot(individual_ref.T/24,XperIBDtype{i}(:,individual_ref.Ired.Neut_LP,2),'Color',colours(i,:))
end
yl = ylim;
xl = xlim;
t{6} = title('Neutrophils');
xlabel('Time [days]')

f2 = IBD_nicePlot(f2);
plotName = 'IBDtype_timeCourse';
if save2pdf
    IBD_saveFigure(f2,plotName,'pdf')
end
if save2tikz
    for i = 1:6
        subplot(2,3,i)
        xl = xlim;
        yl = ylim;
        text(xl(1),(yl(2)-yl(1))*1.35+yl(1),t{i}.String,'HorizontalAlignment','left','FontSize',t{i}.FontSize,'FontWeight',t{i}.FontWeight,'Interpreter','latex')
        title('')
    end
    IBD_saveFigure(f2,plotName,'tikz')
end

%--------------------------------------------------------------------------
%% CDEIS distribution of the different IBD types
x = nan(length(IBDtype),max(IBDtype));
labels = {};
for i = 1:max(IBDtype)
    x_i = CDEIS(IBDtype==i);
    x(1:length(x_i),i) = x_i;
    labels{i} = sprintf('type %i',i);
end
f3 = IBD_violinPlot(x,labels,colours,true,false);
ylabel('CDEIS')
yline(4);
xlabel('IBD type')
xticklabels({'1','2','3','4','5','6','7','8','9','10'})
f3 = IBD_nicePlot(f3);
plotName = 'IBDtype_CDEIS';
if save2pdf
    IBD_saveFigure(f3,plotName,'pdf')
end
if save2tikz
    IBD_saveFigure(f3,plotName,'tikz')
end

%% CDEIS distribution corrected for CDEIS>4
x = nan(length(IBDtype),max(IBDtype));
labels = {};
for i = 1:max(IBDtype)
    x_i = CDEIS(IBDtype==i);
    x_i(x_i<4) = nan;
    x(1:length(x_i),i) = x_i;
    labels{i} = sprintf('type %i',i);
end
f3a = IBD_violinPlot(x,labels,colours,true,false);
ylabel('CDEIS')
yline(4);
xlabel('IBD type')
xticklabels({'1','2','3','4','5','6','7','8','9','10'})
f3a = IBD_nicePlot(f3a);
plotName = 'IBDtype_CDEIS_corrected';
if save2pdf
    IBD_saveFigure(f3a,plotName,'pdf')
end
if save2tikz
    IBD_saveFigure(f3a,plotName,'tikz')
end

%--------------------------------------------------------------------------
%% Plot most different parameters
N = 3;
options                 = struct;
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = false;
options.removeLegend    = false;
options.density         = true;
options.ncolrow         = [3 1];
parx                     = struct;
for i = 1:max(IBDtype)
    parx.(sprintf('type_%i',i)) = par(:,IBDtype==i);
end

f4 = IBD_plotParDist(parx,individual_ref,fieldnames(parx),parCor.idx(1:N),options);
plotName = 'IBDtype_parComparison';
if save2pdf
    IBD_saveFigure(f4,plotName,'pdf')
end
if save2tikz
    options.tikz            = save2tikz;
    options.removeLegend    = true;
    f4a = IBD_plotParDist(parx,individual_ref,fieldnames(parx),parCor.idx(1:N),options);
    IBD_saveFigure(f4a,plotName,'tikz')
    close(f4a)
end

%--------------------------------------------------------------------------
%% Plot most different pre-trigger steady state levels
N = 6;
ss0Cor                  = ss0Cor(ss0Cor.idx<=individual_ref.I.nrOfStates,:); % remove additional states
ss0Cor('mucus',:)       = [];   % mucus only follows epi
options                 = struct;
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = false;
options.removeLegend    = false;
options.density         = true;
ss0x                     = struct;
for i = 1:max(IBDtype)
    ss0x.(sprintf('type_%i',i)) = ss0(:,IBDtype==i);
end

f5 = IBD_plotParDist(ss0x,individual_ref,fieldnames(ss0x),ss0Cor.idx(1:N),options);
plotName = 'IBDtype_ss0Comparison';
if save2pdf
    IBD_saveFigure(f5,plotName,'pdf')
end
if save2tikz
    options.tikz            = save2tikz;
    options.removeLegend    = true;
    f5a = IBD_plotParDist(ss0x,individual_ref,fieldnames(ss0x),ss0Cor.idx(1:N),options);
    IBD_saveFigure(f5a,plotName,'tikz')
    close(f5a)
end

%--------------------------------------------------------------------------
%% Plot most different post-trigger steady state levels
N = 6;
ssMICor                 = ssMICor(ssMICor.idx<=individual_ref.I.nrOfStates,:); % remove additional states
ssMICor('mucus',:)      = [];       % mucus only follows epi
options                 = struct;
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = false;
options.removeLegend    = false;
options.density         = true;
ssMIx                	= struct;
for i = 1:max(IBDtype)
    ssMIx.(sprintf('type_%i',i)) = ssMI(:,IBDtype==i);
end
f6 = IBD_plotParDist(ssMIx,individual_ref,fieldnames(ssMIx),ssMICor.idx(1:N),options);
plotName = 'IBDtype_ssMIComparison';
if save2pdf
    IBD_saveFigure(f6,plotName,'pdf')
end
%%
if save2tikz
    options.tikz            = save2tikz;
    options.removeLegend    = true;
    options.addText         = {};
    for i = 1:N
        options.addText{i} = sprintf('$\\rho=%.2g$',ssMICor{i,'t'});
    end
    options.addText_position = {'left','right','right','right','left','right'};
    for i = [1 5]
        options.addText{i}      = {[options.addText{i}(1:6),'$'],['$',options.addText{i}(7:end)]};
    end
    f6a = IBD_plotParDist(ssMIx,individual_ref,fieldnames(ssMIx),ssMICor.idx(1:N),options);
    IBD_saveFigure(f6a,plotName,'tikz')
    close(f6a)
end


%--------------------------------------------------------------------------
