%==========================================================================
% IBD_PlotPopulationSteadyStateRelative
%==========================================================================
% Plot fractions of cell types from all cells in post-trigger steady state
% for healthy and IBD in comparison with literature
% 29 November 2022
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
% Plot
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Data

% Simulated data
load(fileNameList.RelativeSteadyState)

% Literature data
ssFractionsLiterature = IBD_LPfractionsLiterature();

% Select from literature data the simulated cell types and modify fractions to add up to 1
cellTypes = fieldnames(fractions.healthy)';
fractionsLit = ssFractionsLiterature(:,cellTypes);
sumFractions = sum(fractionsLit{:,:},2);
sumFractions(2) = sumFractions(1);
sumFractions(4) = sumFractions(3);
fractionsLit{:,:} = fractionsLit{:,:}./sumFractions;

%--------------------------------------------------------------------------
% Plot

% Mean and sd of simulated data
simMean         = struct;
simMean.healthy = [];
simSD.healthy   = [];
simMean.IBD     = [];
simSD.IBD       = [];
litMean.healthy = [];
litSD.healthy   = [];
litMean.IBD     = [];
litSD.IBD       = [];

for i = 1:length(cellTypes)
    simMean.healthy(i)  = mean(fractions.healthy.(cellTypes{i}));
    simSD.healthy(i)   	= std(fractions.healthy.(cellTypes{i}));
    simMean.IBD(i)      = mean(fractions.IBD.(cellTypes{i}));
    simSD.IBD(i)       	= std(fractions.IBD.(cellTypes{i}));
    litMean.healthy(i) 	= fractionsLit{'healthy_mean',cellTypes{i}};
    litSD.healthy(i)  	= fractionsLit{'healthy_SD',cellTypes{i}};
    litMean.IBD(i)      = fractionsLit{'UC_mean',cellTypes{i}};
    litSD.IBD(i)        = fractionsLit{'UC_SD',cellTypes{i}};
end

f = figure;
hold on
h1 = errorbar((1:length(cellTypes))-0.2, simMean.healthy, simSD.healthy, 'o',      'Color', IBD_myColours('healthy'),    'LineStyle','none');
h2 = errorbar((1:length(cellTypes))-0.1, simMean.IBD,     simSD.IBD,     'o',      'Color', IBD_myColours('IBD'),        'LineStyle','none');
h3 = errorbar((1:length(cellTypes))+0.1, litMean.healthy, litSD.healthy, 'square', 'Color', IBD_myColours('healthy'),    'LineStyle','none');
h4 = errorbar((1:length(cellTypes))+0.2, litMean.IBD,     litSD.IBD,     'square', 'Color', IBD_myColours('IBD'),        'LineStyle','none');
for i = 1:length(cellTypes)
    plot([i-0.2 i-0.1],[simMean.healthy(i) simMean.IBD(i)],'Color',[0.7 0.7 0.7])
    plot([i+0.1 i+0.2],[litMean.healthy(i) litMean.IBD(i)],'Color',[0.7 0.7 0.7])
end
xlim([0.5 8.5])
ylim([0 1])
legend({'healthy simulated','IBD simulated','healthy literature','IBD literature'})
legend('boxoff')
xticks(1:length(cellTypes))
xticklabels(replace(cellTypes,'_',' '))
xtickangle(90)
f = IBD_nicePlot(f);

plotName = 'populationSteadyStateLiterature';
if save2pdf
    IBD_saveFigure(f,plotName,'pdf')
end
if save2tikz
    IBD_saveFigure(f,plotName,'tikz')
end

%--------------------------------------------------------------------------