%==========================================================================
% IBD_PlotResponseRatesForCombinationTreatments
%==========================================================================
% Plot response rates for all combination treatments 
% (cytokine inhibitor in combination with all others)
% 5 January 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine'};

% Load data
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})                        = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(['cytokineInhibitorX',scenarios{i}]) = load(fileNameList.constantTreatment_CDEIS.(['cytokineInhibitorX',scenarios{i}]),'options','effects','CDEIS');
end

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
responseRates   = struct;
y               = [];
scenario1       = 'cytokineInhibitor';

for i = 1:length(scenarios)
    scenario2    = scenarios{i};
    scenarioX   = ['cytokineInhibitorX',scenarios{i}];
    
    A = S.(scenarioX).options.etas(1:size(S.(scenario1).options.etas,1));
    B = S.(scenario1).options.etas;
    i_eta1 = find(all(B==A,1),1);
    
    A = S.(scenarioX).options.etas(size(S.(scenario1).options.etas,1)+1:end);
    B = S.(scenario2).options.etas;
    i_eta2 = find(all(B==A,1),1);
    
    responders1 = (S.(scenario1).CDEIS.ssEOT(i_eta1,:)<4) + 1;  % 1 = non-responder, 2 = responder
    responders2 = (S.(scenario2).CDEIS.ssEOT(i_eta2,:)<4) + 1;  % 1 = non-responder, 2 = responder
    respondersX = (S.(scenarioX).CDEIS.ssEOT<4)           + 1;  % 1 = non-responder, 2 = responder
    N_IBD = length(responders1);
    
    for s1 = [1 2]
        for s2 = [1 2]
            for sX = [1 2]
                RR(s1,s2,sX) = sum(responders1==s1 & responders2==s2 & respondersX==sX)/N_IBD*100;
            end
        end
    end
    
    y = [y;[RR(2,1,2),RR(2,2,2),RR(1,2,2),RR(1,1,2)]];
    responseRates.(scenarioX) = RR;
    
end

f1 = figure;
n = 3;
m = 3;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

b = bar(y,'stacked');
ylim([0 100])
ylabel('Response rate [%]')
xticklabels(scenarioNames)
xtickangle(45)
ax = gca;
myColourMap = IBD_myColours('combinedResponse');
for i = 1:length(b)
    b(i).FaceColor = myColourMap(i,:);
end
l = legend({...
    'only cytokine inhibitor',...
    'cytokine inhibitor and second treatment',...
    'only second treatment',...
    'none of the single treatments'...
    },'Location','northwest');
t = title(l,'response to combination treatment and ...');
f1 = IBD_nicePlot(f1);


%--------------------------------------------------------------------------
if save2pdf
    IBD_saveFigure(f1,'RRcombination','pdf')
end
if save2tikz
    extraCode.AtEndOfAxis = '\node [anchor=north west, align=left] at (0,100) {Response to combination treatment and ...};';
    extraCode.Axis = 'legend style={at={(0.03,0.94)}, anchor=north west, legend cell align=left, align=left, draw=white!15!black},';
    %extraCode = struct;
    IBD_saveFigure(f1,'RRcombination','tikz',extraCode)
end
