%==========================================================================
% IBD_PlotResponseRatesForSingleTreatments
%==========================================================================
% Plot response rates over eta for all single treatments
% 14 December 2020
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};

% Load data
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i}) = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
end

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Plot response rates over eta
f1 = figure;
n = 3;
m = 3;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);
for i = 1:length(scenarios)
    scenario    = scenarios{i};
    options     = S.(scenario).options;
    CDEIS       = S.(scenario).CDEIS;
    
    subplot(m,n,i);
    ax = gca;
    
    % Do not plot the extra points for response rate 30/50%
    % Restrict to one eta for treatments with multiple effects
    if strcmp(scenario,'FMT')
        options.etas = options.etas(2,:);
        etaIdx = [1:length(options.etas)-2,length(options.etas)];
    elseif strcmp(scenario,'azathioprine')
        etaIdx = 1:length(options.etas)-1;
    elseif strcmp(scenario,'antibiotics')
        etaIdx = 1:length(options.etas);
    elseif strcmp(scenario,'methotrexate')
        options.etas = options.etas(1,:);
        etaIdx = 1:length(options.etas)-2;
    elseif strcmp(scenario,'S1PRmodulator')
        etaIdx = options.etas(2,:)==0;
        etaIdx = etaIdx(1:end-2);
        options.etas = options.etas(1,:);
    else
        etaIdx = 1:length(options.etas)-2;
    end
    
    if save2tikz
        IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssEOT(etaIdx,:),struct('colour',IBD_myColours('responseRates'),'title',[scenarioNames{i},'\phantom{y}'],'tikz',true),ax);
        %IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssT1(etaIdx,:),struct('colour',IBD_myColours('responseRates_early'),'title',[scenarioNames{i},'\phantom{y}'],'tikz',true),ax);
        IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssPT(etaIdx,:),struct('colour',IBD_myColours('responseRates_PT'),'title',[scenarioNames{i},'\phantom{y}'],'tikz',true),ax);
        if strcmp(scenario,'phosphatidylcholine')
            xticks([-0.8,-0.4,0])
        end
    else
        IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssEOT(etaIdx,:),struct('colour',IBD_myColours('responseRates'),'title',scenarioNames{i}),ax);
        IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssPT(etaIdx,:),struct('colour',IBD_myColours('responseRates_PT'),'title',scenarioNames{i}),ax);
    end
    if ~ismember(i,[1,4,7])
        ylabel('')
    end
	if save2tikz
        ax = gca;
        xlabel({ax.XLabel.String,''})
    end
end

f1 = IBD_nicePlot(f1);

if save2pdf
    IBD_saveFigure(f1,'RRsingle','pdf')
end
if save2tikz
    IBD_saveFigure(f1,'RRsingle','tikz')
end

%--------------------------------------------------------------------------
%% S1PR modulator: 2 effects --> separate plot
scenario    = 'S1PRmodulator';
options     = S.(scenario).options;
effects     = S.(scenario).effects;
CDEIS       = S.(scenario).CDEIS;
etaIdx      = 1:length(options.etas)-2;
options.etas = options.etas(:,etaIdx);
CDEIS.ssEOT = CDEIS.ssEOT(etaIdx,:);
f2 = figure;
for divideRow = [1,2]
    subplot(1,2,divideRow);
    otherRow = setdiff([1,2],divideRow);
    etas2divide = unique(options.etas(divideRow,:));
    colours = IBD_colourMap('dark rainbow',length(etas2divide)+1);
    legends = {};
    for i = 1:length(etas2divide)
        ax = gca;
        idx = options.etas(divideRow,:)==etas2divide(i);
        IBD_plotResponseRate(options.etas(otherRow,idx),CDEIS.ssEOT(idx,:),struct('plot0',false,'colour',colours(i,:)),ax);
        if save2tikz
            if divideRow==1
                legends{i} = sprintf('$\\eta_{\\mathrm{egress}} = %.2f$',etas2divide(i));
            else
                legends{i} = sprintf('$\\eta_{\\mathrm{Treg}} = %.2f$',etas2divide(i));
            end
        else
            legends{i} = sprintf('%s = %.2f',options.treatments{divideRow},etas2divide(i));
        end
    end
    if save2tikz
        if divideRow==1
            xlabel('$\eta_{\mathrm{Treg}}$','interpreter','latex')
        else
            xlabel('$\eta_{\mathrm{egress}}$','interpreter','latex')
        end
    else
        xlabel(sprintf('etas (%s)',options.treatments{otherRow}))
    end
    if save2tikz
        legend(legends,'interpreter','latex')
    else
        legend(legends)
    end
    ylim([0 170])
    yticks(0:20:100)
    yticklabels(0:20:100)
end
f2 = IBD_nicePlot(f2);

if save2pdf
    IBD_saveFigure(f2,'RRsingle_S1PR','pdf')
end
if save2tikz
    IBD_saveFigure(f2,'RRsingle_S1PR','tikz')
end
