%==========================================================================
% IBD_Relapse
%==========================================================================
% Analyse patients who relapse after the different treatments
% 3 March 2021
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
scenarioNames = {'Cytokine inhibition',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Methotrexate',...
                 'Azathioprine',...
                 'Antibiotics'};

% Load data
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})            = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(scenarios{i}).response   = S.(scenarios{i}).CDEIS.ssEOT<4;
    S.(scenarios{i}).rr         = sum(S.(scenarios{i}).response,2)/size(S.(scenarios{i}).response,2)*100;
    % Etas resulting in 30/50% response rate:
    S.(scenarios{i}).idx30      = find(round(S.(scenarios{i}).rr,1)==30);
    if isempty(S.(scenarios{i}).idx30)
        S.(scenarios{i}).idx30 = nan;
    end
    S.(scenarios{i}).idx50      = find(round(S.(scenarios{i}).rr,1)==50);
    if isempty(S.(scenarios{i}).idx50)
        S.(scenarios{i}).idx50 = nan;
    end
    S.(scenarios{i}).idx        = [S.(scenarios{i}).idx30,S.(scenarios{i}).idx50];
end

%--------------------------------------------------------------------------

if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Barplot of percentage of patients that relapse per treatment (50%/30% response rate)
relapseRate = nan(2,length(scenarios));

% 50%
for i = 1:length(scenarios)
    if isnan(S.(scenarios{i}).idx50)
        continue
    end
    responders  = S.(scenarios{i}).CDEIS.ssEOT(S.(scenarios{i}).idx50,:)<4;
    relapse     = responders & S.(scenarios{i}).CDEIS.ssPT(S.(scenarios{i}).idx50,:)>=4;
    relapseRate(1,i) = sum(relapse)/sum(responders);
end

% 30%
for i = 1:length(scenarios)
    if isnan(S.(scenarios{i}).idx30)
        continue
    end
    responders  = S.(scenarios{i}).CDEIS.ssEOT(S.(scenarios{i}).idx30,:)<4;
    relapse     = responders & S.(scenarios{i}).CDEIS.ssPT(S.(scenarios{i}).idx30,:)>=4;
    relapseRate(2,i) = sum(relapse)/sum(responders);
end

f = figure;
set(f, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*1*3, 0.3*2*3]);
titles = {'Single response rates: 50\,\%','Single response rates: 30\,\%'};

for j = 1:2
    subplot(2,1,j)
    b50 = bar(relapseRate(j,:)*100);
    b50.FaceColor = IBD_myColours('histogram1');
    xticks(1:length(scenarios))
    xticklabels(scenarioNames)
    ax = gca;
    ax.XTickLabel(isnan(relapseRate(j,:)*100)) = {''};
    xtickangle(45)
    if save2tikz
        set(ax,'TickLabelInterpreter','latex')
    end
    for k = 1:size(relapseRate,2)
        if ~isnan(relapseRate(j,k))
            text(k,relapseRate(j,k)*100+10,sprintf('%.0f%%',relapseRate(j,k)*100),'HorizontalAlignment','center')
        end
    end
    ylim([0 75])
    %xlabel({'',''})
    ylabel('Relapse rate [%]')
    title(titles{j},'Interpreter','latex')
end

f = IBD_nicePlot(f);

if save2pdf
    IBD_saveFigure(f,'Relapse','pdf')
end
if save2tikz
    IBD_saveFigure(f,'Relapse','tikz')
end

