%==========================================================================
% IBD_SamplePopulation
%==========================================================================
% Sample and classify individuals
% Save: parameters, steady state before & after mucosal injury, time course 
% of infection (Neut, Th, M, epi, mucus, tissue, Bact), class, IBD type
% 21 August 2019
%==========================================================================

clearvars -except save2tikz save2pdf

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
if exist('Data/fileNameList.mat','file')
    load('Data/fileNameList.mat','fileNameList')
else
    fileNameList = struct;
end
if ~isfield(fileNameList,thisFile)
    fileNameList.(thisFile) = {};
end
n = numel(fileNameList.(thisFile))+1;
thisFileName = [thisFile,int2str(n)];

% Adapt file name list
fileNameList.(thisFile){n} = [thisFileName,'_in_progress'];
save('Data/fileNameList.mat','fileNameList')

fprintf('Generating sample population nr %i...\n',n)

%--------------------------------------------------------------------------
N = 100000;

tic_start = tic;

%--------------------------------------------------------------------------
% Get reference individual (parameters, steady state, no inflammation)
individual_ref = IBD_referenceIndividual();
I = individual_ref.I;

%--------------------------------------------------------------------------
% Mucosal injury
MI = [1:-0.1:0.1;...    % epiDamage
      1:-0.1:0.1];      % tisDamage

% Reference individual
individual_ref.infection.epiDamage      = MI(1,1);
individual_ref.infection.tisDamage      = MI(2,1);
individual_ref.timespan                 = unique([0:1:24,24:12:7*24,7*24:24:individual_ref.timespan(end)]);
individual_ref                          = IBD_runSteadyState(individual_ref);
individual_ref                          = IBD_runInfection(individual_ref,true);

% Index for saved states of time course
inflIdx                                 = [I.Neut_LP,I.M_tot_LP,I.Th_tot_LP,I.Bact_LP,I.epi,I.tissue,I.mucus];
individual_ref.Ired.inflIdx             = inflIdx;
individual_ref.Ired.stateName           = individual_ref.I.stateName(inflIdx);
for i = 1:length(individual_ref.Ired.stateName)
    individual_ref.Ired.(individual_ref.Ired.stateName{i}) = i;
end
individual_ref.Ired.nrOfStates          = i;
individual_ref.Ired.allStates           = 1:individual_ref.Ired.nrOfStates;

classDefinition                         = IBD_centroids(individual_ref);

%--------------------------------------------------------------------------
% Specify parameters to sample
% all (except integers, ssEpi, ssTis, ssMucus)
omitPars        = [I.egressThreshold,I.egressThresholdm,I.nTn,I.nTm,I.ssEpi,I.ssTis,I.ssMucus];
parIdx          = setdiff(I.allPar,omitPars);

% Sample from lognormal distribution
sd              = 0.4;  % standard deviation
sigma           = zeros(size(individual_ref.par));
sigma(parIdx)   = sd;
sigma           = repmat(sigma',[1,N]);
mu              = zeros(size(individual_ref.par));
mu              = repmat(mu',[1,N]);

rng(n)
par             = lognrnd(mu,sigma).*individual_ref.par';

%--------------------------------------------------------------------------
% Characteristics to save
ss0     = nan([length(individual_ref.Xadd_ss),N]);              % steady state concentrations before any stimulus
ssMI    = nan([length(individual_ref.Xadd_ss),N]);              % steady state concentrations after mucosal injury
X       = nan([length(individual_ref.T),length(inflIdx),N]);    % inflammation time course
class   = nan(1,N);                                             % class
IBDtype = nan(1,N);                                             % IBD type (only for class IBD)
infectionProblems = nan(1,N);

%--------------------------------------------------------------------------
% Simulation per individual
fprintf('Sampling and simulating %i individuals with sd %.2f...\n',N,sd);

parfor (ind = 1:N)
    
    fprintf('Individual %i/%i:\t',ind,N)
    individual_tmp = individual_ref;
    
    % Sample parameters
    individual_tmp.par = par(:,ind)';
    
    % Rerun steady state
    individual_tmp      = IBD_runSteadyState(individual_tmp);
    if individual_tmp.problems
        class(ind)      = 0;
    else
        
        % Run infection scenario
        individual_tmp  = IBD_runInfection(individual_tmp,true);
        if individual_tmp.T(end) < individual_tmp.timespan(end)
            infectionProblems(ind) = true;
            fprintf('Strange problem in infection.\n')
        else
        
            % Classify
            class(ind)      = IBD_classifyInflammation(individual_tmp.Xadd_ss',individual_tmp.Xadd_ss_after',classDefinition,individual_ref);

            % Save results
            ss0(:,ind)      = individual_tmp.Xadd_ss;
            ssMI(:,ind) 	= individual_tmp.Xadd_ss_after;
            X(:,:,ind)  	= individual_tmp.Xadd(:,inflIdx);

            % Determine IBD type/the extent of mucosal injury needed as stimulus
            isIBDpatient  	= class(ind) == classDefinition.I.IBD;
            IBDtype(ind) 	= size(MI,2);       % start with least severe type, i.e. highest stimulus resulting in IBD
            while isIBDpatient && IBDtype(ind) > 1
                individual_tmp.infection.epiDamage  = MI(1,end-IBDtype(ind)+2);
                individual_tmp.infection.tisDamage  = MI(2,end-IBDtype(ind)+2);
                individual_tmp                      = IBD_runInfection(individual_tmp,true);
                class_tmp                           = IBD_classifyInflammation(individual_tmp.Xadd_ss',individual_tmp.Xadd_ss_after',classDefinition,individual_ref);
                isIBDpatient                        = class_tmp == classDefinition.I.IBD;
                if isIBDpatient
                    IBDtype(ind)                    = IBDtype(ind) - 1;
                end
            end
        end
        
    end
end

fprintf('%i/%i individuals had problems with steady state. Remaining: %i/%i\n',sum(class==0),N,sum(class>0),N)

%--------------------------------------------------------------------------
% Save results
for i = [0,classDefinition.I.allClasses]
    if i == 0
        thisClass = 'problems';
    else
        thisClass = classDefinition.I.className{i};
    end
    fullFileName = savePopulation(thisFileName,...
        par(:,class==i),...
        ss0(:,class==i),...
        ssMI(:,class==i),...
        IBDtype(:,class==i),...
        X(:,:,class==i),...
        thisClass,individual_ref);
end

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile){n} = fullFileName;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
fprintf('... took %.2f min/ %.2f h/ %.2f days.\n',toc(tic_start)/60,toc(tic_start)/60/60,toc(tic_start)/60/60/24)


%==========================================================================
% LOCAL FUNCTIONS
function fullFileName = savePopulation(fileName,par,ss0,ssMI,IBDtype,X,thisClass,individual_ref)
    fullFileName = ['Data/',fileName,'_',date,'_',thisClass,'.mat'];
    save(fullFileName,'par','ss0','ssMI','IBDtype','X','individual_ref')
    fprintf('Saved as %s\n',fullFileName);
    fullFileName = strrep(fullFileName,thisClass,'xxx');
end

%--------------------------------------------------------------------------
