%==========================================================================
% IBD_VirtualPopulationOverview
%==========================================================================
% Workflow overview of constructing and dealing with the virtual population
% of healthy and diseased subjects
% Execution of this script takes very long!
% 21 August 2019
%==========================================================================

% Save figures (on laptop) as:
save2tikz = true;           % Requires the file 'Settings_SSt_modelCommands.tex' defining the used latex commands
save2pdf  = true;

%--------------------------------------------------------------------------
%% Construct a virtual population of healthy and diseased subjects
for i = 1:10
    IBD_SamplePopulation
    % generates 100,000 subjects each
    % For test purposes, set N to a lower number (line 37 in 
    % IBD_SamplePopulation) - We note however, that a too low N might lead 
    % to subsequent problems in the analyses as the number of IBD 
    % individuals in the population might get too small (one or even none).
end

%--------------------------------------------------------------------------
%% Analysis
% Combine the datasets and average time course of inflammation per class
IBD_CombinePopulation
% - download: CombinePopulation_average, CombinePopulation_averageIBD

% Plot the time course of the different populations (healthy, IBD, chronic
% infection, chronic inflammation) in response to trigger
IBD_PlotPopulationTimeCourse                        % on laptop

% Identify necessary parameter changes for IBD per patient
for i = 1:10
    IBD_NecessaryParChangesForIBD
    % once per sample population file
end
IBD_CombineNecessaryParChanges
% - download: CombineNecessaryParChanges

% Visually analyse the necessary parameter changes
IBD_AnalyseNecessaryParChanges                      % on laptop

% Comparison of parameter distributions
IBD_CompareParameters
% - download: CompareParameters
IBD_PlotParameterComparison                         % on laptop

% Comparison of pre-trigger steady state distribution
IBD_CompareStates
% - download: CompareStates
IBD_PlotStateComparison                             % on laptop

% IBD types
IBD_IBDsteadyStates
IBD_CompareIBDtypes
% - download: CompareIBDtypes
IBD_PlotIBDtypes                                    % on laptop

% Comparison of classification methods (for healthy vs IBD based on pars/states)
IBD_fs_compareClassificationMethods('par')
IBD_fs_compareClassificationMethods('ss0')
IBD_fs_compareClassificationMethods('par_ss0')
% - download: fs_compareClassificationMethods_par
%             fs_compareClassificationMethods_ss0
%             fs_compareClassificationMethods_par_ss0
% Analysis on laptop
IBD_fs_analyseClassificationMethods('par')
IBD_fs_analyseClassificationMethods('ss0')
IBD_fs_analyseClassificationMethods('par_ss0')

% Prediction of IBD vs healthy based on parameters or pre-trigger steady state (feature selection)
IBD_fs_LDAfeatureSelection('par')
IBD_fs_LDAfeatureSelection('ss0')
IBD_fs_LDAfeatureSelection('par_ss0')
% - download: fs_LDAfeatureSelection_par
%             fs_LDAfeatureSelection_ss0
%             fs_LDAfeatureSelection_par_ss0
% Analysis on laptop
IBD_fs_analyseFeatureSelection('par')
IBD_fs_analyseFeatureSelection('ss0')
IBD_fs_analyseFeatureSelection('par_ss0')


%--------------------------------------------------------------------------
%% Treatment

% Generate clinical study population by excluding subjects with CDEIS<6
IBD_ClinicalIBDpopulation
% - download: ClinicalIBDpopulation

% Single treatments
singleTreatments = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
for i = 1:length(singleTreatments)
    IBD_singleTreatment(singleTreatments{i})
end
% - download: IBD_constantTreatment_CDEIS_(scenario)

% Plot exemplary profiles (IBD types and treatment with cytokine inhibitor)
IBD_ExamplePatients         % on laptop

% Analyse response rates per treatment effect, including CDEIS and FCP distributions
% per scenario:
IBD_analyseResponse(SCENARIO)                           % on laptop
% response rates for all scenarios:
IBD_PlotResponseRatesForSingleTreatments                % on laptop

% Relapse
IBD_Relapse                                             % on laptop

% Correlation between responsiveness to different treatments
IBD_CorrelationsOfResponsiveness                        % on laptop

% Combination treatments: cytokine inhibitor with all others
singleTreatments = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','methotrexate','azathioprine','antibiotics'};
for i = 1:length(singleTreatments)
    IBD_combinationTreatment({singleTreatments{1},singleTreatments{i}},30)
end
for i = 1:length(singleTreatments)
    IBD_combinationTreatment({singleTreatments{1},singleTreatments{i}},30)
end
% Analysis on laptop
IBD_PlotResponseRatesForCombinationTreatments           % on laptop

% Comparison of responders and non-responders (parameters/states)
IBD_CompareParametersResponders
IBD_CompareStatesResponders
% - download: CompareParametersResponders
%             CompareStatesResponders
IBD_AnalyseParameterComparisonResponders        	% on laptop
IBD_AnalyseStateComparisonResponders                % on laptop
IBD_CompareNecessaryParChangesResponders            % on laptop
IBD_CorrelationOfReponseToIBDtype                   % on laptop

% Prediction of responsiveness (for all treatments) (feature selection)
for i = 1:length(singleTreatments)
    IBD_fs_LDAfeatureSelection(singleTreatments{i})
end
% - download: fs_LDAfeatureSelection_(scenario)
% Analysis on laptop
for i = 1:length(singleTreatments)
    IBD_fs_analyseFeatureSelection(singleTreatments{i})     % on laptop
end
IBD_fs_AnalyseFeatureSelectionTreatment         % on laptop

% Prediction of relapse (for all treatments)
for i = 1:length(singleTreatments)
    IBD_fs_LDAfeatureSelection([singleTreatments{i},'_relapse'])
end
IBD_fs_LDAfeatureSelection_relapse
IBD_fs_TestRelapseModel
IBD_fs_AnalyseFeatureSelectionRelapse       % on laptop









