function [] = IBD_analyseResponse(scenario,save2tikz,save2pdf)
%==========================================================================
% [] = IBD_analyseResponse(scenario)
%==========================================================================
% Analyse response rates, including CDEIS and FCP distribution
% 19 November 2020
%--------------------------------------------------------------------------
%-- input
% scenario:     treatment scenario
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>(%s)\n',fileName,scenario)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.constantTreatment_CDEIS.(scenario),'options','effects','CDEIS','FCP','individual_ref')
N_IBD       = length(CDEIS.ss0);
nrOfEtas    = size(options.etas,2);

%--------------------------------------------------------------------------
if ~exist('save2tikz','var')
    save2tikz = false;
end
if ~exist('save2pdf','var')
    save2pdf = false;
end

%--------------------------------------------------------------------------
% Response rate over eta
plotName = ['response_',scenario];

% Special cases (see treatment database)
if strcmp(scenario,'FMT')
    options.etas = options.etas(2,:);
end
if strcmp(scenario,'methotrexate')
    options.etas = options.etas(1,:);
end

% For single treatments/only one effect
if size(options.etas,1)==1
    [f1,responseRate] = IBD_plotResponseRate(options.etas,CDEIS.ssEOT);
    if save2pdf
        IBD_saveFigure(f1,plotName,'pdf')
    end
    if save2tikz
        f1_tikz = IBD_plotResponseRate(options.etas,CDEIS.ssEOT,struct('tikz',true));
        IBD_saveFigure(f1_tikz,plotName,'tikz')
    end
    
    % Print response rates per eta
    rr = table;
    for i = 1:size(options.etas,1)
        rr.(sprintf('eta%i',i)) = options.etas(i,:)';
    end
    rr.responseRate = responseRate';
    disp(rr)
end

% For two effects
if size(options.etas,1)==2
    f1 = figure;
    
    rr = table;
    for i = 1:size(options.etas,1)
        rr.(sprintf('eta%i',i)) = options.etas(i,:)';
    end
    rr.responseRate = nan(size(options.etas,2),1);
    
    for divideRow = [1,2]
        subplot(1,2,divideRow);
        %[~,divideRow] = min([length(unique(options.etas(1,:))),length(unique(options.etas(2,:)))]);
        otherRow = setdiff([1,2],divideRow);
        etas2divide = unique(options.etas(divideRow,:));
        colours = IBD_colourMap('dark rainbow',length(etas2divide)+1);
        legends = {};
        for i = 1:length(etas2divide)
            ax = gca;
            idx = options.etas(divideRow,:)==etas2divide(i);
            [~,responseRate] = IBD_plotResponseRate(options.etas(otherRow,idx),CDEIS.ssEOT(idx,:),struct('plot0',false,'colour',colours(i,:)),ax);
            xlabel(sprintf('etas (%s)',options.treatments{otherRow}))
            legends{i} = sprintf('%s = %.2f',options.treatments{divideRow},etas2divide(i));
            rr.responseRate(idx) = responseRate;
        end
        legend(legends)
        f1 = IBD_nicePlot(f1);
    end
    
    if save2pdf
        IBD_saveFigure(f1,plotName,'pdf')
    end
    if save2tikz
        % Adapt figure for tikz!
        IBD_saveFigure(f1_tikz,plotName,'tikz')
    end
    
    % Print response rates per eta
    disp(rr)
end

%--------------------------------------------------------------------------
%% Additivity of effects (for multiple effects)
if size(options.etas,1)==2
    add = rr;
    add.single1	= nan(size(options.etas,2),1);
    add.single2	= nan(size(options.etas,2),1);
    add.added	= nan(size(options.etas,2),1);
    add = add(:,[1 2 4 5 6 3]);
    for i = 1:size(add,1)
        single1 = add.responseRate(add.eta1==add.eta1(i) & add.eta2==0);
        single2 = add.responseRate(add.eta2==add.eta2(i) & add.eta1==0);
        if length(single1)==1 && length(single2) == 1
            add.single1(i) = single1;
            add.single2(i) = single2;
            add.added(i)   = single1+single2;
        end
    end
    f1a = figure;
    plot(add.added,add.responseRate,'x','Color',IBD_myColours('crosses1'))
    xlabel('Sum of single response rates')
    ylabel('Combined response rate')
    refline(1,0)
    f1a = IBD_nicePlot(f1a);
end

%--------------------------------------------------------------------------
%% CDEIS distribution over treatment effect extent (only for single effects)
if size(options.etas,1)==1
    fprintf('Plotting CDEIS values...\n')
    [etaswith0,idx] = sort([0,options.etas]);
    CDEISwith0      = [CDEIS.ssMI;CDEIS.ssEOT]';
    CDEISwith0      = CDEISwith0(:,idx);
    f2 = IBD_violinPlot(CDEISwith0,etaswith0,struct('colours',IBD_colourMap('dark rainbow',size(CDEISwith0,2)+1),'logY',true,'boxplotShifted',true));
    pause(2)    % to ensure that f2 is active
    xlabel('eta')
    ylabel('log(CDEIS)')
    yl = ylim;
    ylim([-10,yl(2)]);
    yline(log(4));
    f2 = IBD_nicePlot(f2);
    plotName = ['CDEIS_',scenario];
    if save2pdf
        IBD_saveFigure(f2,plotName,'pdf')
    end
    if save2tikz
        xlabel('\eta')
        f2 = IBD_nicePlot(f2);
        IBD_saveFigure(f2,plotName,'tikz')
    end
end

%--------------------------------------------------------------------------
%% FCP distribution over treatment effect extent (only for single effects)
if size(options.etas,1)==1
    fprintf('Plotting FCP values...\n')
    FCPwith0 = [FCP.ssMI;FCP.ssEOT]';
    FCPwith0 = FCPwith0(:,idx);
    f2 = IBD_violinPlot(FCPwith0,etaswith0,struct('colours',IBD_colourMap('dark rainbow',size(FCPwith0,2)+1),'normaliseSeparately',true));
    xlabel('eta')
    ylabel('FCP')
    ylim([0 1000])
    f2 = IBD_nicePlot(f2);
    plotName = ['FCP_',scenario];
    if save2pdf
        IBD_saveFigure(f2,plotName,'pdf')
    end
    if save2tikz
        xlabel('\eta')
        f2 = IBD_nicePlot(f2);
        IBD_saveFigure(f2,plotName,'tikz')
    end
end

%--------------------------------------------------------------------------
end