function [] = IBD_constantTreatment(options)
%==========================================================================
% [] = IBD_constantTreatment(options)
%==========================================================================
% Simulate treatment/treatment combinations in all IBD patients
% 16 December 2019
%--------------------------------------------------------------------------
%-- input
% treatmentOptions: struct of
%                       treatments      cell array of treatments
%                       etas            array of eta combinations (one row per treatment)
%                       duration        treatment duration
%                       obsDuration   	time of observation post-treatment
%                       T1T2            time points of treatment observations (2 time points)
%==========================================================================

treatments = options.treatments;

if ~iscell(treatments)
    treatments = {treatments};
end

fileName = IBD_getFileName(mfilename('fullpath'));
printTreatments = join(treatments,' & ');
printTreatments = printTreatments{1};
fprintf('<strong>%s</strong>(%s)\n',fileName,printTreatments)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
S = load(fileNameList.ClinicalIBDpopulation,'par','ssMI','ss0','individual_ref');
individual_ref  = S.individual_ref;
par             = S.par;
ssMI            = S.ssMI(1:individual_ref.I.nrOfStates,:);
ss0             = S.ss0;
I               = individual_ref.I;

N_IBD   = size(par,2);
%inflIdx = [individual_ref.Ired.inflIdx,individual_ref.I.FCP];   % add FCP

%--------------------------------------------------------------------------
fprintf('Simulating treatment: %s with etas:\n',printTreatments)
disp(options.etas)

% Reset infection scenario
individual_ref.infection.epiDamage = nan;
individual_ref.infection.tisDamage = nan;

% Timespan
timespan_treat          = unique([0:1:24,24:12:7*24,7*24:24:options.duration]);
timespan_afterTreat     = unique([0:1:24,24:12:7*24,7*24:24:options.obsTime]);
individual_ref.timespan = unique([timespan_treat,timespan_afterTreat+options.duration]);

% Treatment effects
effects = IBD_treatmentEffects(treatments,individual_ref);

% What if different treatment mechanisms affect the same parameter/rate?
% effects
% ismember(effects.affectedPar{1},effects.affectedPar{2})
% 
% error('stop')

%--------------------------------------------------------------------------
% Characteristics to save
%X       = nan([length(timespan_treat)+length(timespan_afterTreat)+1,length(inflIdx)+length(effects.saveIdx),size(options.etas,2),N_IBD]); % inflammation time course during and after treatment (together)
ssT1    = nan([length(individual_ref.Xadd_ss),size(options.etas,2),N_IBD]); % state (no steady state) after 4 weeks of treatment for each treatment extent
ssT2    = nan([length(individual_ref.Xadd_ss),size(options.etas,2),N_IBD]); % state (no steady state) after 12 weeks of treatment for each treatment extent
ssEOT   = nan([length(individual_ref.Xadd_ss),size(options.etas,2),N_IBD]); % state (no steady state) after 24 weeks of treatment for each treatment extent
ssPT    = nan([length(individual_ref.Xadd_ss),size(options.etas,2),N_IBD]); % steady state after stop of treatment for each treatment extent

%--------------------------------------------------------------------------
% Simulation of treatment
etas            = options.etas;
affectedPar     = effects.affectedPar;
affectedRates   = effects.affectedRates;
newPar          = effects.newPar;
duration        = options.duration;
nrOfEtas        = size(etas,2);
%saveIdx         = effects.saveIdx;
T1              = options.T1T2(1);
T2              = options.T1T2(2);
EOT             = options.duration;

parfor (ind = 1:N_IBD)
    
    fprintf('Individual %i/%i:\t\n',ind,N_IBD)
    individual_tmp      = individual_ref;
    
    individual_tmp.par  = par(:,ind)';
    individual_tmp.X_ss = ssMI(:,ind)';
    
    individual_tmp      = IBD_runSteadyState(individual_tmp);   % should take no time
    
    for e = 1:nrOfEtas
        
        % Simulation of treatment
        individual_tmp = IBD_runTreatment(individual_tmp,duration,etas(:,e),affectedPar,affectedRates,newPar,true);
        
        % Save time course, states at specific times of treatment, and steady state after stop of treatment
%         if ~individual_tmp.problems
%             X(:,:,e,ind)       	= individual_tmp.Xadd(:,[inflIdx,saveIdx]);
%         end
        ssT1(:,e,ind)     	= individual_tmp.Xadd(find(individual_tmp.T==T1, 1),:)';
        ssT2(:,e,ind)    	= individual_tmp.Xadd(find(individual_tmp.T==T2, 1),:)';
        ssEOT(:,e,ind)   	= individual_tmp.Xadd(find(individual_tmp.T==EOT,1),:)';
        ssPT(:,e,ind)       = individual_tmp.Xadd_ss_after';
    end
end

% Calculate CDEIS
CDEIS = struct;
CDEIS.ss0               = IBD_CDEIS(ss0,I)';
CDEIS.ssMI              = IBD_CDEIS(ssMI,I)';
for e = 1:nrOfEtas
    CDEIS.ssT1(e,:)     = IBD_CDEIS(squeeze(ssT1(:,e,:)),I);
    CDEIS.ssT2(e,:)     = IBD_CDEIS(squeeze(ssT2(:,e,:)),I);
    CDEIS.ssEOT(e,:)  	= IBD_CDEIS(squeeze(ssEOT(:,e,:)),I);
    CDEIS.ssPT(e,:)     = IBD_CDEIS(squeeze(ssPT(:,e,:)),I);
end

% Save FCP values
FCP = struct;
FCP.ss0                 = IBD_calcFCPss(ss0,par,individual_ref.I);
FCP.ssMI                = IBD_calcFCPss(ssMI,par,individual_ref.I);
for e = 1:nrOfEtas
    FCP.ssT1(e,:)       = squeeze(ssT1(I.FCP,e,:));
    FCP.ssT2(e,:)       = squeeze(ssT2(I.FCP,e,:));
    FCP.ssEOT(e,:)  	= squeeze(ssEOT(I.FCP,e,:));
    FCP.ssPT(e,:)       = squeeze(ssPT(I.FCP,e,:));
end

% For time course: Treatment in reference individual
individual_ref = IBD_runTreatment(individual_ref,duration,etas(:,1),affectedPar,affectedRates,newPar,true);

%--------------------------------------------------------------------------
% Save data
if isfield(options,'scenario')
    printTreatments = options.scenario;
else
    printTreatments = join(treatments,'_');
    printTreatments = printTreatments{1};
end
fullFileName        = ['Data/',thisFile,'_',printTreatments,'_',date,'.mat'];
fullFileName_CDEIS 	= ['Data/',thisFile,'_CDEIS_',printTreatments,'_',date,'.mat'];
%save(fullFileName,'X','ssT1','ssT2','ssEOT','ssPT','options','effects','individual_ref')
save(fullFileName,'ssT1','ssT2','ssEOT','ssPT','CDEIS','FCP','options','effects','individual_ref')
save(fullFileName_CDEIS,'CDEIS','FCP','options','effects','individual_ref')
fprintf('Saved as %s\n',fullFileName);

% Load and adapt file name list
load('Data/fileNameList.mat','fileNameList')
fileNameList.(thisFile).(printTreatments)               = fullFileName;
fileNameList.([thisFile,'_CDEIS']).(printTreatments)    = fullFileName_CDEIS;
save('Data/fileNameList.mat','fileNameList')

%--------------------------------------------------------------------------
end