function options = IBD_treatmentDatabase(scenario)
%==========================================================================
% options = IBD_treatmentDatabase(scenario)
%==========================================================================
% Details of the different virtual clinical studies
% 16 November 2020
%--------------------------------------------------------------------------
%-- input
% scenario:         treatment name (see below)
%--------------------------------------------------------------------------
%-- output
% options:          treatment definitions
%==========================================================================

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>(%s)\n',fileName,scenario)

%--------------------------------------------------------------------------

switch scenario
    
    %----------------------------------------------------------------------
    % Single treatments
    %----------------------------------------------------------------------
    case 'cytokineInhibitor'
        % Cytokine inhibitor
        treatments          = {'cytokine'};
        options.etas        = [0.05 0.1 0.15 0.2 0.25 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0 0.1456 0.2258];
        options.eta30       = 0.1456;       % 29.998
        options.eta50       = 0.2258;       % 50.041

    %----------------------------------------------------------------------
    case 'integrinInhibitor'
        % Integrin inhibitor
        treatments          = {'integrin'};
        options.etas        = [0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 0.99 0.261 0.3785];
        %options.etas        = [0.2 0.4 0.6 0.8 1.0 0.261 0.3785];
        %options.etas        = [0.2 0.4 0.6 0.8 0.261 0.3785];
        %options.etas        = [0.8 0.9 0.99];
        options.eta30       = 0.261;        % 30.020
        options.eta50       = 0.3785;       % 49.996
        
    %----------------------------------------------------------------------
    case 'S1PRmodulator'
        % S1PR modulator
        treatments          = {'S1P_egress','S1P_Treg'};               
     	options.etas        = [combvec([0 0.25 0.5 0.75 0.9 0.95 0.99 1],[0 -1 -2 -4]),[0.51;0],[0.723;0]];
        options.eta30       = [0.51;0];  	% 29.975
        options.eta50       = [0.723;0];    % 49.996
       
	%----------------------------------------------------------------------
    case 'phosphatidylcholine'
        % Orally administered phosphatidylcholine
        treatments          = {'mucus'};
        options.etas        = [-0.1 -0.2 -0.3 -0.4 -0.5 -0.6 -0.8 -1 -0.3292 -0.4507];
        options.eta30       = -0.3292;       % 29.998
        options.eta50       = -0.4507;       % 50.004
        
	%----------------------------------------------------------------------
    case 'FMT'
        % Fecal microbial transplantation
        treatments          = {'microbiota_Th1','microbiota_Th2','microbiota_Th17'};
        etaTh2              = [1/3 0.4 0.6 0.8 0.9 0.721 0.945];
        options.etas        = [(1-etaTh2)/2;etaTh2;(1-etaTh2)/2];
        options.eta30       = options.etas(:,end-1);	% 30.005
        options.eta50       = options.etas(:,end);   	% 50.026
        
    %----------------------------------------------------------------------
    case 'methotrexate'
        % Folic acid analogue, anti-proliferative and anti-inflammatory effects
        treatments          = {'cytokine','proliferation','TCellApoptosis'};
        eta                 = [0.05 0.1 0.15 0.2 0.3 0.4 0.105 0.1706];
        options.etas        = [eta;eta;-eta];
        options.eta30       = [0.105;0.105;-0.105];         % 29.983
        options.eta50       = [0.1706;0.1706;-0.1706];      % 49.989
        
    %----------------------------------------------------------------------
    case 'azathioprine'
        % Prodrug of 6-MP, a purine analog
        treatments          = {'proliferation'};
        options.etas        = [0.2 0.4 0.6 0.8 0.9 0.99 0.518]; 
        options.eta30       = 0.518;        % 29.99
        options.eta50       = nan;
        
    %----------------------------------------------------------------------
    case 'antibiotics'
        % Antibiotic treatment
        treatments          = {'antibiotic'};
        options.etas        = [0.2 0.4 0.6 0.8 0.9];
        options.eta30       = nan;
        options.eta50       = nan;
    
  	%----------------------------------------------------------------------
    otherwise
        error('Specified scenario has not been defined.')
end

options.duration    = 6*4*7*24;             % 6 months
options.obsTime     = 6*4*7*24;             % 6 months
options.T1T2        = [1*4*7*24,3*4*7*24];  % 1 month, 3 months

options.scenario    = scenario;
options.treatments  = treatments;

%--------------------------------------------------------------------------
end