function effects = IBD_treatmentEffects(treatments,individual_ref)
%==========================================================================
% effects = IBD_treatmentEffects(treatments,individual_ref)
%==========================================================================
% Define effects of the different treatment mechanisms as constant
% parameter/reation rate inhibition
% 16 November 2020
%--------------------------------------------------------------------------
%-- input
% treatments:    	list of treatment mechanisms (see below)
% individual_ref:   reference individual struct
%--------------------------------------------------------------------------
%-- output
% effects:          struct of effects
%==========================================================================

I = individual_ref.I;
affectedPar     = {};
affectedRates   = {};
newPar          = {};
saveIdx         = [];   % additional states to save time course for

for i = 1:length(treatments)
    whichTreatment      = treatments{i};
    affectedPar{i}      = [];
    affectedRates{i}    = [];
    newPar{i}           = [];

    switch whichTreatment

        case 'proliferation'
            affectedPar{i} = [...
                I.pTn1,...
                I.pTni...
            ];

        case 'TCellApoptosis'
            affectedPar{i} = [...
                I.muT_LN,...
                I.muT_LP,...
                I.muTeff,...
                I.muTprol...
            ];

        case 'antibiotic'
            affectedPar{i} = [...
                I.pBactLu,...
                I.pBact...
            ];

        case 'cytokine'
            % Treatment effect on parameters
            affectedPar{i} = [...
                I.wcyto_RecNeut_Th1,...
                I.wcyto_RecNeut_Th17,...
                I.wcyto_RecNeut_Neut,...
                I.wcyto_RecNeut_M,...
                I.wcyto_RecM_Th1,...
                I.wcyto_RecM_Th17,...
                I.wcyto_RecM_Neut,...
                I.wcyto_RecM_M,...
                I.wcyto_ActM_Th1,...
                I.wcyto_ActM_Th17,...
                I.wcyto_ActM_Neut,...
                I.wcyto_ActM_M,...
                I.wcyto_ActDC_Th1,...
                I.wcyto_ActDC_Th17,...
                I.wcyto_ActDC_Neut,...
                I.wcyto_ActDC_M,...
                I.wcyto_DamageEpi_Th1,...
                I.wcyto_DamageEpi_Th17,...
                I.wcyto_DamageEpi_Th2,...
                I.wcyto_DamageEpi_Neut,...
                I.wcyto_DamageEpi_M,...
                I.wcyto_DamageTis_Th1,...
                I.wcyto_DamageTis_Th17,...
                I.wcyto_DamageTis_Th2,...
                I.wcyto_DamageTis_Neut,...
                I.wcyto_DamageTis_M,...
            ];

        case 'integrin'
            % Treatment effect on parameters
            affectedPar{i} = [...
                I.cRecM,...
                I.lambdaMmax,...
                I.cRecDC,...
                I.lambdaT_LN,...
                I.lambdaNeutMax...
            ];% What about inflow of T cells into LP: Do they disappear from the system? --> decrease migration rate, increase death rate by the same amount = loss into blood

        case 'S1P_egress'
            % Treatment effect on parameters
            affectedPar{i} = [...
                I.muT_LN...
            ];
            % Save time course for additional states
            %saveIdx = [saveIdx,I.iTreg_eff_LN,I.iTreg_eff_LP,I.Temh_tot_LP,I.Tn_LN,I.Tcm_LN]; % too large to save
            saveIdx = [saveIdx,I.iTreg_eff_LP];

        case 'S1P_Treg'
            % Treatment effect on parameters
            affectedPar{i} = [...
                I.wcyto_DeactM_Treg,...
                I.wcyto_DeactDC_Treg...
            ];
            % Treatment effect on rates
            affectedRates{i} = [72,73,81,82,85,86,87,88,89];
            % Save time course for additional states
            %saveIdx = [saveIdx,I.iTreg_eff_LN,I.iTreg_eff_LP,I.Temh_tot_LP,I.Tn_LN,I.Tcm_LN]; % too large to save
            saveIdx = [saveIdx,I.iTreg_eff_LP];

        case 'mucus'
            % Treatment effect on rates
            affectedRates{i} = [30];

        case 'microbiota_Th1'
            % Treatment effect on parameters (new parameter value)
            newPar{i}        = [I.theta1bact];

        case 'microbiota_Th2'
            % Treatment effect on parameters (new parameter value)
            newPar{i}        = [I.theta2bact];

        case 'microbiota_Th17'
            % Treatment effect on parameters (new parameter value)
            newPar{i}        = [I.theta17bact];


        otherwise
            error('Specified treatment has not been implemented') 
    end
end

effects.affectedPar     = affectedPar;
effects.affectedRates   = affectedRates;
effects.newPar          = newPar;
effects.saveIdx         = unique(saveIdx);

% Update index of output states
Ired 	= individual_ref.Ired;
i1 = length(Ired.stateName);
for i = 1:length(saveIdx)
    Ired.stateName{i+i1}            = I.stateName{saveIdx(i)};
    Ired.(I.stateName{saveIdx(i)})  = i+i1;
end
effects.Ired = Ired;

%--------------------------------------------------------------------------
end

