%==========================================================================
% Paper_AnalysisOfIBD
%==========================================================================
% Plot comparison of parameter distributions, comparison of pre-trigger
% steady state distributions, extent vs number of necessary parameter
% changes
% 6 April 2021
%==========================================================================

clearvars

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

classDefinition = IBD_centroids();

%==========================================================================
%% First row: parameter distributions

% Load data
load(fileNameList.CompareParameters)

%--------------------------------------------------------------------------
% Sort by correlation
[p_table_sortedCor] = sortrows(p_table,'t_KS','descend','MissingPlacement','last');
stateOrder = p_table_sortedCor.Properties.RowNames;
p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);

%--------------------------------------------------------------------------
% Plot most different between healthy and IBD as histogram
N = 4;
options.colours         = [IBD_myColours('healthy');IBD_myColours('IBD')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = true;
options.removeLegend    = true;
options.addText         = {};
options.ncolrow         = [4 1];
for i = 1:N
    options.addText{i} = sprintf('$D=%.2g$',p_table{i,'t_KS'});
end
f1 = IBD_plotParDist(par,individual_ref,{'healthy','IBD'},p_table.idx(1:N),options);

%==========================================================================
%% Second row: pre-trigger steady state distributions

% Load data
load(fileNameList.CompareStates)

%--------------------------------------------------------------------------
% Remove additional states, sort by correlation
p_table = p_table(1:individual_ref.I.nrOfStates,:);
[p_table_sortedCor] = sortrows(p_table,'t_KS','descend','MissingPlacement','last');
stateOrder = p_table_sortedCor.Properties.RowNames;
p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);

%--------------------------------------------------------------------------
% Plot most different between healthy and IBD as histogram...
N = 4;
options.colours         = [IBD_myColours('healthy');IBD_myColours('IBD')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = true;
options.removeLegend    = true;
options.addText         = {};
for i = 1:N
    options.addText{i} = sprintf('$D=%.2g$',p_table{i,'t_KS'});
end
f2 = IBD_plotParDist(ss0,individual_ref,{'healthy','IBD'},p_table.idx(1:N),options);

%==========================================================================
%% Third row left: extent vs number of necessary parameter changes

% Load data
load(fileNameList.CombineNecessaryParChanges,'minimalPar','individual_ref','minimalParIdx','classWhenSetBack')

N_IBD   = size(minimalPar,2);

% Distinguish necessary parameters by class when set back
for ind = 1:N_IBD
    thisMinimalParIdx           = minimalParIdx{ind};
    thisClassWhenSetBack        = classWhenSetBack(thisMinimalParIdx,ind);
    minParIdx.healthy{ind}      = thisMinimalParIdx(thisClassWhenSetBack==1);
    minParIdx.problems{ind}     = thisMinimalParIdx(thisClassWhenSetBack==0);
    minParIdx.chronic{ind}      = thisMinimalParIdx(thisClassWhenSetBack>2);
    if ~sum(thisClassWhenSetBack==2)==0
        error('Something went wrong here!')
    end
end
thisMinParIdx   = minParIdx.healthy;

% Number of parameters changed per individual for each group
nrOf.problems  	= cellfun(@length,minParIdx.problems);
nrOf.healthy   	= cellfun(@length,minParIdx.healthy);
nrOf.chronic   	= cellfun(@length,minParIdx.chronic);
nrOf.all        = cellfun(@length,minimalParIdx);

f3 = necParCh_extentVsNumber(minimalPar,thisMinParIdx,nrOf,N_IBD,individual_ref,false);

%==========================================================================
%% Third row right: combinations of disease-relevant parameter changes

combiNr = 4;
patientIdx = find(nrOf.healthy==combiNr);

N = 20;        % nr of patients to plot

colours = IBD_colourMap('dark rainbow',40);
colours = repmat(colours,[4,1]);

f4 = figure;
hold on
for i = 1:N
    for j = 1:combiNr
        plot(i,minParIdx.healthy{patientIdx(i)}(j),'x','Color',colours(minParIdx.healthy{patientIdx(i)}(j),:))
    end
end
xl = xlim;
yl = ylim;
yticks(1:yl(2))
yticklabels({})
xticks(1:N)
xticklabels({})
ylabel('Parameters')
xlabel('Patients')
f4 = IBD_nicePlot(f4);

%==========================================================================
%% Overall figure

f = figure;
for i = 1:8
    s(i) = subplot(4,4,i);
    set(gca,'visible','off')
end
s(9) = subplot(4,4,[9:10]);
set(gca,'visible','off')
s(10) = subplot(4,4,[11:12]);
set(gca,'visible','off')
s(11) = subplot(4,4,[13:16]);
set(gca,'visible','off')

% Adapt subplot positions
for i = 5:8
    s(i).Position(2) = s(i).Position(2)-0.12;
end
for i = [9 10]
    s(i).Position(2)  = s(i).Position(2)-0.25;
    s(i).Position(4)  = s(i).Position(4)*1.2;
end

% Parameters
for i = 1:4
    new(i) = copyobj(f1.Children(i),f);
    new(i).Position = s(5-i).Position;
    new(i).YTick = [];
end

% Pre-trigger steady state
for i = 1:4
    new(i+4) = copyobj(f2.Children(i),f);
    new(i+4).Position = s(5-i+4).Position;
    new(i+4).YTick = [];
end

% Disease-relevant parameter changes
new(9) = copyobj(f4.Children(1),f);
new(9).Position = s(9).Position;
new(9).Position(3) = s(9).Position(3)*0.8;

% Combinations of disease-relevant parameter changes
new(10) = copyobj(f3.Children(1),f);
new(10).Position = s(10).Position;

% A/B/C titles
ABCtitle(new(4),'{\Large\textbf{A}}\ \,{\textbf{Parameters}}',-1.53,1.7);
ABCtitle(new(8),'{\Large\textbf{B}}\ \,{\textbf{Pre-trigger steady state variables}}',-1.97e6,1.7);
ABCtitle(new(9),'{\Large\textbf{C}}\ \,{\textbf{Possible combinations}}',-5,1.3);
ABCtitle(new(10),'{\Large\textbf{D}}\ \,{\textbf{Disease-relevant parameter changes}}',-10.5,1.3);

l = legend(new(5),{'healthy','IBD'},'box','off','Location','west');

%==========================================================================

extraCode = struct;
extraCode.Axis = 'clip mode=individual';
IBD_saveFigure(f,'Paper_AnalysisOfIBD','tikz',extraCode)

% Change line 384 to
% legend style={at={(-0.5,1.6)}, anchor=west, legend cell align=left, align=left, fill=none, draw=none},

%==========================================================================
% LOCAL FUNCTIONS

% Average extent of change vs number of changes
function f = necParCh_extentVsNumber(minimalPar,thisMinParIdx,nrOf,N_IBD,individual_ref,reducePoints)
extent = nan(1,N_IBD);
for i = 1:N_IBD
    change = minimalPar(thisMinParIdx{i},i)./individual_ref.par(thisMinParIdx{i})';
    change(change<1) = 1./change(change<1);
    extent(i) = mean(change);
end
f = figure;
hold on
xvalues = nrOf.healthy(nrOf.chronic==0 & nrOf.problems==0);
yvalues = extent(~nrOf.chronic & ~nrOf.problems);
if reducePoints
    idx = 1:5:length(xvalues);
else
    idx = 1:length(xvalues);
end
plot(xvalues(idx),yvalues(idx),'x','Color',IBD_myColours('crosses1'));
xlabel('Number of parameter changes')
ylabel('Mean rel.\ change')

% Add average line
xnumbers        = sort(unique(xvalues));
averageExtent   = nan(size(xnumbers));
for i = 1:length(xnumbers)
    if sum(xvalues==xnumbers(i))<5
        break
    end
    averageExtent(i) = mean(yvalues(xvalues==xnumbers(i)));
end
plot(xnumbers(~isnan(averageExtent)),averageExtent(~isnan(averageExtent)),'k');

f = IBD_nicePlot(f);

end

% Make A/B/C title
function t = ABCtitle(ax,str,posX,posFactorUp)
pos	= [posX,ax.YLim(2)*posFactorUp,0];
t   = text(ax,'String',str,'HorizontalAlignment','left','VerticalAlignment','top','Position',pos,'Interpreter','latex');
end
%--------------------------------------------------------------------------