%==========================================================================
% Paper_AnalysisOfResponsiveness
%==========================================================================
% Plot comparison of parameter distributions, comparison of pre-treatment
% steady state distributions, response rates over eta
% Parameters/states only for cytokine inhibitor
% 6 April 2021
%==========================================================================

clearvars

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

load(fileNameList.ClinicalIBDpopulation,'par','ssMI','individual_ref');

scenario = 'cytokineInhibitor';

% Responders vs non-responders
S               = load(fileNameList.constantTreatment_CDEIS.(scenario),'options','effects','CDEIS');
S.response      = S.CDEIS.ssEOT<4;
S.rr            = sum(S.response,2)/size(S.response,2)*100;
S.idx30         = find(round(S.rr,1)==30);
if isempty(S.idx30)
    S.idx30     = nan;
end
S.idx50         = find(round(S.rr,1)==50);
if isempty(S.idx50)
    S.idx50     = nan;
end
S.idx           = [S.idx30,S.idx50];
responders      = S.CDEIS.ssEOT(S.idx30,:)<4;
nonresponders   = ~responders;

%==========================================================================
%% Third row: parameter distributions

% Load data
load(fileNameList.CompareParametersResponders)

p_table = t_KS_30(:,scenario);
p_table.absCor = abs(p_table.(scenario));

%--------------------------------------------------------------------------
% Sort by correlation
[p_table_sortedCor] = sortrows(p_table,'absCor','descend','MissingPlacement','last');
stateOrder = p_table_sortedCor.Properties.RowNames;
p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);

parStruct               = struct;
parStruct.responders    = par(:,responders);
parStruct.nonresponders = par(:,nonresponders);

%--------------------------------------------------------------------------
% Plot most different between healthy and IBD as histogram
N = 4;
options.colours         = [IBD_myColours('responders');IBD_myColours('nonresponders')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = true;
options.removeLegend    = true;
options.addText         = {};
options.ncolrow         = [4 1];
for i = 1:N
    options.addText{i} = sprintf('$D=%.2g$',p_table{i,scenario});
end
f1 = IBD_plotParDist(parStruct,individual_ref,{'responders','nonresponders'},p_table.idx(1:N),options);

%==========================================================================
%% Fourth row: pre-trigger steady state distributions

% Load data
load(fileNameList.CompareStatesResponders)

p_table = t_KS_30(:,scenario);
p_table.absCor = abs(p_table.(scenario));

ssMIStruct               = struct;
ssMIStruct.responders    = ssMI(:,responders);
ssMIStruct.nonresponders = ssMI(:,nonresponders);

%--------------------------------------------------------------------------
% Remove additional states, sort by correlation
p_table = p_table(1:individual_ref.I.nrOfStates,:);
[p_table_sortedCor] = sortrows(p_table,'absCor','descend','MissingPlacement','last');
stateOrder = p_table_sortedCor.Properties.RowNames;
p_table.idx = (1:size(p_table,1))';
p_table = p_table(stateOrder,:);
% Remove mucus
p_table(p_table.idx==individual_ref.I.mucus,:) = [];

%--------------------------------------------------------------------------
% Plot most different between healthy and IBD as histogram...
N = 4;
options.colours         = [IBD_myColours('responders');IBD_myColours('nonresponders')];
options.removeYTicks    = true;
options.removeXLabel    = true;
options.tikz            = true;
options.removeLegend    = true;
options.addText         = {};
options.plotReference   = false;
options.threshold       = [0.95 0.75 0.75 0.95];
for i = 1:N
    options.addText{i} = sprintf('$D=%.2g$',p_table{i,scenario});
end
f2 = IBD_plotParDist(ssMIStruct,individual_ref,{'responders','nonresponders'},p_table.idx(1:N),options);

%==========================================================================
%% First two rows: response rates over eta

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','antibiotics','azathioprine'};
scenarioNames = {'Cytokine inhibitor',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Antibiotics',...
                 'Proliferation inhibitor'};

S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i}) = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
end

% Plot response rates over eta
f3 = figure;
n = 4;
m = 2;
set(f3, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

col_EOT = [0 0 102]./255;
col_PT = [51 102 0]./255;

for i = 1:length(scenarios)
    scenario    = scenarios{i};
    options     = S.(scenario).options;
    CDEIS       = S.(scenario).CDEIS;
    
    subplot(m,n,i);
    ax = gca;
    
    % Do not plot the extra points for response rate 30/50%
    % Restrict to one eta for treatments with multiple effects
    if strcmp(scenario,'FMT')
        options.etas = options.etas(2,:);
        etaIdx = [1:length(options.etas)-2,length(options.etas)];
    elseif strcmp(scenario,'azathioprine')
        etaIdx = 1:length(options.etas)-1;
    elseif strcmp(scenario,'antibiotics')
        etaIdx = 1:length(options.etas);
    elseif strcmp(scenario,'methotrexate')
        options.etas = options.etas(1,:);
        etaIdx = 1:length(options.etas)-2;
    elseif strcmp(scenario,'S1PRmodulator')
        etaIdx = options.etas(2,:)==0;
        etaIdx = etaIdx(1:end-2);
        options.etas = options.etas(1,:);
    else
        etaIdx = 1:length(options.etas)-2;
    end
    
    IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssEOT(etaIdx,:),struct('colour',col_EOT,'title',[scenarioNames{i},'\phantom{y}'],'tikz',true),ax);
    IBD_plotResponseRate(options.etas(etaIdx),CDEIS.ssPT(etaIdx,:),struct('colour',col_PT,'tikz',true),ax);
    if strcmp(scenario,'phosphatidylcholine')
        xticks([-0.8,-0.4,0])
    end
    if ~ismember(i,[1,5])
        ylabel('')
    end
    ax = gca;
    xlabel({ax.XLabel.String,''})
end

f3 = IBD_nicePlot(f3);

%==========================================================================
%% Overall figure

f = figure;
for i = 1:24
    s(i) = subplot(6,4,i);
    set(gca,'visible','off')
end

% Adapt subplot positions
for i = 5:8
    s(i).Position(2) = s(i).Position(2)-0.06;
end
for i = 9:12
    s(i).Position(2) = s(i).Position(2)-0.16;
end
for i = 13:16
    s(i).Position(2) = s(i).Position(2)-0.26;
end

% Parameters
for i = 9:12
    new(i) = copyobj(f1.Children(end-(i-9)),f);
    new(i).Position = s(i).Position;
    new(i).YTick = [];
end

% Pre-treatment steady state
for i = 13:16
    new(i) = copyobj(f2.Children(end-(i-13)),f);
    new(i).Position = s(i).Position;
    new(i).YTick = [];
end

% Reponse rates over eta
for i = 1:7
    new(i) = copyobj(f3.Children(end-(i-1)),f);
    new(i).Position = s(i).Position;
    new(i).YTick = 0:20:100;
end
for i = [2 3 4 6 7]
    new(i).YTickLabel = {};
end
new(5).YLabel.Position(2) = new(5).YLim(end)*1.4;
text(new(5),new(5).YLabel.Position(1),new(5).YLabel.Position(2),new(5).YLabel.String,'HorizontalAlignment','center','Rotation',90);
new(5).YLabel.String = '';
new(1).YLabel.String = '';

% Legend
new(8) = s(8);
plot(new(8),1,1,'Color',col_EOT)
hold(new(8),'on')
plot(new(8),1,1,'Color',col_PT)
new(8).XLim = [0 0.1];
new(8).YLim = [0 0.1];
legend(new(8),{'end-of-treatment','post-treatment'},'box','off','Location','west')
new(8).Visible = 'off';

% A/B/C titles
ABCtitle(new(1),'{\Large\textbf{A}}\ \,{\textbf{Response rates}}',-0.6,180);
ABCtitle(new(1),'{\Large\textbf{B}}\ \,{\textbf{Parameters}}',-0.6,-260);
ABCtitle(new(1),'{\Large\textbf{C}}\ \,{\textbf{Pre-treatment steady state variables}}',-0.6,-500);

xlab = xlabel(new(16),{'|'},'Color',[1 1 1]);

l = legend(new(16),{'responders','non-responders'},'box','off','Location','west');


%==========================================================================

IBD_saveFigure(f,'Paper_AnalysisOfResponsiveness','tikz')
% Change line 637 (652) to
% legend style={at={(0.2,1.7)}, anchor=west, legend cell align=left, align=left, fill=none, draw=none}

%==========================================================================
% LOCAL FUNCTIONS

% Make A/B/C title
function t = ABCtitle(ax,str,posX,posY)
pos	= [posX,posY,0];
t   = text(ax,'String',str,'HorizontalAlignment','left','VerticalAlignment','top','Position',pos,'Interpreter','latex');
end
%--------------------------------------------------------------------------