%==========================================================================
% Paper_CombinationTreatments
%==========================================================================
% Barplot of combination of cytokine inhibitor with other treatments
% 27 March 2022
%==========================================================================

clearvars 

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

scenarios = {'cytokineInhibitor','integrinInhibitor','S1PRmodulator',...
    'phosphatidylcholine','FMT','azathioprine'};
scenarioNames = {'Cytokine inhibitor',...
                 'Anti-cell adhesion',...
                 'S1PR modulator',...
                 'Phosphatidylcholine',...
                 'FMT',...
                 'Proliferation inhibitor'};

% Load data
S = struct;
for i = 1:length(scenarios)
    S.(scenarios{i})                        = load(fileNameList.constantTreatment_CDEIS.(scenarios{i}),'options','effects','CDEIS');
    S.(['cytokineInhibitorX',scenarios{i}]) = load(fileNameList.constantTreatment_CDEIS.(['cytokineInhibitorX',scenarios{i}]),'options','effects','CDEIS');
end

%--------------------------------------------------------------------------
responseRates   = struct;
y               = [];   % bar   --> responders to any (single or combination)
y2              = [];   % line  --> responders to combination (<= bar)
y3              = [];   % line  --> responders to first- or second-line
scenario1       = 'cytokineInhibitor';

for i = 1:length(scenarios)
    scenario2    = scenarios{i};
    scenarioX   = ['cytokineInhibitorX',scenarios{i}];
    
    A = S.(scenarioX).options.etas(1:size(S.(scenario1).options.etas,1));
    B = S.(scenario1).options.etas;
    i_eta1 = find(all(B==A,1),1);
    
    A = S.(scenarioX).options.etas(size(S.(scenario1).options.etas,1)+1:end);
    B = S.(scenario2).options.etas;
    i_eta2 = find(all(B==A,1),1);
    
    responders1 = (S.(scenario1).CDEIS.ssEOT(i_eta1,:)<4) + 1;  % 1 = non-responder, 2 = responder
    responders2 = (S.(scenario2).CDEIS.ssEOT(i_eta2,:)<4) + 1;  % 1 = non-responder, 2 = responder
    respondersX = (S.(scenarioX).CDEIS.ssEOT<4)           + 1;  % 1 = non-responder, 2 = responder
    N_IBD = length(responders1);
    
    for s1 = [1 2]
        for s2 = [1 2]
            for sX = [1 2]
                RR(s1,s2,sX) = sum(responders1==s1 & responders2==s2 & respondersX==sX)/N_IBD*100;
            end
        end
    end
    
    y   = [y;[sum(sum(RR(2,:,:))),sum(RR(1,2,:)),RR(1,1,2)]];
    y2  = [y2;sum(sum(RR(:,:,2)))];
    y3  = [y3;sum(sum(RR(2,:,:)))+sum(RR(1,2,:))];
    responseRates.(scenarioX) = RR;
    
    lose(i,1) = RR(2,1,1);      % responder to cytokine inhibitor but not combination treatment
    lose(i,2) = RR(1,2,1);      % responder to alternative treatment but not combination treatment
end

% Left bar: 
y_left  = y(:,1:2);
y_left(:,3) = 0;

% Right bar:
lose(:,3) = 0;
y_right = y-lose;

% Total response rates
y_sequential = sum(y_left, 2);
y_combination = sum(y_right, 2);
y_plot = [y_sequential y_combination];

%--------------------------------------------------------------------------
% A: response rates to sequential and combination treatment
f1 = figure;
n = 3;
m = 1.5;
set(f1, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

% Barplot to show response to any treatment
b = bar(y_plot,'BarWidth',0.6);
ylim([0 100])
ylabel('Response rate [%]')
xticklabels(scenarioNames)
xtickangle(45)
ax = gca;
myColourMap = IBD_myColours('sequentialVsCombination');
for i = 1:length(b)
    b(i).FaceColor = myColourMap(i,:);
end

% Leged
l = legend({...
    'sequential treatment',...
    'combination treatment'...
    },'Location','northwest','box','off');

f1 = IBD_nicePlot(f1);

%--------------------------------------------------------------------------
% B: patients responding to only sequential or combination treatment
y_plot2 = [sum(lose,2), y_right(:,3)];

f2 = figure;
n = 3;
m = 1.5;
set(f2, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

% Barplot to show response to any treatment
b = bar(y_plot2,'BarWidth',0.6);
ylim([0 60])
ylabel('Response rate [%]')
xticklabels(scenarioNames)
xtickangle(45)
ax = gca;
myColourMap = IBD_myColours('sequentialVsCombination2');
for i = 1:length(b)
    b(i).FaceColor = myColourMap(i,:);
end

% Leged
l = legend({...
    'sequential, but not combination',...
    'combination, but not sequential'...
    },'Location','northwest','box','off');

f2 = IBD_nicePlot(f2);


%--------------------------------------------------------------------------
% C: A and B combined
y_plot3 = [y_plot y_plot2];

f3 = figure;
n = 3;
m = 1.5;
set(f3, 'Units', 'normalized', 'Position', [0.2, 0.1, 0.2*n, 0.3*m]);

% Barplot to show response to any treatment
b = bar(y_plot3,'BarWidth',0.6);
ylim([0 120])
ylabel('Fraction of responders [%]')
xticklabels(scenarioNames)
xtickangle(45)
ax = gca;
myColourMap = [IBD_myColours('sequentialVsCombination');IBD_myColours('sequentialVsCombination2')];
for i = 1:length(b)
    b(i).FaceColor = myColourMap(i,:);
end

% Leged
l = legend({...
    'to first- or second-line treatment',...
    'to combination treatment'...
    'to first- or second-line, but not combination treatment',...
    'to combination, but neither first- nor second-line treatment'...
    },'Location','northwest','box','off');

f3 = IBD_nicePlot(f3);


%--------------------------------------------------------------------------
IBD_saveFigure(f1,'Paper_CombinationTreatments_A','tikz')
IBD_saveFigure(f2,'Paper_CombinationTreatments_B','tikz')
IBD_saveFigure(f3,'Paper_CombinationTreatments_C','tikz')


% Change line 24 to
% legend style={at={(0.03,1.125)}, anchor=north west, legend cell align=left, align=left, fill=none, draw=none}

%==========================================================================
% LOCAL FUNCTIONS

% Average extent of change vs number of changes
function h = hatchedArea(ax,x1,x2,y1,y2,m,d,col)
% ax: axis
% x1, x2, y1, y2: coordinates of rectangle to hatch
% m: slope
% d: distance between lines

diffX = sind(atand(m))*d;
diffY = m*diffX;

dotsX = x1:diffX:x2;
dotsY = y1:diffY:y2;

h = gobjects(1,length(dotsX)+length(dotsY));

if ~exist('col','var')
    col = [0 0 0];
end

for j = 1:length(dotsX)
    xvalue1 = dotsX(j);
    xvalue2 = min((y2-y1)/m+xvalue1,x2);
    yvalue1 = y1;
    yvalue2 = yvalue1+m*(xvalue2-xvalue1);
    h(j) = plot(ax,[xvalue1,xvalue2],[yvalue1,yvalue2],'Color',col);
    if ~isempty(h(j))
        h(j).Annotation.LegendInformation.IconDisplayStyle = 'off';
    end
end
for j = 1:length(dotsY)
    xvalue1 = x1;
    xvalue2 = min((y2-dotsY(j))/m+xvalue1,x2);
    yvalue1 = dotsY(j);
    yvalue2 = yvalue1+m*(xvalue2-xvalue1);
    h = plot([xvalue1,xvalue2],[yvalue1,yvalue2],'Color',col);
    if ~isempty(h)
        h.Annotation.LegendInformation.IconDisplayStyle = 'off';
    end
end

end
%--------------------------------------------------------------------------