%==========================================================================
% Paper_ExamplePatients
%==========================================================================
% Exemplary patient profiles
% - mucosal injury
% - treatment with cytokine inhibitor
% - treatment
% 7 April 2021
%==========================================================================

clearvars

fileName = IBD_getFileName(mfilename('fullpath'));
fprintf('<strong>%s</strong>\n',fileName)

%--------------------------------------------------------------------------
thisFile = strrep(fileName,'IBD_','');

% Load file name list
load('Data/fileNameList.mat','fileNameList')

% Load data
load(fileNameList.ClinicalIBDpopulation)
TNF = load(fileNameList.constantTreatment_CDEIS.cytokineInhibitor,'options','effects','CDEIS','FCP','individual_ref');
integrin = load(fileNameList.constantTreatment_CDEIS.integrinInhibitor,'options','effects','CDEIS','FCP','individual_ref');
individual_ref = TNF.individual_ref;
I = individual_ref.I;

%--------------------------------------------------------------------------
% Response rate 30 %
TNF.i_eta   = 14;
fprintf('Cytokine inhibtor with eta=%.4f\n',TNF.options.etas(TNF.i_eta))
integrin.i_eta  = 11;
fprintf('integrin modulator with eta=%.4f\n',integrin.options.etas(1,integrin.i_eta))

% Responders:
TNF.responders      = TNF.CDEIS.ssEOT(TNF.i_eta,:)<4;
TNF.nonresponders   = TNF.CDEIS.ssEOT(TNF.i_eta,:)>=4;
TNF.relapse         = TNF.CDEIS.ssPT(TNF.i_eta,:)>=4 & TNF.CDEIS.ssEOT(TNF.i_eta,:)<4;

integrin.responders      = integrin.CDEIS.ssEOT(integrin.i_eta,:)<4;
integrin.nonresponders   = integrin.CDEIS.ssEOT(integrin.i_eta,:)>=4;
integrin.relapse         = integrin.CDEIS.ssPT(integrin.i_eta,:)>=4 & integrin.CDEIS.ssEOT(integrin.i_eta,:)<4;

if TNF.options.duration~=integrin.options.duration
    error('Different treatment durations!')
end

%--------------------------------------------------------------------------
% 2 patients

% 50 %:
% A: 1 0 0 0        --> 3ok, 14ok, 19(ok), 52, 84, 104
% B: 1 1 1 0        --> 1x, 10x, 74xx, 100x, 103(ok), 137x, 142x, 148x, 153x, 156x, 188x, 189x, 194x

% alternativ:
% A: 0 0 1 0        --> 31ok         225ok         385(ok)         459ok 621ok!         689(ok)
% B: 1 0 1 1        --> 4x    20x    32x    39(x)    47ok!    65ok!    88x    92x   101ok   136x   165x   193x   206   266   280

%patientA = 621;
%patientB = 65;

% 30%
% A: 1 0 0 0        --> 3 (ok)    24 ok    32x    69ok   155x   238   242   263   319   457
% B: 1 1 1 0        --> 33x   120(x-ok)   228x   229x   295x   299x   397x 479x   658x   665x

% alternativ:
% A: 0 0 1 0        --> 65(ok)    68(ok)   380(ok)   405ok(..)   647ok(..) 745x   796x   926x   967x   971ok
% B: 1 0 1 1        --> 215ok   328x   365(ok)   393(ok)   418(ok)   442x   461x   545ok   579x 

patientA = 647;
patientB = 215;

%--------------------------------------------------------------------------
% Specify different individuals incl. inflammation scenario and knockout
i = 1;
individual(i)                                   = individual_ref;
individual(i).par                               = par(:,patientA)';
individual(i).infection.epiDamage               = 1;
individual(i).infection.tisDamage               = 1;
%individual(i).title                             = 'Patient A';

individual(2) = individual(1);

i = 3;
individual(i)                                   = individual_ref;
individual(i).par                               = par(:,patientB)';
individual(i).infection.epiDamage               = 1;
individual(i).infection.tisDamage               = 1;
%individual(i).title                             = 'Patient B';

individual(4) = individual(3);
%--------------------------------------------------------------------------
% For each individual: rerun steady state
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind) = IBD_runSteadyState(individual(ind));
end

%--------------------------------------------------------------------------
% For each individual: run mucosal injury
for ind = 1:length(individual)
    fprintf('Individual %i:\t',ind)
    individual(ind)	= IBD_runInfection(individual(ind),true);
end

%--------------------------------------------------------------------------
% For each individual: run treatment scenario
individual_x = individual;      % save mucosal injury time course
for ind = [1 3]
    fprintf('Individual %i:\t',ind)
    individual(ind).X_ss = individual(ind).X_ss_after;
    individual(ind) = IBD_runTreatment(individual(ind),TNF.options.duration,TNF.options.etas(:,TNF.i_eta),...
        TNF.effects.affectedPar,TNF.effects.affectedRates,TNF.effects.newPar,false);
end
for ind = [2 4]
    fprintf('Individual %i:\t',ind)
    individual(ind).X_ss = individual(ind).X_ss_after;
    individual(ind) = IBD_runTreatment(individual(ind),integrin.options.duration,integrin.options.etas(:,integrin.i_eta),...
        integrin.effects.affectedPar,integrin.effects.affectedRates,integrin.effects.newPar,false);
end

% Combine the time courses
T_treat = 200*24;
for ind = 1:length(individual)
    idx_treat = find(individual_x(ind).T<T_treat,1,'last');
 	individual_x(ind).T     = [individual_x(ind).T(1:idx_treat);(individual(ind).T+T_treat)];
    individual_x(ind).X     = [individual_x(ind).X(1:idx_treat,:);(individual(ind).X)];
    individual_x(ind).Xadd  = [individual_x(ind).Xadd(1:idx_treat,:);(individual(ind).Xadd)];
end

%--------------------------------------------------------------------------
%% Plot
p               = IBD_plotDatabase('overview',individual_ref);
p = p(2:3);    % do not show bacteria
[p.tikz]        = deal(true);
[p.showLegend]  = deal(false);
[p.main]        = deal('');

for i = 1:length(p)
    p(i).background     = [T_treat TNF.options.duration+T_treat];
    p(i).backgroundCol  = IBD_myColours('treatmentBackground');
end

f1     = IBD_plotIndividuals(individual_x,p);

%--------------------------------------------------------------------------
%% Copy into new figure
f = figure;
for i = 1:8
    s(i) = subplot(4,2,i);
    set(gca,'visible','off')
end

% Adapt subplot positions
barrierUp = 0.04;
for i = [3 4]
    s(i).Position(2) = s(i).Position(2)+barrierUp;
end
for i = [7 8]
    s(i).Position(2) = s(i).Position(2)+barrierUp;
end

xx = [1 13;3 14; 5 10; 7 12; 2 6; 4 8; 6 2; 8 4];

for i = 1:size(xx,1)
    f1.Children(xx(i,2)).XLabel.String = '';
    f1.Children(xx(i,2)).YLabel.String = '';
    if ismember(xx(i,1),[1 2 5 6])
        f1.Children(xx(i,2)).XTickLabel = {};
    end
    new(xx(i,1)) = copyobj(f1.Children(xx(i,2)),f);
    new(xx(i,1)).Position = s(xx(i,1)).Position;
end

% Titles
titleUp = 1.4;
t = title(new(1),'Patient A');
xl = new(1).XLim;
yl = new(1).YLim;
text(new(1),xl(1),(yl(2)-yl(1))*titleUp+yl(1),t.String,'HorizontalAlignment','left','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
new(1).Title.String = '';

t = title(new(2),'Patient B');
xl = new(2).XLim;
yl = new(2).YLim;
text(new(2),xl(1),(yl(2)-yl(1))*titleUp+yl(1),t.String,'HorizontalAlignment','left','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex')
new(2).Title.String = '';

t = title(new(4),'Cytokine inhibitor');
xl = new(4).XLim;
yl = new(4).YLim;
text(new(4),xl(end)*1.1,yl(end),t.String,'HorizontalAlignment','center','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex','Rotation',-90)
new(4).Title.String = '';

t = title(new(8),'Anti-cell adhesion');
xl = new(8).XLim;
yl = new(8).YLim;
text(new(8),xl(end)*1.1,yl(end),t.String,'HorizontalAlignment','center','FontSize',t.FontSize,'FontWeight',t.FontWeight,'Interpreter','latex','Rotation',-90)
new(8).Title.String = '';

% Markers
bracketDown = -0.5;
for i = [7 8]
    axes(new(i))
    bracket = drawbrace([(T_treat+TNF.options.duration)/24 bracketDown],[T_treat/24 bracketDown],[],'Color','k');
    set(bracket,'clipping','off')
    bracketTarget = min(bracket.YData);
    plot(new(i),[0,0],[bracketTarget,bracketDown],'clipping','off','Color','black')
    plot([-10,0,10],[bracketDown-0.1,bracketDown,bracketDown-0.1],'clipping','off','Color','black')
    TextDown = bracketTarget;
    text(new(i),0,TextDown,'Trigger','HorizontalAlignment','left','VerticalAlignment','top')
    text(new(i),(T_treat+TNF.options.duration/2)/24,TextDown,'Treatment','HorizontalAlignment','center','VerticalAlignment','top')
    text(new(i),(T_treat+TNF.options.duration)/24,TextDown,'Post-treatment','HorizontalAlignment','left','VerticalAlignment','top')
end

% y-labels
for i = [1 5]
    ylabel(new(i),'Conc. [1/mL]')
end
for i = [3 7]
    ylabel(new(i),{'State variable'; 'value'})
end
% x-labels
for i = [3 4]
    xlabel(new(i),'Time [days]')
end

% Responder/non-responder/relapse
text_x = 200;
text_y = 0.2;
colour = [0.5 0.5 0.5];
i=3; text(new(i),text_x,new(i).YLim(2)*text_y,'$\rightarrow$ non-responder','Interpreter','latex','Color',colour)
i=4; text(new(i),text_x,new(i).YLim(2)*text_y,'$\rightarrow$ responder','Interpreter','latex','Color',colour)
i=7; text(new(i),text_x,new(i).YLim(2)*text_y,'$\rightarrow$ responder','Interpreter','latex','Color',colour)
i=8; text(new(i),text_x,new(i).YLim(2)*text_y,'$\rightarrow$ responder/relapse','Interpreter','latex','Color',colour)

IBD_saveFigure(f,'Paper_ExamplePatients','tikz')

%--------------------------------------------------------------------------
